@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 
 #define TEST_MAP_WIDTH 72
 #define TEST_MAP_HEIGHT 24
+#define TEST_MAP_NB_LAYERS 2
 #define TEST_NB_ROUNDS 1000
 #define TEST_ROUNDS_STEP 10
 #define TEST_SERVER_ID 0x1234123412341234LL
@@ -52,7 +53,8 @@ new_data (lw6map_level_t ** level,
 {
   int ret = 0;
 
-  *level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+  *level =
+    lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
   *game_struct = lw6ker_game_struct_new (*level, NULL);
   *game_state = lw6ker_game_state_new (*game_struct, NULL);
 
