@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@ _mod_random_repr (_mod_random_context_t * random_context, u_int32_t id)
 
   ret =
     lw6sys_new_sprintf (_("%u random pos=%d,%d"), id,
-			(int) random_context->pos.x,
-			(int) random_context->pos.y);
+			(int) random_context->pos_x,
+			(int) random_context->pos_y);
 
   return ret;
 }
