@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,6 +25,10 @@
 #endif
 
 #ifdef LW6_CONSOLE
+/*
+ * Need stdio.h for some old readline headers, see bug #24315 on Savannah
+ */
+#include <stdio.h>
 #include <readline/history.h>
 #endif
 
