@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -653,14 +653,15 @@ lw6gfx_display_map_zones (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 
 void
 lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
-			     lw6ker_game_state_t * game_state, int team_id)
+			     lw6ker_game_state_t * game_state, int team_id,
+			     int layer_id)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_map_gradient)
     {
       backend->display_map_gradient (backend->gfx_context, look, game_state,
-				     team_id);
+				     team_id, layer_id);
     }
   else
     {
@@ -672,13 +673,15 @@ lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 
 void
 lw6gfx_display_game (lw6gfx_backend_t * backend,
-		     lw6gui_look_t * look, lw6ker_game_state_t * game_state)
+		     lw6gui_look_t * look, lw6ker_game_state_t * game_state,
+		     u_int16_t main_cursor_id)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_game)
     {
-      backend->display_game (backend->gfx_context, look, game_state);
+      backend->display_game (backend->gfx_context, look, game_state,
+			     main_cursor_id);
     }
   else
     {
@@ -691,13 +694,15 @@ lw6gfx_display_game (lw6gfx_backend_t * backend,
 void
 lw6gfx_display_cursors (lw6gfx_backend_t * backend,
 			lw6gui_look_t * look,
-			lw6ker_game_state_t * game_state)
+			lw6ker_game_state_t * game_state,
+			u_int16_t main_cursor_id)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_cursors)
     {
-      backend->display_cursors (backend->gfx_context, look, game_state);
+      backend->display_cursors (backend->gfx_context, look, game_state,
+				main_cursor_id);
     }
   else
     {
