@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -116,3 +116,11 @@ mod_gl_utils_update_team_color_map (mod_gl_utils_team_color_map_t *
 	}
     }
 }
+
+void
+mod_gl_utils_force_color32_alpha (Uint32 * color, float alpha)
+{
+  unsigned char *ptr = (unsigned char *) color;
+
+  ptr[3] = (unsigned char) (alpha * 255.0f);
+}
