@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,11 +38,16 @@
 SDL_Surface *
 mod_gl_utils_create_gradient_surface (mod_gl_utils_context_t * utils_context,
 				      lw6ker_map_state_t * map_state,
-				      int team_id)
+				      int team_id, int layer_id)
 {
   SDL_Surface *gradient_surface;
   lw6sys_color_f_t color;
 
+  if (layer_id < 0 || layer_id >= map_state->shape.d)
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("layer %d out of range"), layer_id);
+    }
+
   gradient_surface =
     mod_gl_utils_create_surface (utils_context,
 				 map_state->map_struct->shape.w,
@@ -74,20 +79,23 @@ mod_gl_utils_create_gradient_surface (mod_gl_utils_context_t * utils_context,
       for (i = 0; i < map_state->map_struct->nb_zones; ++i)
 	{
 	  zone = &map_state->map_struct->zones[i];
-	  grey =
-	    ((float) (team->gradient[i].potential - pot_min)) /
-	    ((float) (pot_max - pot_min));
-	  grey *= DISPLAY_CYCLES;
-	  grey = fmod (grey, 1.0f);
+	  if (zone->pos.z == layer_id)
+	    {
+	      grey =
+		((float) (team->gradient[i].potential - pot_min)) /
+		((float) (pot_max - pot_min));
+	      grey *= DISPLAY_CYCLES;
+	      grey = fmod (grey, 1.0f);
 
-	  color.r = color.g = color.b = grey;
-	  color.a = utils_context->const_data.gradient_opacity;
+	      color.r = color.g = color.b = grey;
+	      color.a = utils_context->const_data.gradient_opacity;
 
-	  mod_gl_utils_draw_rectfill (gradient_surface, zone->pos.x,
-				      zone->pos.y,
-				      zone->pos.x + zone->size - 1,
-				      zone->pos.y + zone->size - 1,
-				      lw6sys_color_f_to_i (&color));
+	      mod_gl_utils_draw_rectfill (gradient_surface, zone->pos.x,
+					  zone->pos.y,
+					  zone->pos.x + zone->size - 1,
+					  zone->pos.y + zone->size - 1,
+					  lw6sys_color_f_to_i (&color));
+	    }
 	}
     }
 
