@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -106,9 +106,9 @@ map2surface_xywh (mod_gl_utils_context_t * gfx_context,
        * Blit map to image
        */
       memset (ret->pixels, 0, ret->pitch * ret->h);
-      for (i = 0; i < level->texture.shape.w; ++i)
+      for (i = 0; i < level->texture.w; ++i)
 	{
-	  for (j = 0; j < level->texture.shape.h; ++j)
+	  for (j = 0; j < level->texture.h; ++j)
 	    {
 	      color_8 = lw6map_texture_get (&level->texture, i, j);
 	      mod_gl_utils_putpixel (ret, i + x, j + y,
@@ -134,8 +134,8 @@ map2surface (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level)
    * No need to use the closest power of 2 here, it does not
    * make sense for a surface (but it surely does for a texture).
    */
-  return map2surface_wh (gfx_context, level, level->texture.shape.w,
-			 level->texture.shape.h);
+  return map2surface_wh (gfx_context, level, level->texture.w,
+			 level->texture.h);
 }
 
 SDL_Surface *
