@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -289,8 +289,8 @@ map2texture (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level)
   int w, h;
 
   /* Use the map width and height expanded to powers of 2 */
-  w = mod_gl_utils_power_of_two_ge (level->texture.shape.w);
-  h = mod_gl_utils_power_of_two_ge (level->texture.shape.h);
+  w = mod_gl_utils_power_of_two_ge (level->texture.w);
+  h = mod_gl_utils_power_of_two_ge (level->texture.h);
 
   return map2texture_wh (gfx_context, level, w, h);
 }
