@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -186,14 +186,14 @@ mod_gl_utils_map2texture_xywh_using_cache (mod_gl_utils_context_t * context,
   GLuint texture = 0;
 
   texture =
-    find_in_cache (context, level->texture.shape.w, level->texture.shape.h,
+    find_in_cache (context, level->texture.w, level->texture.h,
 		   str_key, int_key);
 
   if (!texture)
     {
       texture = mod_gl_utils_map2texture_xywh (context, level, x, y, w, h);
 
-      store_in_cache (context, level->texture.shape.w, level->texture.shape.h,
+      store_in_cache (context, level->texture.w, level->texture.h,
 		      str_key, int_key, texture);
     }
 
@@ -208,14 +208,14 @@ mod_gl_utils_map2texture_wh_using_cache (mod_gl_utils_context_t * context,
   GLuint texture = 0;
 
   texture =
-    find_in_cache (context, level->texture.shape.w, level->texture.shape.h,
+    find_in_cache (context, level->texture.w, level->texture.h,
 		   str_key, int_key);
 
   if (!texture)
     {
       texture = mod_gl_utils_map2texture_wh (context, level, w, h);
 
-      store_in_cache (context, level->texture.shape.w, level->texture.shape.h,
+      store_in_cache (context, level->texture.w, level->texture.h,
 		      str_key, int_key, texture);
     }
 
@@ -230,14 +230,14 @@ mod_gl_utils_map2texture_using_cache (mod_gl_utils_context_t * context,
   GLuint texture = 0;
 
   texture =
-    find_in_cache (context, level->texture.shape.w, level->texture.shape.h,
+    find_in_cache (context, level->texture.w, level->texture.h,
 		   str_key, int_key);
 
   if (!texture)
     {
       texture = mod_gl_utils_map2texture (context, level);
 
-      store_in_cache (context, level->texture.shape.w, level->texture.shape.h,
+      store_in_cache (context, level->texture.w, level->texture.h,
 		      str_key, int_key, texture);
     }
 
