@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -368,6 +368,7 @@ extern SDL_Color mod_gl_utils_color_f_to_sdl (lw6sys_color_f_t * color_f);
 extern void mod_gl_utils_update_team_color_map (mod_gl_utils_team_color_map_t
 						* team_color_map,
 						lw6map_style_t * map_style);
+extern void mod_gl_utils_force_color32_alpha (Uint32 * color, float alpha);
 inline static Uint32
 mod_gl_utils_get_shaded_color_for_fighter (mod_gl_utils_context_t *
 					   utils_context, int team_id,
@@ -510,8 +511,7 @@ extern void mod_gl_utils_update_game_texture (mod_gl_utils_context_t *
 					      GLuint texture,
 					      lw6ker_game_state_t *
 					      game_state,
-					      lw6gui_look_t * look,
-					      int layer_id);
+					      lw6gui_look_t * look);
 extern void mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
 						    utils_context,
 						    mod_gl_utils_surface_array_t
@@ -520,8 +520,7 @@ extern void mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
 						    * texture_array,
 						    lw6ker_game_state_t *
 						    game_state,
-						    lw6gui_look_t *
-						    look, int layer_id);
+						    lw6gui_look_t * look);
 
 /*
  * In gradient.c
@@ -530,7 +529,7 @@ extern SDL_Surface
   * mod_gl_utils_create_gradient_surface (mod_gl_utils_context_t *
 					  utils_context,
 					  lw6ker_map_state_t * map_state,
-					  int team_id);
+					  int team_id, int layer_id);
 
 /*
  * In info.c
@@ -884,13 +883,17 @@ extern void mod_gl_utils_viewport_calc_view_area (mod_gl_utils_context_t *
 extern void mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t *
 						 utils_context, float *map_x1,
 						 float *map_y1, float *map_x2,
-						 float *map_y2, int shape_w,
-						 int shape_h,
+						 float *map_y2,
+						 int main_cursor_x,
+						 int main_cursor_y,
+						 int shape_w, int shape_h,
 						 lw6gui_look_t * look);
 extern void mod_gl_utils_viewport_calc_map_pos (mod_gl_utils_context_t *
 						utils_context, float *map_x,
-						float *map_y, int x, int y,
-						int w, int h,
+						float *map_y, int pos_x,
+						int pos_y, int main_cursor_x,
+						int main_cursor_y,
+						int shape_w, int shape_h,
 						lw6gui_look_t * look);
 
 /*
