@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -71,7 +71,8 @@ static void
 display_texture (mod_gl_utils_context_t * utils_context,
 		 _mod_gl_view_flat_context_t * flat_context,
 		 int texture_w, int texture_h, int shape_w, int shape_h,
-		 GLuint texture, lw6gui_look_t * look)
+		 GLuint texture, int center_x, int center_y,
+		 lw6gui_look_t * look)
 {
   float x1, y1, x2, y2, scale_w, scale_h;
 
@@ -79,7 +80,8 @@ display_texture (mod_gl_utils_context_t * utils_context,
   scale_h = mod_gl_utils_texture_scale (texture_h);
 
   mod_gl_utils_viewport_calc_map_area (utils_context, &x1, &y1, &x2, &y2,
-				       shape_w, shape_h, look);
+				       center_x, center_y, shape_w, shape_h,
+				       look);
 
   display_texture_ex (utils_context,
 		      flat_context,
@@ -94,7 +96,7 @@ display_texture_array (mod_gl_utils_context_t * utils_context,
 		       int shape_w,
 		       int shape_h,
 		       mod_gl_utils_texture_array_t * texture_array,
-		       lw6gui_look_t * look)
+		       int center_x, int center_y, lw6gui_look_t * look)
 {
   float x1, y1, x2, y2, w, h, coef_x, coef_y;
   float scale_w, scale_h;
@@ -105,6 +107,7 @@ display_texture_array (mod_gl_utils_context_t * utils_context,
   float min_x, min_y, max_x, max_y;
 
   mod_gl_utils_viewport_calc_map_area (utils_context, &x1, &y1, &x2, &y2,
+				       center_x, center_y,
 				       shape_w, shape_h, look);
   w = x2 - x1;
   h = y2 - y1;
@@ -180,19 +183,16 @@ display_texture_array (mod_gl_utils_context_t * utils_context,
 static void
 display_map_preview (mod_gl_utils_context_t * utils_context,
 		     _mod_gl_view_flat_context_t * flat_context,
-		     lw6gui_look_t * look, lw6map_level_t * level)
+		     lw6gui_look_t * look, lw6map_level_t * level,
+		     int center_x, int center_y)
 {
   display_texture_array (utils_context, flat_context,
-			 flat_context->game_context.map.level->texture.shape.
-			 w,
-			 flat_context->game_context.map.level->texture.shape.
-			 h,
-			 flat_context->game_context.map.level->texture.shape.
-			 w,
-			 flat_context->game_context.map.level->texture.shape.
-			 h,
+			 flat_context->game_context.map.level->texture.w,
+			 flat_context->game_context.map.level->texture.h,
+			 flat_context->game_context.map.level->body.shape.w,
+			 flat_context->game_context.map.level->body.shape.h,
 			 &(flat_context->game_context.map.map_texture_array),
-			 look);
+			 center_x, center_y, look);
 }
 
 void
@@ -213,7 +213,8 @@ _mod_gl_view_flat_display_preview (mod_gl_utils_context_t * utils_context,
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_map_preview (utils_context, flat_context, look, level);
+      display_map_preview (utils_context, flat_context, look, level,
+			   level->body.shape.w / 2, level->body.shape.h / 2);
     }
 }
 
@@ -243,9 +244,11 @@ display_map_zones (mod_gl_utils_context_t * utils_context,
 
       if (texture)
 	{
-	  display_texture (utils_context, flat_context, map_struct->shape.w,
-			   map_struct->shape.h, level->texture.shape.w,
-			   level->texture.shape.h, texture, look);
+	  display_texture (utils_context, flat_context, level->texture.w,
+			   level->texture.h, map_struct->shape.w,
+			   map_struct->shape.h, texture,
+			   map_struct->shape.w / 2, map_struct->shape.h / 2,
+			   look);
 
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
 	}
@@ -290,22 +293,26 @@ display_map_gradient (mod_gl_utils_context_t * utils_context,
 		      _mod_gl_view_flat_context_t * flat_context,
 		      lw6gui_look_t * look,
 		      lw6map_level_t * level,
-		      lw6ker_map_state_t * map_state, int team_id)
+		      lw6ker_map_state_t * map_state, int team_id,
+		      int layer_id)
 {
   GLuint texture = 0;
   SDL_Surface *surface = NULL;
 
   surface =
-    mod_gl_utils_create_gradient_surface (utils_context, map_state, team_id);
+    mod_gl_utils_create_gradient_surface (utils_context, map_state, team_id,
+					  layer_id);
   if (surface)
     {
       texture = mod_gl_utils_surface2texture (utils_context, surface);
 
       if (texture)
 	{
-	  display_texture (utils_context, flat_context, map_state->shape.w,
-			   map_state->shape.h, level->texture.shape.w,
-			   level->texture.shape.h, texture, look);
+	  display_texture (utils_context, flat_context, level->texture.w,
+			   level->texture.h, map_state->shape.w,
+			   map_state->shape.h, texture,
+			   map_state->shape.w / 2, map_state->shape.h / 2,
+			   look);
 
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
 	}
@@ -320,7 +327,7 @@ _mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
 				    flat_context, lw6gui_look_t * look,
 				    lw6map_level_t * level,
 				    lw6ker_map_state_t * map_state,
-				    int team_id)
+				    int team_id, int layer_id)
 {
   if (utils_context && flat_context && map_state)
     {
@@ -330,7 +337,7 @@ _mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
       glEnable (GL_TEXTURE_2D);	// for texture
 
       display_map_gradient (utils_context, flat_context, look, level,
-			    map_state, team_id);
+			    map_state, team_id, layer_id);
     }
 }
 
@@ -340,12 +347,12 @@ mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
 				   lw6gui_look_t * look,
 				   lw6map_level_t * level,
 				   lw6ker_map_state_t * map_state,
-				   int team_id)
+				   int team_id, int layer_id)
 {
   _mod_gl_view_flat_display_gradient (utils_context,
 				      (_mod_gl_view_flat_context_t *)
 				      flat_context, look, level, map_state,
-				      team_id);
+				      team_id, layer_id);
 }
 
 /*
@@ -357,34 +364,27 @@ mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
 static void
 display_armies (mod_gl_utils_context_t * utils_context,
 		_mod_gl_view_flat_context_t *
-		flat_context, lw6gui_look_t * look)
+		flat_context, int center_x, int center_y,
+		lw6gui_look_t * look)
 {
-  int i;
-
-  for (i = 0;
-       i < flat_context->game_context.armies.game_state->map_state.nb_layers;
-       ++i)
-    {
-      mod_gl_utils_update_game_texture_array (utils_context,
-					      &(flat_context->game_context.
-						armies.armies_surface_array),
-					      &(flat_context->game_context.
-						armies.
-						armies_texture_arrays[i]),
-					      flat_context->game_context.
-					      armies.game_state, look, i);
-      display_texture_array (utils_context, flat_context,
-			     flat_context->game_context.armies.game_state->
-			     map_state.shape.w,
-			     flat_context->game_context.armies.game_state->
-			     map_state.shape.h,
-			     flat_context->game_context.map.level->texture.
-			     shape.w,
-			     flat_context->game_context.map.level->texture.
-			     shape.h,
-			     &(flat_context->game_context.armies.
-			       armies_texture_arrays[i]), look);
-    }
+  mod_gl_utils_update_game_texture_array (utils_context,
+					  &(flat_context->game_context.
+					    armies.armies_surface_array),
+					  &(flat_context->game_context.armies.
+					    armies_texture_array),
+					  flat_context->game_context.
+					  armies.game_state, look);
+  display_texture_array (utils_context, flat_context,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.w,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.h,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.w,
+			 flat_context->game_context.armies.game_state->
+			 map_state.shape.h,
+			 &(flat_context->game_context.armies.
+			   armies_texture_array), center_x, center_y, look);
 }
 
 /*
@@ -397,11 +397,17 @@ static void
 display_game (mod_gl_utils_context_t * utils_context,
 	      _mod_gl_view_flat_context_t *
 	      flat_context, lw6gui_look_t * look,
-	      lw6ker_game_state_t * game_state)
+	      lw6ker_game_state_t * game_state, u_int16_t main_cursor_id)
 {
+  int center_x = 0;
+  int center_y = 0;
+
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("display game"));
+  lw6ker_game_state_get_cursor_info (game_state, main_cursor_id,
+				     NULL, NULL, NULL, &center_x, &center_y);
   display_map_preview (utils_context, flat_context, look,
-		       game_state->game_struct->level);
-  display_armies (utils_context, flat_context, look);
+		       game_state->game_struct->level, center_x, center_y);
+  display_armies (utils_context, flat_context, center_x, center_y, look);
 }
 
 void
@@ -409,7 +415,8 @@ _mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
 				_mod_gl_view_flat_context_t *
 				flat_context,
 				lw6gui_look_t * look,
-				lw6ker_game_state_t * game_state)
+				lw6ker_game_state_t * game_state,
+				u_int16_t main_cursor_id)
 {
   if (utils_context && flat_context && game_state)
     {
@@ -427,7 +434,8 @@ _mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_game (utils_context, flat_context, look, game_state);
+      display_game (utils_context, flat_context, look, game_state,
+		    main_cursor_id);
     }
 }
 
@@ -435,11 +443,13 @@ void
 mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
 			       void *flat_context,
 			       lw6gui_look_t * look,
-			       lw6ker_game_state_t * game_state)
+			       lw6ker_game_state_t * game_state,
+			       u_int16_t main_cursor_id)
 {
   _mod_gl_view_flat_display_game (utils_context,
 				  (_mod_gl_view_flat_context_t *)
-				  flat_context, look, game_state);
+				  flat_context, look, game_state,
+				  main_cursor_id);
 }
 
 static void
@@ -456,7 +466,8 @@ static void
 display_cursor (mod_gl_utils_context_t * utils_context,
 		_mod_gl_view_flat_context_t * flat_context,
 		lw6gui_look_t * look,
-		int i, int x, int y, lw6sys_wh_t * shape, int even_odd)
+		int i, int x, int y, int w, int h, int center_x, int center_y,
+		int even_odd)
 {
 
   float cursor_x = 0.0f;
@@ -465,7 +476,7 @@ display_cursor (mod_gl_utils_context_t * utils_context,
   float cursor_h = 0.0f;
 
   mod_gl_utils_viewport_calc_map_pos (utils_context, &cursor_x, &cursor_y,
-				      x, y, shape->w, shape->h, look);
+				      x, y, center_x, center_y, w, h, look);
   cursor_w = cursor_h =
     (utils_context->screen.width +
      utils_context->screen.height) * flat_context->const_data.cursor_size *
@@ -484,16 +495,21 @@ static void
 display_cursors (mod_gl_utils_context_t * utils_context,
 		 _mod_gl_view_flat_context_t *
 		 flat_context,
-		 lw6gui_look_t * look, lw6ker_game_state_t * game_state)
+		 lw6gui_look_t * look, lw6ker_game_state_t * game_state,
+		 u_int16_t main_cursor_id)
 {
   int i;
   lw6ker_cursor_t *cursor;
   int blink_state;
+  int center_x = 0;
+  int center_y = 0;
 
   lw6sys_log (LW6SYS_LOG_DEBUG, _("display cursors"));
   blink_state =
     mod_gl_utils_get_ticks (utils_context) /
     (flat_context->const_data.cursor_blink_period / 2) % 2;
+  lw6ker_game_state_get_cursor_info (game_state, main_cursor_id,
+				     NULL, NULL, NULL, &center_x, &center_y);
   for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
     {
       cursor = &(game_state->map_state.cursor_array.cursors[i]);
@@ -501,7 +517,9 @@ display_cursors (mod_gl_utils_context_t * utils_context,
 	{
 	  display_cursor (utils_context, flat_context, look,
 			  i, cursor->pos.x, cursor->pos.y,
-			  &game_state->map_state.shape, blink_state);
+			  game_state->map_state.shape.w,
+			  game_state->map_state.shape.h, center_x, center_y,
+			  blink_state);
 	}
     }
 }
@@ -511,7 +529,8 @@ _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t * utils_context,
 				   _mod_gl_view_flat_context_t *
 				   flat_context,
 				   lw6gui_look_t * look,
-				   lw6ker_game_state_t * game_state)
+				   lw6ker_game_state_t * game_state,
+				   u_int16_t main_cursor_id)
 {
   if (utils_context && flat_context && game_state)
     {
@@ -526,7 +545,8 @@ _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t * utils_context,
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_cursors (utils_context, flat_context, look, game_state);
+      display_cursors (utils_context, flat_context, look, game_state,
+		       main_cursor_id);
     }
 }
 
@@ -535,9 +555,11 @@ mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
 				  utils_context,
 				  void *flat_context,
 				  lw6gui_look_t * look,
-				  lw6ker_game_state_t * game_state)
+				  lw6ker_game_state_t * game_state,
+				  u_int16_t main_cursor_id)
 {
   _mod_gl_view_flat_display_cursors (utils_context,
 				     (_mod_gl_view_flat_context_t *)
-				     flat_context, look, game_state);
+				     flat_context, look, game_state,
+				     main_cursor_id);
 }
