@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -84,8 +84,8 @@ _mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
 					     &
 					     (game_context_map->
 					      map_texture_array),
-					     level->texture.shape.w,
-					     level->texture.shape.h,
+					     level->texture.w,
+					     level->texture.h,
 					     flat_context->const_data.
 					     tile_size_map);
       if (ret)
@@ -123,8 +123,6 @@ _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t *
 					    lw6ker_game_state_t * game_state)
 {
   int ret = 0;
-  int i;
-
   ret = 1;
 
   ret = ret
@@ -137,18 +135,15 @@ _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t *
 					flat_context->const_data.
 					tile_size_armies);
 
-  for (i = 0; i < game_state->map_state.nb_layers; ++i)
-    {
-      ret = ret
-	&& mod_gl_utils_texture_array_init (utils_context,
-					    &
-					    (game_context_armies->
-					     armies_texture_arrays[i]),
-					    game_state->map_state.shape.w,
-					    game_state->map_state.shape.h,
-					    flat_context->const_data.
-					    tile_size_armies);
-    }
+  ret = ret
+    && mod_gl_utils_texture_array_init (utils_context,
+					&
+					(game_context_armies->
+					 armies_texture_array),
+					game_state->map_state.shape.w,
+					game_state->map_state.shape.h,
+					flat_context->const_data.
+					tile_size_armies);
 
   game_context_armies->game_state = game_state;
   game_context_armies->game_state_id = game_state->id;
@@ -197,19 +192,13 @@ _mod_gl_view_flat_game_context_clear_armies (mod_gl_utils_context_t *
 					     _mod_gl_view_flat_game_context_armies_t
 					     * game_context_armies)
 {
-  int i;
-
   mod_gl_utils_surface_array_clear (utils_context,
 				    &
 				    (game_context_armies->
 				     armies_surface_array));
-  for (i = 0; i < LW6MAP_MAX_DEPTH; ++i)
-    {
-      mod_gl_utils_texture_array_clear (utils_context,
-					&
-					(game_context_armies->
-					 armies_texture_arrays[i]));
-    }
+  mod_gl_utils_texture_array_clear (utils_context,
+				    &(game_context_armies->
+				      armies_texture_array));
 
   memset (game_context_armies, 0,
 	  sizeof (_mod_gl_view_flat_game_context_armies_t));
