@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ typedef struct _mod_gl_view_flat_game_context_armies_s
   int game_state_id;
   lw6ker_game_state_t *game_state;
   mod_gl_utils_surface_array_t armies_surface_array;
-  mod_gl_utils_texture_array_t armies_texture_arrays[LW6MAP_MAX_DEPTH];
+  mod_gl_utils_texture_array_t armies_texture_array;
 }
 _mod_gl_view_flat_game_context_armies_t;
 
@@ -168,20 +168,23 @@ extern void _mod_gl_view_flat_display_gradient (mod_gl_utils_context_t *
 						lw6gui_look_t * look,
 						lw6map_level_t * level,
 						lw6ker_map_state_t *
-						map_state, int team_id);
+						map_state, int team_id,
+						int layer_id);
 extern void _mod_gl_view_flat_display_game (mod_gl_utils_context_t *
 					    utils_context,
 					    _mod_gl_view_flat_context_t *
 					    flat_context,
 					    lw6gui_look_t * look,
-					    lw6ker_game_state_t * game_state);
+					    lw6ker_game_state_t * game_state,
+					    u_int16_t main_cursor_id);
 extern void _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
 					       utils_context,
 					       _mod_gl_view_flat_context_t *
 					       flat_context,
 					       lw6gui_look_t * look,
 					       lw6ker_game_state_t *
-					       game_state);
+					       game_state,
+					       u_int16_t main_cursor_id);
 
 /*
  * In gamecontext.c
