@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -51,18 +51,20 @@ extern void mod_gl_view_flat_display_gradient (mod_gl_utils_context_t *
 					       lw6gui_look_t * look,
 					       lw6map_level_t * level,
 					       lw6ker_map_state_t * map_state,
-					       int team_id);
+					       int team_id, int layer_id);
 extern void mod_gl_view_flat_display_game (mod_gl_utils_context_t *
 					   utils_context,
 					   void *flat_context,
 					   lw6gui_look_t * look,
-					   lw6ker_game_state_t * game_state);
+					   lw6ker_game_state_t * game_state,
+					   u_int16_t main_cursor_id);
 extern void mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
 					      utils_context,
 					      void *flat_context,
 					      lw6gui_look_t * look,
 					      lw6ker_game_state_t *
-					      game_state);
+					      game_state,
+					      u_int16_t main_cursor_id);
 
 /*
  * In setup.c
