@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,13 +48,16 @@ typedef struct mod_gl_view_backend_s
   void (*display_gradient) (mod_gl_utils_context_t * utils_context,
 			    void *view_context, lw6gui_look_t * look,
 			    lw6map_level_t * level,
-			    lw6ker_map_state_t * map_state, int team_id);
+			    lw6ker_map_state_t * map_state, int team_id,
+			    int layer_id);
   void (*display_game) (mod_gl_utils_context_t * utils_context,
 			void *view_context, lw6gui_look_t * look,
-			lw6ker_game_state_t * game_state);
+			lw6ker_game_state_t * game_state,
+			u_int16_t main_cursor_id);
   void (*display_cursors) (mod_gl_utils_context_t * utils_context,
 			   void *view_context, lw6gui_look_t * look,
-			   lw6ker_game_state_t * game_state);
+			   lw6ker_game_state_t * game_state,
+			   u_int16_t main_cursor_id);
 }
 mod_gl_view_backend_t;
 
@@ -81,16 +84,18 @@ extern void mod_gl_view_display_gradient (mod_gl_utils_context_t *
 					  lw6gui_look_t * look,
 					  lw6map_level_t * level,
 					  lw6ker_map_state_t * map_state,
-					  int team_id);
+					  int team_id, int layer_id);
 extern void mod_gl_view_display_game (mod_gl_utils_context_t * utils_context,
 				      mod_gl_view_backend_t * backend,
 				      lw6gui_look_t * look,
-				      lw6ker_game_state_t * game_state);
+				      lw6ker_game_state_t * game_state,
+				      u_int16_t main_cursor_id);
 extern void mod_gl_view_display_cursors (mod_gl_utils_context_t *
 					 utils_context,
 					 mod_gl_view_backend_t * backend,
 					 lw6gui_look_t * look,
-					 lw6ker_game_state_t * game_state);
+					 lw6ker_game_state_t * game_state,
+					 u_int16_t main_cursor_id);
 
 /*
  * In backend.c
