@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -478,7 +478,8 @@ _display_map_zones (void *gfx_context, lw6gui_look_t * look,
 
 static void
 _display_map_gradient (void *gfx_context, lw6gui_look_t * look,
-		       lw6ker_game_state_t * game_state, int team_id)
+		       lw6ker_game_state_t * game_state, int team_id,
+		       int layer_id)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -489,13 +490,14 @@ _display_map_gradient (void *gfx_context, lw6gui_look_t * look,
       mod_gl_view_display_gradient (&(mod_gl_context->utils_context),
 				    mod_gl_context->view_backend, look,
 				    game_state->game_struct->level,
-				    &(game_state->map_state), team_id);
+				    &(game_state->map_state), team_id,
+				    layer_id);
     }
 }
 
 static void
 _display_game (void *gfx_context, lw6gui_look_t * look,
-	       lw6ker_game_state_t * game_state)
+	       lw6ker_game_state_t * game_state, u_int16_t main_cursor_id)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -505,13 +507,13 @@ _display_game (void *gfx_context, lw6gui_look_t * look,
 
       mod_gl_view_display_game (&(mod_gl_context->utils_context),
 				mod_gl_context->view_backend, look,
-				game_state);
+				game_state, main_cursor_id);
     }
 }
 
 static void
 _display_cursors (void *gfx_context, lw6gui_look_t * look,
-		  lw6ker_game_state_t * game_state)
+		  lw6ker_game_state_t * game_state, u_int16_t main_cursor_id)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -521,7 +523,7 @@ _display_cursors (void *gfx_context, lw6gui_look_t * look,
 
       mod_gl_view_display_cursors (&(mod_gl_context->utils_context),
 				   mod_gl_context->view_backend, look,
-				   game_state);
+				   game_state, main_cursor_id);
     }
 }
 
@@ -769,7 +771,7 @@ mod_gl_get_pedigree ()
 	("This is the most accomplished graphics backend for Liquid War 6. It uses OpenGL hardware acceleration if available, and uses SDL as a technical wrapper.");
       module_pedigree->version = VERSION;
       module_pedigree->copyright =
-	"Copyright (C)  2008  Christian Mauduit <ufoot@ufoot.org>";
+	"Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
