@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,8 +36,6 @@ update_quick (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_VERSION);
   lw6sys_list_push_back (list, LW6DEF_TEST);
   lw6sys_list_push_back (list, LW6DEF_PEDIGREE);
-  lw6sys_list_push_back (list, LW6DEF_AUDIT);
-  lw6sys_list_push_back (list, LW6DEF_MODULES);
   lw6sys_list_push_back (list, LW6DEF_RESET);
   lw6sys_list_push_back (list, LW6DEF_DEFAULTS);
   lw6sys_list_push_back (list, LW6DEF_LIST);
@@ -122,6 +120,8 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_DATE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TIME);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TARGET_CPU);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENDIANNESS);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_POINTER_SIZE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TARGET_OS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MS_WINDOWS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TOP_SRCDIR);
@@ -399,11 +399,13 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_FIGHTER_ATTACK);
   lw6sys_list_push_back (list, LW6DEF_FIGHTER_DEFENSE);
   lw6sys_list_push_back (list, LW6DEF_FIGHTER_NEW_HEALTH);
+  lw6sys_list_push_back (list, LW6DEF_FIGHTER_REGENERATE);
   lw6sys_list_push_back (list, LW6DEF_SIDE_ATTACK_FACTOR);
   lw6sys_list_push_back (list, LW6DEF_SIDE_DEFENSE_FACTOR);
   lw6sys_list_push_back (list, LW6DEF_NB_MOVE_TRIES);
   lw6sys_list_push_back (list, LW6DEF_NB_ATTACK_TRIES);
   lw6sys_list_push_back (list, LW6DEF_NB_DEFENSE_TRIES);
+  lw6sys_list_push_back (list, LW6DEF_VERTICAL_MOVE);
   lw6sys_list_push_back (list, LW6DEF_SINGLE_ARMY_SIZE);
   lw6sys_list_push_back (list, LW6DEF_TOTAL_ARMIES_SIZE);
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_TEAMS);
@@ -411,6 +413,7 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_SERVERS);
   lw6sys_list_push_back (list, LW6DEF_X_POLARITY);
   lw6sys_list_push_back (list, LW6DEF_Y_POLARITY);
+  lw6sys_list_push_back (list, LW6DEF_Z_POLARITY);
   lw6sys_list_push_back (list, LW6DEF_MAX_ZONE_SIZE);
   lw6sys_list_push_back (list, LW6DEF_ROUND_DELTA);
   lw6sys_list_push_back (list, LW6DEF_MAX_ROUND_DELTA);
@@ -505,6 +508,7 @@ update_map_style (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_ANIMATION_DENSITY);
   lw6sys_list_push_back (list, LW6DEF_ANIMATION_SPEED);
   lw6sys_list_push_back (list, LW6DEF_CURSOR_SIZE);
+  lw6sys_list_push_back (list, LW6DEF_HIDDEN_LAYER_ALPHA);
   lw6sys_list_push_back (list, LW6DEF_COLORIZE);
   lw6sys_list_push_back (list, LW6DEF_COLOR_BASE_BG);
   lw6sys_list_push_back (list, LW6DEF_COLOR_BASE_FG);
@@ -601,6 +605,9 @@ lw6hlp_list_hooks ()
 static int
 update_tuning (lw6sys_list_t ** list)
 {
+  lw6sys_list_push_back (list, LW6DEF_TARGET);
+  lw6sys_list_push_back (list, LW6DEF_AUDIT);
+  lw6sys_list_push_back (list, LW6DEF_MODULES);
   lw6sys_list_push_back (list, LW6DEF_LOG_LEVEL);
   lw6sys_list_push_back (list, LW6DEF_FRAMES_PER_SEC);
   lw6sys_list_push_back (list, LW6DEF_IO_PER_SEC);
