@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,8 +44,8 @@ _lw6ker_cursor_update_checksum (lw6ker_cursor_t * cursor,
   lw6sys_checksum_update_int32 (checksum, cursor->letter);
   lw6sys_checksum_update_int32 (checksum, cursor->enabled);
   lw6sys_checksum_update_int32 (checksum, cursor->team_color);
-  lw6sys_checksum_update_xy (checksum, &(cursor->pos));
-  lw6sys_checksum_update_xy (checksum, &(cursor->apply_pos));
+  lw6sys_checksum_update_xyz (checksum, &(cursor->pos));
+  lw6sys_checksum_update_xyz (checksum, &(cursor->apply_pos));
   lw6sys_checksum_update_int32 (checksum, cursor->pot_offset);
 }
 
@@ -69,7 +69,7 @@ _lw6ker_cursor_check_server_id (lw6ker_cursor_t * cursor, u_int64_t server_id)
 
 int
 _lw6ker_cursor_get_start_xy (int32_t * x, int32_t * y, int team_color,
-			     lw6sys_wh_t * shape, lw6map_rules_t * rules)
+			     lw6sys_whd_t * shape, lw6map_rules_t * rules)
 {
   int ret = 1;
   int32_t px = 50;
@@ -206,7 +206,7 @@ lw6ker_cursor_disable (lw6ker_cursor_t * cursor)
 int
 lw6ker_cursor_update (lw6ker_cursor_t * cursor, int32_t x,
 		      int32_t y, int32_t pot_offset,
-		      lw6sys_wh_t * shape, lw6map_rules_t * rules)
+		      lw6sys_whd_t * shape, lw6map_rules_t * rules)
 {
   int ret = 1;
 
@@ -225,7 +225,7 @@ lw6ker_cursor_update (lw6ker_cursor_t * cursor, int32_t x,
 
 int
 lw6ker_cursor_sanity_check (lw6ker_cursor_t * cursor,
-			    lw6sys_wh_t * shape, lw6map_rules_t * rules)
+			    lw6sys_whd_t * shape, lw6map_rules_t * rules)
 {
   int ret = 1;
 
