@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,10 +49,11 @@ _lw6ker_fighter_update_checksum (lw6ker_fighter_t * fighter,
 				 u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, fighter->team_color);
-  lw6sys_checksum_update_int32 (checksum, fighter->layer);
   lw6sys_checksum_update_int32 (checksum, fighter->last_direction);
   lw6sys_checksum_update_int32 (checksum, fighter->health);
-  lw6sys_checksum_update_xy (checksum, &(fighter->pos));
+  lw6sys_checksum_update_int32 (checksum, fighter->pos.x);
+  lw6sys_checksum_update_int32 (checksum, fighter->pos.y);
+  lw6sys_checksum_update_int32 (checksum, fighter->pos.z);
 }
 
 void
@@ -60,37 +61,38 @@ _lw6ker_fighter_print_debug (lw6ker_fighter_t * fighter)
 {
   lw6sys_log (LW6SYS_LOG_DEBUG,
 	      _
-	      ("fighter team_color=%d, layer=%d, last_direction=%d, health=%d, x=%d, y=%d"),
-	      fighter->team_color, fighter->layer, fighter->last_direction,
-	      fighter->health, (int) fighter->pos.x, (int) fighter->pos.y);
+	      ("fighter team_color=%d, last_direction=%d, health=%d, x=%d, y=%d, z=%d"),
+	      fighter->team_color, fighter->last_direction,
+	      fighter->health, (int) fighter->pos.x, (int) fighter->pos.y,
+	      (int) fighter->pos.z);
 }
 
 void
 _lw6ker_fighter_move (lw6ker_fighter_t * fighter,
 		      int32_t fighter_id,
-		      int32_t layer, int32_t x,
-		      int32_t y, lw6ker_map_state_t * map_state)
+		      int32_t x,
+		      int32_t y, int32_t z, lw6ker_map_state_t * map_state)
 {
-  lw6ker_map_state_set_fighter_id (map_state, fighter->layer,
-				   fighter->pos.x, fighter->pos.y, -1);
-  fighter->layer = layer;
+  lw6ker_map_state_set_fighter_id (map_state,
+				   fighter->pos.x, fighter->pos.y,
+				   fighter->pos.z, -1);
   fighter->pos.x = x;
   fighter->pos.y = y;
-  lw6ker_map_state_set_fighter_id (map_state, layer, x, y, fighter_id);
+  fighter->pos.z = z;
+  lw6ker_map_state_set_fighter_id (map_state, x, y, z, fighter_id);
 }
 
 void
 _lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
-			int32_t fighter_id,
-			int32_t layer, int32_t x,
-			int32_t y, lw6ker_map_state_t * map_state,
+			int32_t x,
+			int32_t y, int32_t z, lw6ker_map_state_t * map_state,
 			int32_t fighter_attack, int32_t fighter_new_health)
 {
   lw6ker_fighter_t *enemy;
 
-  enemy = lw6ker_map_state_get_fighter_unsafe (map_state, layer, x, y);
+  enemy = lw6ker_map_state_get_fighter_unsafe (map_state, x, y, z);
   enemy->health -= fighter_attack;
-  if (enemy->health <= 0 || enemy->health > LW6MAP_MAX_FIGHTER_HEALTH)
+  if (enemy->health <= 0)
     {
       /*
        * Reflect changes in pre-calculated values
@@ -110,18 +112,29 @@ _lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
 
 void
 _lw6ker_fighter_defend (lw6ker_fighter_t * fighter,
-			int32_t fighter_id,
-			int32_t layer, int32_t x,
+			int32_t x,
 			int32_t y,
+			int32_t z,
 			lw6ker_map_state_t * map_state,
 			int32_t fighter_defense)
 {
   lw6ker_fighter_t *ally;
 
-  ally = lw6ker_map_state_get_fighter_unsafe (map_state, layer, x, y);
+  ally = lw6ker_map_state_get_fighter_unsafe (map_state, x, y, z);
   ally->health += fighter_defense;
-  if (ally->health > LW6MAP_MAX_FIGHTER_HEALTH || ally->health <= 0)
+  if (ally->health > LW6MAP_MAX_FIGHTER_HEALTH)
     {
       ally->health = LW6MAP_MAX_FIGHTER_HEALTH;
     }
 }
+
+void
+_lw6ker_fighter_regenerate (lw6ker_fighter_t * fighter,
+			    int32_t fighter_regenerate)
+{
+  fighter->health += fighter_regenerate;
+  if (fighter->health > LW6MAP_MAX_FIGHTER_HEALTH)
+    {
+      fighter->health = LW6MAP_MAX_FIGHTER_HEALTH;
+    }
+}
