@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -98,10 +98,6 @@ lw6ker_game_state_point_to (lw6ker_game_state_t * game_state,
     {
       game_state->map_state.teams[i].map_struct = &(game_struct->map_struct);
     }
-  for (i = 0; i < LW6MAP_MAX_DEPTH; ++i)
-    {
-      game_state->map_state.layers[i].map_struct = &(game_struct->map_struct);
-    }
 }
 
 int
@@ -126,10 +122,11 @@ lw6ker_game_state_repr (lw6ker_game_state_t * game_state)
        * function is called when freeing the object
        */
       ret =
-	lw6sys_new_sprintf ("%u (%dx%d, round %d, %d fighters)",
+	lw6sys_new_sprintf ("%u (%dx%dx%d, round %d, %d fighters)",
 			    game_state->id,
 			    game_state->map_state.shape.w,
 			    game_state->map_state.shape.h,
+			    game_state->map_state.shape.d,
 			    lw6ker_game_state_get_rounds (game_state),
 			    lw6ker_game_state_get_nb_active_fighters
 			    (game_state));
@@ -379,14 +376,17 @@ lw6ker_game_state_add_cursor (lw6ker_game_state_t * game_state,
 	      if ((rules->color_conflict_mode == 1
 		   &&
 		   !_lw6ker_cursor_array_is_color_owned_by (&
-							    (game_state->map_state.cursor_array),
+							    (game_state->
+							     map_state.
+							     cursor_array),
 							    server_id,
 							    team_color))
 		  || rules->color_conflict_mode == 2)
 		{
 		  real_team_color =
 		    lw6ker_map_state_get_free_team_color (&
-							  (game_state->map_state));
+							  (game_state->
+							   map_state));
 		}
 	    }
 
@@ -413,9 +413,9 @@ lw6ker_game_state_add_cursor (lw6ker_game_state_t * game_state,
 		    {
 		      ret =
 			lw6ker_cursor_array_enable (&
-						    (game_state->
-						     map_state.cursor_array),
-						    server_id, cursor_id,
+						    (game_state->map_state.
+						     cursor_array), server_id,
+						    cursor_id,
 						    real_team_color, x, y);
 		    }
 		}
@@ -538,8 +538,8 @@ lw6ker_game_state_set_cursor (lw6ker_game_state_t * game_state,
 
   if (check_server_id (game_state, server_id))
     {
-      lw6map_coords_fix (&(game_state->game_struct->rules),
-			 &(game_state->map_state.shape), &x, &y);
+      lw6map_coords_fix_xy (&(game_state->game_struct->rules),
+			    &(game_state->map_state.shape), &x, &y);
       ret =
 	lw6ker_cursor_array_update (&(game_state->map_state.cursor_array),
 				    server_id, cursor_id, x, y, 0,
@@ -568,7 +568,7 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
   if (!lw6ker_game_state_team_exists (game_state, team_color))
     {
       int32_t nb_fighters;
-      lw6sys_xy_t desired_center;
+      lw6sys_xyz_t desired_center;
       int32_t x;
       int32_t y;
 
@@ -607,10 +607,9 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
 						     i,
 						     (total_fighters_to_remove
 						      *
-						      game_state->map_state.
-						      armies.
-						      fighters_per_team[i]) /
-						     total_fighters);
+						      game_state->
+						      map_state.armies.fighters_per_team
+						      [i]) / total_fighters);
 	    }
 	  /*
 	   * Note that this value has probably changed since we last
@@ -675,8 +674,8 @@ lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
 	  new_average_fighters_per_team =
 	    nb_active_fighters / (nb_active_teams - 1);
 	  single_average_fighters_per_team =
-	    lw6ker_per100_2 (game_state->map_state.
-			     map_struct->room_for_armies,
+	    lw6ker_per100_2 (game_state->map_state.map_struct->
+			     room_for_armies,
 			     game_state->game_struct->rules.single_army_size);
 	  if (new_average_fighters_per_team >
 	      single_average_fighters_per_team)
@@ -707,13 +706,14 @@ lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
 		  lw6ker_map_state_redistribute_team (&
 						      (game_state->map_state),
 						      i, team_color,
-						      (game_state->map_state.
-						       armies.
-						       fighters_per_team[i] *
+						      (game_state->
+						       map_state.armies.fighters_per_team
+						       [i] *
 						       total_fighters_to_distribute)
 						      / new_active_fighters,
-						      &(game_state->
-							game_struct->rules));
+						      &
+						      (game_state->game_struct->
+						       rules));
 		}
 	    }
 	  /*
@@ -725,18 +725,16 @@ lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
 	    {
 	      for (i = 0;
 		   i < LW6MAP_MAX_NB_TEAMS
-		   && game_state->map_state.armies.
-		   fighters_per_team[team_color] > 0; ++i)
+		   && game_state->map_state.
+		   armies.fighters_per_team[team_color] > 0; ++i)
 		{
 		  if (game_state->map_state.teams[i].active)
 		    {
 		      lw6ker_map_state_redistribute_team (&
-							  (game_state->
-							   map_state), i,
-							  team_color, 1,
-							  &(game_state->
-							    game_struct->
-							    rules));
+							  (game_state->map_state),
+							  i, team_color, 1,
+							  &
+							  (game_state->game_struct->rules));
 		    }
 		}
 	    }
@@ -832,8 +830,8 @@ lw6ker_game_state_do_spread (lw6ker_game_state_t *
   // todo: use team_mask
   lw6ker_map_state_spread_gradient (&(game_state->map_state),
 				    &(game_state->game_struct->rules),
-				    game_state->game_struct->rules.
-				    spreads_per_round, team_mask);
+				    game_state->game_struct->
+				    rules.spreads_per_round, team_mask);
 }
 
 void
@@ -845,8 +843,8 @@ lw6ker_game_state_do_move (lw6ker_game_state_t *
 				  lw6sys_checksum_int32 (game_state->rounds) %
 				  LW6KER_NB_PARITIES,
 				  &(game_state->game_struct->rules),
-				  game_state->game_struct->rules.
-				  moves_per_round, team_mask);
+				  game_state->game_struct->
+				  rules.moves_per_round, team_mask);
 }
 
 void
