@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 extern int32_t _LW6KER_TABLES_MOVE_X_OFFSET[LW6KER_NB_DIRS];
 extern int32_t _LW6KER_TABLES_MOVE_Y_OFFSET[LW6KER_NB_DIRS];
+extern int32_t _LW6KER_TABLES_MOVE_Z_OFFSET[LW6KER_NB_DIRS];
 extern int32_t
   _LW6KER_TABLES_MOVE_DIR[LW6KER_NB_PARITIES][LW6KER_NB_DIRS]
   [LW6MAP_MAX_NB_DIR_TRIES];
@@ -59,7 +60,7 @@ extern int _lw6ker_cursor_check_server_id (lw6ker_cursor_t * cursor,
 					   u_int64_t server_id);
 extern int _lw6ker_cursor_get_start_xy (int32_t * x, int32_t * y,
 					int team_color,
-					lw6sys_wh_t * shape,
+					lw6sys_whd_t * shape,
 					lw6map_rules_t * rules);
 extern void _lw6ker_cursor_update_apply_pos (lw6ker_cursor_t * cursor,
 					     lw6ker_map_struct_t *
@@ -89,21 +90,20 @@ extern void _lw6ker_fighter_update_checksum (lw6ker_fighter_t * fighter,
 extern void _lw6ker_fighter_print_debug (lw6ker_fighter_t * fighter);
 extern void _lw6ker_fighter_move (lw6ker_fighter_t * fighter,
 				  int32_t fighter_id,
-				  int32_t layer, int32_t x,
-				  int32_t y, lw6ker_map_state_t * map_state);
+				  int32_t x,
+				  int32_t y, int32_t z,
+				  lw6ker_map_state_t * map_state);
 extern void _lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
-				    int32_t fighter_id,
-				    int32_t layer, int32_t x,
-				    int32_t y,
-				    lw6ker_map_state_t * map_state,
+				    int32_t x, int32_t y,
+				    int32_t z, lw6ker_map_state_t * map_state,
 				    int32_t fighter_attack,
 				    int32_t fighter_new_health);
 extern void _lw6ker_fighter_defend (lw6ker_fighter_t * fighter,
-				    int32_t fighter_id,
-				    int32_t layer, int32_t x,
-				    int32_t y,
-				    lw6ker_map_state_t * map_state,
+				    int32_t x, int32_t y,
+				    int32_t z, lw6ker_map_state_t * map_state,
 				    int32_t fighter_defense);
+extern void _lw6ker_fighter_regenerate (lw6ker_fighter_t * fighter,
+					int32_t fighter_regenerate);
 
 /*
  * In gamestate.c
@@ -119,27 +119,6 @@ extern void _lw6ker_game_struct_update_checksum (lw6ker_game_struct_t *
 						 game_struct,
 						 u_int32_t * checksum);
 
-/*
- * In layer.c
- */
-extern int _lw6ker_layer_init (lw6ker_layer_t * layer,
-			       lw6ker_map_struct_t * map_struct,
-			       lw6ker_armies_t * armies,
-			       lw6map_rules_t * options);
-extern void _lw6ker_layer_clear (lw6ker_layer_t * layer);
-extern int _lw6ker_layer_sync (lw6ker_layer_t * dst, lw6ker_layer_t * src);
-extern void _lw6ker_layer_update_checksum (lw6ker_layer_t * layer,
-					   u_int32_t * checksum);
-
-/*
- * In map.c
- */
-extern int _lw6ker_map_depth_rectangle (lw6map_depth_t * depth, int width,
-					int height);
-extern int _lw6ker_map_metadata_rectangle (lw6map_metadata_t * metadata,
-					   int width, int height);
-
-
 /*
  * in mapstate.c
  */
@@ -154,18 +133,15 @@ extern void _lw6ker_map_state_update_checksum (lw6ker_map_state_t * map_state,
 					       u_int32_t * checksum);
 extern int _lw6ker_map_state_is_slot_free (lw6ker_map_state_t *
 					   map_state,
-					   int32_t layer,
-					   int32_t x, int32_t y);
+					   int32_t x, int32_t y, int32_t z);
 extern int _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t *
 					     map_state,
 					     int32_t team_color,
-					     int32_t layer,
-					     int32_t x, int32_t y);
+					     int32_t x, int32_t y, int32_t z);
 extern int _lw6ker_map_state_is_ally_there (lw6ker_map_state_t *
 					    map_state,
 					    int32_t team_color,
-					    int32_t layer,
-					    int32_t x, int32_t y);
+					    int32_t x, int32_t y, int32_t z);
 extern int _lw6ker_map_state_get_nb_teams (lw6ker_map_state_t * map_state);
 
 /*
