@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,38 +37,47 @@ _lw6ker_map_state_init (lw6ker_map_state_t * map_state,
 {
   int ret = 0;
   int32_t i;
-  int progress_i = 0;
-  int progress_n = 0;
 
   lw6sys_progress_begin (progress);
 
-  progress_n = 1 + map_struct->max_depth + rules->max_nb_teams;
-
   map_state->map_struct = map_struct;
   map_state->shape = map_struct->shape;
 
   ret = 1;
 
-  _lw6ker_cursor_array_init (&(map_state->cursor_array));
-
   ret = ret && _lw6ker_armies_init (&(map_state->armies), map_struct, rules);
-  lw6sys_progress_update (progress, 0, progress_n, progress_i++);
 
-  map_state->nb_layers = map_struct->max_depth;
-  for (i = 0; i < map_state->nb_layers; ++i)
-    {
-      ret = ret
-	&& _lw6ker_layer_init (&(map_state->layers[i]), map_state->map_struct,
-			       &(map_state->armies), rules);
-      lw6sys_progress_update (progress, 0, progress_n, progress_i++);
-    }
+  lw6sys_progress_update (progress, 0, 3, 1);
 
   map_state->max_nb_teams = rules->max_nb_teams;
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
       ret = ret
 	&& _lw6ker_team_init (&(map_state->teams[i]), map_struct, rules);
-      lw6sys_progress_update (progress, 0, progress_n, progress_i++);
+    }
+
+  _lw6ker_cursor_array_init (&(map_state->cursor_array));
+
+  lw6sys_progress_update (progress, 0, 3, 2);
+
+  map_state->nb_slots =
+    map_struct->shape.w * map_struct->shape.h * map_struct->shape.d;
+  map_state->slots =
+    (lw6ker_slot_state_t *) LW6SYS_CALLOC (map_state->nb_slots *
+					   sizeof (lw6ker_slot_state_t));
+  if (map_state->slots)
+    {
+      for (i = 0; i < map_state->nb_slots; ++i)
+	{
+	  map_state->slots[i].fighter_id = -1;
+	}
+    }
+  else
+    {
+      ret = 0;
+
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to allocate SLOT_STATE array"));
     }
 
   lw6sys_progress_end (progress);
@@ -81,22 +90,16 @@ _lw6ker_map_state_clear (lw6ker_map_state_t * map_state)
 {
   int32_t i;
 
+  if (map_state->slots)
+    {
+      LW6SYS_FREE (map_state->slots);
+    }
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
       _lw6ker_team_clear (&(map_state->teams[i]));
     }
-
-  for (i = 0; i < map_state->nb_layers; ++i)
-    {
-      _lw6ker_layer_clear (&(map_state->layers[i]));
-    }
-  map_state->nb_layers = 0;
-
   _lw6ker_armies_clear (&(map_state->armies));
-
-  map_state->shape.w = 0;
-  map_state->shape.h = 0;
-  map_state->map_struct = NULL;
+  memset (map_state, 0, sizeof (lw6ker_map_state_t));
 }
 
 int
@@ -116,14 +119,11 @@ _lw6ker_map_state_sync (lw6ker_map_state_t * dst, lw6ker_map_state_t * src)
 	{
 	  ret = ret && _lw6ker_team_sync (&(dst->teams[i]), &(src->teams[i]));
 	}
-      dst->nb_layers = src->nb_layers;
-      for (i = 0; i < src->nb_layers; ++i)
-	{
-	  ret = ret
-	    && _lw6ker_layer_sync (&(dst->layers[i]), &(src->layers[i]));
-	}
       memcpy (&(dst->cursor_array), &(src->cursor_array),
 	      sizeof (lw6ker_cursor_array_t));
+      dst->nb_slots = src->nb_slots;
+      memcpy (dst->slots, src->slots,
+	      src->map_struct->nb_slots * sizeof (lw6ker_slot_state_t));
     }
   else
     {
@@ -145,18 +145,19 @@ _lw6ker_map_state_update_checksum (lw6ker_map_state_t * map_state,
    * within game_state_update_checksum which itself calls 
    * game_struct_update_checksum.
    */
+  lw6sys_checksum_update_whd (checksum, &(map_state->shape));
   _lw6ker_armies_update_checksum (&(map_state->armies), checksum);
   lw6sys_checksum_update_int32 (checksum, map_state->max_nb_teams);
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
       _lw6ker_team_update_checksum (&(map_state->teams[i]), checksum);
     }
-  lw6sys_checksum_update_int32 (checksum, map_state->nb_layers);
-  for (i = 0; i < map_state->nb_layers; ++i)
-    {
-      _lw6ker_layer_update_checksum (&(map_state->layers[i]), checksum);
-    }
   _lw6ker_cursor_array_update_checksum (&(map_state->cursor_array), checksum);
+  lw6sys_checksum_update_int32 (checksum, map_state->nb_slots);
+  for (i = 0; i < map_state->nb_slots; ++i)
+    {
+      _lw6ker_slot_state_update_checksum (&(map_state->slots[i]), checksum);
+    }
 }
 
 int
@@ -180,19 +181,17 @@ int32_t
 lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
 				int32_t team_color,
 				int32_t nb_fighters,
-				lw6sys_xy_t desired_center,
+				lw6sys_xyz_t desired_center,
 				lw6map_rules_t * rules)
 {
-  lw6sys_xy_t real_center;
+  lw6sys_xyz_t real_center;
   int32_t angle, radius;
   int32_t max_radius, max_angle;
-  int32_t x, y;
-  int32_t depth;
+  int32_t x, y, z;
   int32_t nb_fighters_added = 0;
-  int32_t layer;
   int32_t new_fighter_id;
   lw6ker_fighter_t new_fighter;
-  lw6sys_wh_t shape;
+  lw6sys_whd_t shape;
 
   shape = map_state->shape;
   _lw6ker_fighter_clear (&new_fighter);
@@ -215,29 +214,32 @@ lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
 	    (lw6ker_sin ((angle * LW6KER_TRIGO_2PI) / max_angle) * radius) /
 	    (LW6KER_TRIGO_RADIUS * 2);
 
-	  lw6map_coords_fix (rules, &shape, &x, &y);
+	  lw6map_coords_fix_xy (rules, &shape, &x, &y);
 
-	  depth = lw6ker_map_struct_get_depth (map_state->map_struct, x, y);
-	  for (layer = 0; layer < map_state->nb_layers && layer < depth;
-	       ++layer)
+	  for (z = 0; z < map_state->shape.d; ++z)
 	    {
-	      if (lw6ker_map_state_get_fighter_id (map_state, layer, x, y)
-		  < 0)
+	      if (lw6ker_map_struct_get_zone_id
+		  (map_state->map_struct, x, y, z) >= 0)
 		{
-		  new_fighter.team_color = team_color;
-		  new_fighter.layer = layer;
-		  new_fighter.pos.x = x;
-		  new_fighter.pos.y = y;
-		  new_fighter.health = LW6MAP_MAX_FIGHTER_HEALTH;
-		  new_fighter.last_direction = 0;
-		  new_fighter_id =
-		    lw6ker_armies_add_fighter (&(map_state->armies),
-					       new_fighter);
-		  if (new_fighter_id >= 0)
+		  if (lw6ker_map_state_get_fighter_id (map_state, x, y, z)
+		      < 0)
 		    {
-		      nb_fighters_added++;
-		      lw6ker_map_state_set_fighter_id (map_state, layer,
-						       x, y, new_fighter_id);
+		      new_fighter.team_color = team_color;
+		      new_fighter.pos.x = x;
+		      new_fighter.pos.y = y;
+		      new_fighter.pos.z = z;
+		      new_fighter.health = LW6MAP_MAX_FIGHTER_HEALTH;
+		      new_fighter.last_direction = 0;
+		      new_fighter_id =
+			lw6ker_armies_add_fighter (&(map_state->armies),
+						   new_fighter);
+		      if (new_fighter_id >= 0)
+			{
+			  nb_fighters_added++;
+			  lw6ker_map_state_set_fighter_id (map_state,
+							   x, y, z,
+							   new_fighter_id);
+			}
 		    }
 		}
 	    }
@@ -349,9 +351,10 @@ lw6ker_map_state_remove_fighter (lw6ker_map_state_t * map_state,
 
       if (fighter_id < last_fighter_id)
 	{
-	  lw6ker_map_state_set_fighter_id (map_state, last_fighter.layer,
+	  lw6ker_map_state_set_fighter_id (map_state,
 					   last_fighter.pos.x,
-					   last_fighter.pos.y, fighter_id);
+					   last_fighter.pos.y,
+					   last_fighter.pos.z, fighter_id);
 	  /*
 	   * It's important to really *exchange* the fighters, for
 	   * deletion in the armies struct will read the last fighter's
@@ -363,8 +366,9 @@ lw6ker_map_state_remove_fighter (lw6ker_map_state_t * map_state,
 	  map_state->armies.fighters[last_fighter_id] = fighter;
 	}
 
-      lw6ker_map_state_set_fighter_id (map_state, fighter.layer,
-				       fighter.pos.x, fighter.pos.y, -1);
+      lw6ker_map_state_set_fighter_id (map_state,
+				       fighter.pos.x, fighter.pos.y,
+				       fighter.pos.z, -1);
       lw6ker_armies_remove_fighter (&(map_state->armies));
 
       ret = 1;
@@ -460,16 +464,18 @@ lw6ker_map_state_remove_team_fighters (lw6ker_map_state_t * map_state,
 
 lw6ker_fighter_t *
 lw6ker_map_state_get_fighter_safe (lw6ker_map_state_t * map_state,
-				   int32_t layer, int32_t x, int32_t y)
+				   int32_t x, int32_t y, int32_t z)
 {
   lw6ker_fighter_t *ret = NULL;
   int fighter_id;
 
-  if (layer >= 0 && layer < map_state->nb_layers && x >= 0
-      && x <= map_state->shape.w && y >= 0 && y < map_state->shape.h)
+  if (x >= 0
+      && x <= map_state->shape.w && y >= 0 && y < map_state->shape.h && z >= 0
+      && z < map_state->shape.d)
     {
       fighter_id =
-	map_state->layers[layer].slots[map_state->shape.w * y + x].fighter_id;
+	map_state->slots[lw6ker_map_state_slot_index (map_state, x, y, z)].
+	fighter_id;
       if (fighter_id >= 0)
 	{
 	  ret = &(map_state->armies.fighters[fighter_id]);
@@ -535,14 +541,15 @@ lw6ker_map_state_sanity_check (lw6ker_map_state_t * map_state)
 	}
       (real_fighters_per_team[fighter.team_color])++;
       fighter_id =
-	lw6ker_map_state_get_fighter_id (map_state, fighter.layer,
-					 fighter.pos.x, fighter.pos.y);
+	lw6ker_map_state_get_fighter_id (map_state,
+					 fighter.pos.x, fighter.pos.y,
+					 fighter.pos.z);
       if (i != fighter_id)
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("fighter %d in armies array pretends to be at layer=%d,x=%d,y=%d, but in fact there is fighter %d there from slots point of view"),
-		      i, fighter.layer, fighter.pos.x, fighter.pos.y,
+		      i, fighter.pos.x, fighter.pos.y, fighter.pos.z,
 		      fighter_id);
 	  ret = 0;
 	}
@@ -591,7 +598,8 @@ lw6ker_map_state_spread_gradient (lw6ker_map_state_t * map_state,
 	    {
 	      for (j = 0; j < nb_spreads; ++j)
 		{
-		  lw6ker_team_spread_gradient (&(map_state->teams[i]));
+		  lw6ker_team_spread_gradient (&(map_state->teams[i]),
+					       map_state->shape.d == 1);
 		}
 	    }
 	}
@@ -600,24 +608,24 @@ lw6ker_map_state_spread_gradient (lw6ker_map_state_t * map_state,
 
 int
 _lw6ker_map_state_is_slot_free (lw6ker_map_state_t * map_state,
-				int32_t layer, int32_t x, int32_t y)
+				int32_t x, int32_t y, int32_t z)
 {
-  return (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y) >= 0 &&
-	  lw6ker_map_state_get_fighter_id (map_state, layer, x, y) < 0);
+  return (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y, z) >= 0
+	  && lw6ker_map_state_get_fighter_id (map_state, x, y, z) < 0);
 }
 
 int
 _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
 				  int32_t team_color,
-				  int32_t layer, int32_t x, int32_t y)
+				  int32_t x, int32_t y, int32_t z)
 {
   int ret = 0;
 
-  if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y) >= 0)
+  if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y, z) >= 0)
     {
       int32_t enemy_id;
 
-      enemy_id = lw6ker_map_state_get_fighter_id (map_state, layer, x, y);
+      enemy_id = lw6ker_map_state_get_fighter_id (map_state, x, y, z);
       if (enemy_id >= 0)
 	{
 	  ret =
@@ -631,15 +639,15 @@ _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
 int
 _lw6ker_map_state_is_ally_there (lw6ker_map_state_t * map_state,
 				 int32_t team_color,
-				 int32_t layer, int32_t x, int32_t y)
+				 int32_t x, int32_t y, int32_t z)
 {
   int ret = 0;
 
-  if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y) >= 0)
+  if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y, z) >= 0)
     {
       int32_t ally_id;
 
-      ally_id = lw6ker_map_state_get_fighter_id (map_state, layer, x, y);
+      ally_id = lw6ker_map_state_get_fighter_id (map_state, x, y, z);
       if (ally_id >= 0)
 	{
 	  ret =
@@ -668,24 +676,24 @@ _lw6ker_map_state_get_nb_teams (lw6ker_map_state_t * map_state)
 }
 
 static int32_t
-find_straight_dir (lw6sys_xy_t from, lw6sys_xy_t to, int parity)
+find_straight_dir (int from_x, int from_y, lw6sys_xyz_t to, int parity)
 {
   int32_t ret;
   int32_t straight_dir = 0;
 
-  if (to.y < from.y)
+  if (to.y < from_y)
     {
       straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_UP;
     }
-  if (to.x > from.x)
+  if (to.x > from_x)
     {
       straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_RIGHT;
     }
-  if (to.y > from.y)
+  if (to.y > from_y)
     {
       straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_DOWN;
     }
-  if (to.x < from.x)
+  if (to.x < from_x)
     {
       straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_LEFT;
     }
@@ -705,7 +713,7 @@ find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
   int32_t ret = fighter->last_direction;
   int32_t zone_id =
     lw6ker_map_struct_get_zone_id (map_state->map_struct, fighter->pos.x,
-				   fighter->pos.y);
+				   fighter->pos.y, fighter->pos.z);
   lw6ker_zone_state_t *zone_states =
     map_state->teams[fighter->team_color].gradient;
 
@@ -777,7 +785,7 @@ find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
 	       * closest_cursor_pos.
 	       */
 	      ret =
-		find_straight_dir (fighter->pos,
+		find_straight_dir (fighter->pos.x, fighter->pos.y,
 				   zone_states[zone_id].closest_cursor_pos,
 				   parity);
 	    }
@@ -795,24 +803,27 @@ find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("fighter with incorrect zone_id=%d (pos=%d,%d)"), zone_id,
-		  (int) fighter->pos.x, (int) fighter->pos.y);
+		  _("fighter with incorrect zone_id=%d (pos=%d,%d,%d)"),
+		  zone_id, (int) fighter->pos.x, (int) fighter->pos.y,
+		  (int) fighter->pos.z);
     }
 
   return ret;
 }
 
 static void
-polarity_func (lw6map_rules_t * rules, lw6sys_wh_t * shape, int32_t * x,
-	       int32_t * y, int32_t move_dir)
+polarity_func (lw6map_rules_t * rules, lw6sys_whd_t * shape, int32_t * x,
+	       int32_t * y, int32_t * z, int32_t move_dir)
 {
   (*x) = (*x) + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   (*y) = (*y) + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
+  (*z) = (*z) + _LW6KER_TABLES_MOVE_Z_OFFSET[move_dir];
   /*
    * next line is need to stay within map boundaries,
    * it will also handle polarity information
    */
-  lw6map_coords_fix (rules, shape, x, y);
+  lw6map_coords_fix_xy (rules, shape, x, y);
+  lw6map_coords_fix_z (rules, shape, z);
 }
 
 /*
@@ -832,35 +843,42 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
   lw6ker_armies_t *armies = &(map_state->armies);
   int32_t active_fighters = armies->active_fighters;
   lw6ker_fighter_t *fighter = NULL;
-  int32_t layer, x, y;
+  int32_t x, y, z;
   int32_t best_dir, test_dir;
-  int32_t fighter_team_color, fighter_layer, fighter_x, fighter_y;
+  int32_t fighter_team_color, fighter_x, fighter_y, fighter_z;
   int32_t loop_init, loop_step;
   int done_with_fighter;
   int32_t fighter_attack;
   int32_t fighter_defense;
   int32_t fighter_new_health;
+  int32_t fighter_regenerate;
   int32_t side_attack_factor;
   int32_t side_defense_factor;
   int32_t nb_move_tries;
   int32_t nb_attack_tries;
   int32_t nb_defense_tries;
+  int32_t vertical_move;
   int32_t fighter_side_attack;
   int32_t fighter_side_defense;
-  lw6sys_wh_t shape;
+  lw6sys_whd_t shape;
+  int d;
 
   fighter_attack = rules->fighter_attack;
   fighter_defense = rules->fighter_defense;
   fighter_new_health = rules->fighter_new_health;
+  fighter_regenerate = rules->fighter_regenerate;
   side_attack_factor = rules->side_attack_factor;
   side_defense_factor = rules->side_defense_factor;
   nb_move_tries = rules->nb_move_tries;
   nb_attack_tries = rules->nb_attack_tries;
   nb_defense_tries = rules->nb_defense_tries;
+  vertical_move = rules->vertical_move;
   fighter_side_attack = lw6ker_percent (fighter_attack, side_attack_factor);
   fighter_side_defense =
-    lw6ker_percent (fighter_defense, side_defense_factor);
+    lw6sys_max (fighter_regenerate,
+		lw6ker_percent (fighter_defense, side_defense_factor));
   shape = map_state->shape;
+  d = shape.d;
 
   for (k = 0; k < nb_moves; ++k)
     {
@@ -875,26 +893,54 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
 	    {
 	      fighter_x = fighter->pos.x;
 	      fighter_y = fighter->pos.y;
-	      fighter_layer = fighter->layer;
+	      fighter_z = fighter->pos.z;
 
 	      best_dir = find_best_dir (map_state, fighter, parity);
 	      // we assume best_dir is equal to something valid now
 
-	      layer = fighter_layer;	// not multilayer yet
 	      for (j = 0; j < nb_move_tries; ++j)
 		{
 		  test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
 		  x = fighter_x;
 		  y = fighter_y;
-		  polarity_func (rules, &shape, &x, &y, test_dir);
-		  if (_lw6ker_map_state_is_slot_free
-		      (map_state, fighter_layer, x, y))
+		  z = fighter_z;
+		  polarity_func (rules, &shape, &x, &y, &z, test_dir);
+		  if (_lw6ker_map_state_is_slot_free (map_state, x, y, z))
 		    {
 		      done_with_fighter = 1;
-		      _lw6ker_fighter_move (fighter, i, fighter_layer, x, y,
-					    map_state);
+		      _lw6ker_fighter_move (fighter, i, x, y, z, map_state);
+		      _lw6ker_fighter_regenerate (fighter,
+						  fighter_regenerate);
 		      break;
 		    }
+		  if (d > 1)
+		    {
+		      if (j + 1 == vertical_move)
+			{
+			  z = fighter_z - 1;
+			  lw6map_coords_fix_z (rules, &shape, &z);
+			  if (_lw6ker_map_state_is_slot_free
+			      (map_state, fighter_x, fighter_y, z))
+			    {
+			      _lw6ker_fighter_move (fighter, i, fighter_x,
+						    fighter_y, z, map_state);
+			      _lw6ker_fighter_regenerate (fighter,
+							  fighter_regenerate);
+			      break;
+			    }
+			  z = fighter_z + 1;
+			  lw6map_coords_fix_z (rules, &shape, &z);
+			  if (_lw6ker_map_state_is_slot_free
+			      (map_state, fighter_x, fighter_y, z))
+			    {
+			      _lw6ker_fighter_move (fighter, i, fighter_x,
+						    fighter_y, z, map_state);
+			      _lw6ker_fighter_regenerate (fighter,
+							  fighter_regenerate);
+			      break;
+			    }
+			}
+		    }
 		}
 
 	      if (!done_with_fighter)
@@ -904,15 +950,14 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
 		      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
 		      x = fighter_x;
 		      y = fighter_y;
-		      polarity_func (rules, &shape, &x, &y, test_dir);
+		      polarity_func (rules, &shape, &x, &y, &z, test_dir);
 		      if (_lw6ker_map_state_is_enemy_there
-			  (map_state, fighter_team_color, fighter_layer, x,
-			   y))
+			  (map_state, fighter_team_color, x, y, z))
 			{
 			  done_with_fighter = 1;
-			  _lw6ker_fighter_attack (fighter, i, fighter_layer,
-						  x, y, map_state,
-						  j >
+			  _lw6ker_fighter_attack (fighter,
+						  x, y, z, map_state,
+						  j ==
 						  0 ? fighter_attack :
 						  fighter_side_attack,
 						  fighter_new_health);
@@ -928,21 +973,25 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
 		      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
 		      x = fighter_x;
 		      y = fighter_y;
-		      polarity_func (rules, &shape, &x, &y, test_dir);
+		      z = fighter_z;
+		      polarity_func (rules, &shape, &x, &y, &z, test_dir);
 		      if (_lw6ker_map_state_is_ally_there
-			  (map_state, fighter_team_color, fighter_layer, x,
-			   y))
+			  (map_state, fighter_team_color, x, y, z))
 			{
 			  done_with_fighter = 1;
-			  _lw6ker_fighter_defend (fighter, i, fighter_layer,
-						  x, y, map_state,
-						  j >
+			  _lw6ker_fighter_defend (fighter,
+						  x, y, z, map_state,
+						  j ==
 						  0 ? fighter_defense :
 						  fighter_side_defense);
 			  break;
 			}
 		    }
 		}
+	      if (!done_with_fighter)
+		{
+		  _lw6ker_fighter_regenerate (fighter, fighter_regenerate);
+		}
 	    }
 	}
     }
@@ -953,7 +1002,8 @@ lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
 				lw6map_rules_t * rules, u_int32_t team_mask)
 {
   int32_t i, team_color;
-  int32_t zone_id;
+  int32_t zone_id = -1;
+  int32_t z;
   int32_t max_pot[LW6MAP_MAX_NB_TEAMS];
   int32_t round_delta[LW6MAP_MAX_NB_TEAMS];
 
@@ -981,33 +1031,34 @@ lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
 	    {
 	      {
 		_lw6ker_cursor_update_apply_pos (&
-						 (map_state->
-						  cursor_array.cursors[i]),
+						 (map_state->cursor_array.
+						  cursors[i]),
 						 map_state->map_struct);
-		zone_id =
-		  lw6ker_map_struct_get_zone_id (map_state->map_struct,
-						 map_state->
-						 cursor_array.cursors[i].
-						 apply_pos.x,
-						 map_state->
-						 cursor_array.cursors[i].
-						 apply_pos.y);
+		for (z = 0, zone_id = -1;
+		     z < map_state->shape.d && zone_id < 0; ++z)
+		  {
+		    zone_id =
+		      lw6ker_map_struct_get_zone_id (map_state->map_struct,
+						     map_state->cursor_array.
+						     cursors[i].apply_pos.x,
+						     map_state->cursor_array.
+						     cursors[i].apply_pos.y,
+						     z);
+		  }
 		if (zone_id >= 0)
 		  {
 		    max_pot[team_color] =
 		      lw6sys_max (max_pot[team_color],
-				  map_state->
-				  teams[team_color].gradient[zone_id].
-				  potential);
+				  map_state->teams[team_color].
+				  gradient[zone_id].potential);
 		    round_delta[team_color] =
 		      lw6sys_max (round_delta[team_color],
-				  map_state->teams[team_color].
-				  cursor_ref_pot +
-				  map_state->cursor_array.cursors[i].
-				  pot_offset -
 				  map_state->
-				  teams[team_color].gradient[zone_id].
-				  potential);
+				  teams[team_color].cursor_ref_pot +
+				  map_state->cursor_array.
+				  cursors[i].pot_offset -
+				  map_state->teams[team_color].
+				  gradient[zone_id].potential);
 		    round_delta[team_color] =
 		      lw6sys_min (round_delta[team_color],
 				  rules->max_round_delta);
@@ -1047,44 +1098,35 @@ lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
 	  team_color = map_state->cursor_array.cursors[i].team_color;
 	  if (lw6ker_team_mask_is_concerned (team_color, team_mask))
 	    {
-	      zone_id =
-		lw6ker_map_struct_get_zone_id (map_state->map_struct,
-					       map_state->
-					       cursor_array.cursors[i].
-					       apply_pos.x,
-					       map_state->
-					       cursor_array.cursors[i].
-					       apply_pos.y);
-	      if (zone_id >= 0)
+	      for (z = 0; z < map_state->shape.d; ++z)
 		{
-		  /*
-		   * Beware of multiple cursors, we check again if changing
-		   * the value is needed.
-		   */
-		  if (map_state->teams[team_color].gradient[zone_id].
-		      potential <
-		      map_state->teams[team_color].cursor_ref_pot +
-		      map_state->cursor_array.cursors[i].pot_offset)
+		  zone_id =
+		    lw6ker_map_struct_get_zone_id (map_state->map_struct,
+						   map_state->cursor_array.
+						   cursors[i].apply_pos.x,
+						   map_state->cursor_array.
+						   cursors[i].apply_pos.y, z);
+		  if (zone_id >= 0)
 		    {
-		      map_state->teams[team_color].gradient[zone_id].
-			potential =
-			map_state->teams[team_color].cursor_ref_pot +
-			map_state->cursor_array.cursors[i].pot_offset;
-		      map_state->teams[team_color].gradient[zone_id].
-			closest_cursor_pos =
-			map_state->cursor_array.cursors[i].apply_pos;
+		      /*
+		       * Beware of multiple cursors, we check again if changing
+		       * the value is needed.
+		       */
+		      if (map_state->teams[team_color].
+			  gradient[zone_id].potential <
+			  map_state->teams[team_color].cursor_ref_pot +
+			  map_state->cursor_array.cursors[i].pot_offset)
+			{
+			  map_state->teams[team_color].
+			    gradient[zone_id].potential =
+			    map_state->teams[team_color].cursor_ref_pot +
+			    map_state->cursor_array.cursors[i].pot_offset;
+			  map_state->teams[team_color].
+			    gradient[zone_id].closest_cursor_pos =
+			    map_state->cursor_array.cursors[i].apply_pos;
+			}
 		    }
 		}
-	      else
-		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _
-			      ("unable to apply cursor, neither pos (%d,%d) nor apply_pos (%d,%d) seem to point on a valid zone"),
-			      map_state->cursor_array.cursors[i].pos.x,
-			      map_state->cursor_array.cursors[i].pos.y,
-			      map_state->cursor_array.cursors[i].apply_pos.x,
-			      map_state->cursor_array.cursors[i].apply_pos.y);
-		}
 	    }
 	}
     }
