@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
  */
 typedef struct draft_zone_s
 {
-  lw6sys_xy_t pos;
+  lw6sys_xyz_t pos;
   int32_t used;
   int32_t size;
   int32_t link[LW6KER_NB_DIRS];
@@ -54,7 +54,7 @@ draft_zone_t;
 
 typedef struct draft_zones_s
 {
-  lw6sys_wh_t shape;
+  lw6sys_whd_t shape;
   int32_t max_zone_size;
   draft_zone_t *zones;
 }
@@ -66,12 +66,11 @@ _lw6ker_map_struct_update_checksum (lw6ker_map_struct_t *
 {
   int i;
 
-  lw6sys_checksum_update_wh (checksum, &(map_struct->shape));
+  lw6sys_checksum_update_whd (checksum, &(map_struct->shape));
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_zones);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_slots);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_usable_slots);
   lw6sys_checksum_update_int32 (checksum, map_struct->room_for_armies);
-  lw6sys_checksum_update_int32 (checksum, map_struct->max_depth);
   lw6sys_checksum_update_int32 (checksum, map_struct->max_zone_size);
   for (i = 0; i < map_struct->nb_zones; ++i)
     {
@@ -100,12 +99,12 @@ _lw6ker_map_struct_lazy_compare (lw6ker_map_struct_t *
 	{
 	  ret = (map_struct_a->shape.w == map_struct_b->shape.w) &&
 	    (map_struct_a->shape.h == map_struct_b->shape.h) &&
+	    (map_struct_a->shape.d == map_struct_b->shape.d) &&
 	    (map_struct_a->nb_zones == map_struct_b->nb_zones) &&
 	    (map_struct_a->nb_slots == map_struct_b->nb_slots) &&
 	    (map_struct_a->nb_usable_slots == map_struct_b->nb_usable_slots)
 	    && (map_struct_a->room_for_armies ==
 		map_struct_b->room_for_armies)
-	    && (map_struct_a->max_depth == map_struct_b->max_depth)
 	    && (map_struct_a->max_zone_size == map_struct_b->max_zone_size);
 	}
     }
@@ -119,11 +118,20 @@ _lw6ker_map_struct_lazy_compare (lw6ker_map_struct_t *
 }
 
 static int32_t
-relative_index (lw6map_level_t * level, int32_t x, int32_t y)
+relative_index_no_check (lw6map_level_t * level, int32_t x, int32_t y,
+			 int32_t z)
 {
-  lw6map_coords_fix (&(level->param.rules), &(level->depth.shape), &x, &y);
+  return z * level->body.shape.w * level->body.shape.h +
+    y * level->body.shape.w + x;
+}
 
-  return y * level->depth.shape.w + x;
+static int32_t
+relative_index (lw6map_level_t * level, int32_t x, int32_t y, int32_t z)
+{
+  lw6map_coords_fix_xy (&(level->param.rules), &(level->body.shape), &x, &y);
+  lw6map_coords_fix_z (&(level->param.rules), &(level->body.shape), &z);
+
+  return relative_index_no_check (level, x, y, z);
 }
 
 /*
@@ -144,14 +152,15 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
   ret = (draft_zones_t *) LW6SYS_CALLOC (sizeof (draft_zones_t));
   if (ret)
     {
-      int32_t w, h, size;
+      int32_t w, h, d, size;
 
-      ret->shape = level->depth.shape;
+      ret->shape = level->body.shape;
       ret->max_zone_size = 1;
 
       w = ret->shape.w;
       h = ret->shape.h;
-      size = w * h;
+      d = ret->shape.d;
+      size = w * h * d;
 
       if (size >= LW6MAP_MIN_SURFACE)
 	{
@@ -160,7 +169,7 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 
 	  if (ret->zones)
 	    {
-	      int32_t i, j, x, y;
+	      int32_t i, j, x, y, z;
 
 	      for (i = 0; i < size; ++i)
 		{
@@ -171,70 +180,87 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 		    }
 		}
 
-	      for (y = 0; y < h; ++y)
+	      for (z = 0; z < d; ++z)
 		{
-		  for (x = 0; x < w; ++x)
+		  for (y = 0; y < h; ++y)
 		    {
-		      i = y * w + x;
+		      for (x = 0; x < w; ++x)
+			{
+			  i = relative_index_no_check (level, x, y, z);
 
-		      ret->zones[i].pos.x = x;
-		      ret->zones[i].pos.y = y;
-		      ret->zones[i].used =
-			lw6map_depth_get (&(level->depth), x, y) ? 1 : 0;
+			  ret->zones[i].pos.x = x;
+			  ret->zones[i].pos.y = y;
+			  ret->zones[i].pos.z = z;
+			  ret->zones[i].used =
+			    lw6map_body_get (&(level->body), x, y,
+					     z) > 0 ? 1 : 0;
+			}
 		    }
 		}
 
-	      for (y = 0; y < h; ++y)
+	      for (z = 0; z < d; ++z)
 		{
-		  for (x = 0; x < w; ++x)
+		  for (y = 0; y < h; ++y)
 		    {
-		      i = relative_index (level, x, y);
-
-		      if (ret->zones[i].used)
+		      for (x = 0; x < w; ++x)
 			{
-			  j = relative_index (level, x, y - 1);
-			  if (ret->zones[j].used && i != j)
+			  i = relative_index (level, x, y, z);
+			  if (ret->zones[i].used)
 			    {
-			      ret->zones[i].link[LW6KER_DIR_NNW] =
-				ret->zones[i].link[LW6KER_DIR_NNE] = j;
-			    }
-			  j = relative_index (level, x + 1, y - 1);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_NE] = j;
-			    }
-			  j = relative_index (level, x + 1, y);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_ENE] =
-				ret->zones[i].link[LW6KER_DIR_ESE] = j;
-			    }
-			  j = relative_index (level, x + 1, y + 1);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_SE] = j;
-			    }
-			  j = relative_index (level, x, y + 1);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_SSE] =
-				ret->zones[i].link[LW6KER_DIR_SSW] = j;
-			    }
-			  j = relative_index (level, x - 1, y + 1);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_SW] = j;
-			    }
-			  j = relative_index (level, x - 1, y);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_WSW] =
-				ret->zones[i].link[LW6KER_DIR_WNW] = j;
-			    }
-			  j = relative_index (level, x - 1, y - 1);
-			  if (ret->zones[j].used && i != j)
-			    {
-			      ret->zones[i].link[LW6KER_DIR_NW] = j;
+			      j = relative_index (level, x, y - 1, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_NNW] =
+				    ret->zones[i].link[LW6KER_DIR_NNE] = j;
+				}
+			      j = relative_index (level, x + 1, y - 1, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_NE] = j;
+				}
+			      j = relative_index (level, x + 1, y, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_ENE] =
+				    ret->zones[i].link[LW6KER_DIR_ESE] = j;
+				}
+			      j = relative_index (level, x + 1, y + 1, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_SE] = j;
+				}
+			      j = relative_index (level, x, y + 1, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_SSE] =
+				    ret->zones[i].link[LW6KER_DIR_SSW] = j;
+				}
+			      j = relative_index (level, x - 1, y + 1, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_SW] = j;
+				}
+			      j = relative_index (level, x - 1, y, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_WSW] =
+				    ret->zones[i].link[LW6KER_DIR_WNW] = j;
+				}
+			      j = relative_index (level, x - 1, y - 1, z);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_NW] = j;
+				}
+			      j = relative_index (level, x, y, z - 1);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_UP] = j;
+				}
+			      j = relative_index (level, x, y, z + 1);
+			      if (ret->zones[j].used && i != j)
+				{
+				  ret->zones[i].link[LW6KER_DIR_DOWN] = j;
+				}
 			    }
 			}
 		    }
@@ -252,6 +278,7 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 		      _("map is too small, size=%d, LW6MAP_MIN_SURFACE=%d"),
 		      size, LW6MAP_MIN_SURFACE);
 	}
+
     }
 
   lw6sys_progress_end (progress);
@@ -281,115 +308,230 @@ draft_zones_free (draft_zones_t * draft_zones)
  * we suppress.
  */
 static int32_t
-draft_zones_group (draft_zones_t * draft_zones, int32_t step)
+draft_zones_group (lw6map_level_t * level, draft_zones_t * draft_zones,
+		   int32_t step)
 {
   int32_t found = 0;
-  int32_t x, y, w, h, size, i, j, k;
-  int32_t i_ne, i_se, i_sw, i_nw;
-  draft_zone_t *zone_ne, *zone_se, *zone_sw, *zone_nw;
+  int32_t x, y, z, w, h, d, size, i, j, k;
+  int32_t i_ne, i_se, i_sw, i_nw, i_up, i_down;
+  draft_zone_t *zone_ne, *zone_se, *zone_sw, *zone_nw, *zone_up, *zone_down;
   int32_t *test;
 
   w = draft_zones->shape.w;
   h = draft_zones->shape.h;
-  size = h * w;
+  d = draft_zones->shape.d;
+  size = d * h * w;
 
-  for (y = 0; y < h - step; y += step * 2)
+  for (z = 0; z < d; z++)
     {
-      for (x = 0; x < w - step; x += step * 2)
+      for (y = 0; y < h - step; y += step * 2)
 	{
-	  i = y * w + x;
-	  i_ne = i + step;
-	  i_se = i + (w + 1) * step;
-	  i_sw = i + w * step;
-	  i_nw = i;
-	  zone_ne = &draft_zones->zones[i_ne];
-	  zone_se = &draft_zones->zones[i_se];
-	  zone_sw = &draft_zones->zones[i_sw];
-	  zone_nw = &draft_zones->zones[i_nw];
-
-	  /*
-	   * This test contains all the criteria which make
-	   * us decide wether we group the squares are not.
-	   * It's a wise choice to be rather restrictive.
-	   * For instance the fact tha NE SW NW NE links
-	   * actually point to something might seem useless.
-	   * It's not, the main reason is that it's a rather
-	   * good choice that whenever there's an obstacle,
-	   * the zones around it are forced to small.
-	   */
-	  if (zone_ne->used && zone_ne->size == step
-	      && zone_se->used && zone_se->size == step
-	      && zone_sw->used && zone_sw->size == step
-	      && zone_nw->used && zone_nw->size == step
-	      && zone_ne->link[LW6KER_DIR_NNW] ==
-	      zone_ne->link[LW6KER_DIR_NNE]
-	      && zone_ne->link[LW6KER_DIR_ENE] ==
-	      zone_ne->link[LW6KER_DIR_ESE]
-	      && zone_se->link[LW6KER_DIR_ENE] ==
-	      zone_se->link[LW6KER_DIR_ESE]
-	      && zone_se->link[LW6KER_DIR_SSE] ==
-	      zone_se->link[LW6KER_DIR_SSW]
-	      && zone_sw->link[LW6KER_DIR_SSE] ==
-	      zone_sw->link[LW6KER_DIR_SSW]
-	      && zone_sw->link[LW6KER_DIR_WSW] ==
-	      zone_sw->link[LW6KER_DIR_WNW]
-	      && zone_nw->link[LW6KER_DIR_WSW] ==
-	      zone_nw->link[LW6KER_DIR_WNW]
-	      && zone_nw->link[LW6KER_DIR_NNW] ==
-	      zone_nw->link[LW6KER_DIR_NNE]
-	      && zone_ne->link[LW6KER_DIR_NE] >= 0
-	      && zone_se->link[LW6KER_DIR_SE] >= 0
-	      && zone_sw->link[LW6KER_DIR_SW] >= 0
-	      && zone_nw->link[LW6KER_DIR_NW] >= 0)
+	  for (x = 0; x < w - step; x += step * 2)
 	    {
-	      /*
-	       * Delete unused zones
-	       */
-	      zone_ne->used = 0;
-	      zone_se->used = 0;
-	      zone_sw->used = 0;
-
-	      /*
-	       * Double the zone size of the remaining zone
-	       */
-	      zone_nw->size = step * 2;
-
-	      /*
-	       * Change the links of the remaining zone
-	       */
-	      zone_nw->link[LW6KER_DIR_NNE] = zone_ne->link[LW6KER_DIR_NNE];
-	      zone_nw->link[LW6KER_DIR_NE] = zone_ne->link[LW6KER_DIR_NE];
-	      zone_nw->link[LW6KER_DIR_ENE] = zone_ne->link[LW6KER_DIR_ENE];
-	      zone_nw->link[LW6KER_DIR_ESE] = zone_se->link[LW6KER_DIR_ESE];
-	      zone_nw->link[LW6KER_DIR_SE] = zone_se->link[LW6KER_DIR_SE];
-	      zone_nw->link[LW6KER_DIR_SSE] = zone_se->link[LW6KER_DIR_SSE];
-	      zone_nw->link[LW6KER_DIR_SSW] = zone_sw->link[LW6KER_DIR_SSW];
-	      zone_nw->link[LW6KER_DIR_SW] = zone_sw->link[LW6KER_DIR_SW];
-	      zone_nw->link[LW6KER_DIR_WSW] = zone_sw->link[LW6KER_DIR_WSW];
-
-	      /*
-	       * Change all the links of the adjacent zones,
-	       * which were pointing on the deleted zones,
-	       * and must now point on the remaining one.
-	       */
-	      for (j = 0; j < LW6KER_NB_DIRS; ++j)
+	      i = z * w * h + y * w + x;
+	      if (draft_zones->zones[i].used)
 		{
-		  for (k = 0; k < LW6KER_NB_DIRS; ++k)
+		  i_ne = i + step;
+		  i_se = i + (w + 1) * step;
+		  i_sw = i + w * step;
+		  i_nw = i;
+		  zone_ne = &draft_zones->zones[i_ne];
+		  zone_se = &draft_zones->zones[i_se];
+		  zone_sw = &draft_zones->zones[i_sw];
+		  zone_nw = &draft_zones->zones[i_nw];
+
+		  i_up = i - w * h;	// may be out of bounds
+		  if (i_up >= 0 && i_up < size)
 		    {
-		      if (zone_nw->link[j] >= 0)
+		      zone_up = &draft_zones->zones[i_up];
+		    }
+		  else
+		    {
+		      zone_up = NULL;
+		    }
+		  i_down = i + w * h;	// may be out of bounds
+		  if (i_down >= 0 && i_down < size)
+		    {
+		      zone_down = &draft_zones->zones[i_down];
+		    }
+		  else
+		    {
+		      zone_down = NULL;
+		    }
+
+		  /*
+		   * This test contains all the criteria which make
+		   * us decide wether we group the squares are not.
+		   * It's a wise choice to be rather restrictive.
+		   * For instance the fact tha NE SW NW NE links
+		   * actually point to something might seem useless.
+		   * It's not, the main reason is that it's a rather
+		   * good choice that whenever there's an obstacle,
+		   * the zones around it are forced to be small.
+		   */
+		  if (zone_ne->used && zone_ne->size == step
+		      && zone_se->used && zone_se->size == step
+		      && zone_sw->used && zone_sw->size == step
+		      && zone_nw->used && zone_nw->size == step
+		      && zone_ne->link[LW6KER_DIR_NNW] ==
+		      zone_ne->link[LW6KER_DIR_NNE]
+		      && zone_ne->link[LW6KER_DIR_ENE] ==
+		      zone_ne->link[LW6KER_DIR_ESE]
+		      && zone_se->link[LW6KER_DIR_ENE] ==
+		      zone_se->link[LW6KER_DIR_ESE]
+		      && zone_se->link[LW6KER_DIR_SSE] ==
+		      zone_se->link[LW6KER_DIR_SSW]
+		      && zone_sw->link[LW6KER_DIR_SSE] ==
+		      zone_sw->link[LW6KER_DIR_SSW]
+		      && zone_sw->link[LW6KER_DIR_WSW] ==
+		      zone_sw->link[LW6KER_DIR_WNW]
+		      && zone_nw->link[LW6KER_DIR_WSW] ==
+		      zone_nw->link[LW6KER_DIR_WNW]
+		      && zone_nw->link[LW6KER_DIR_NNW] ==
+		      zone_nw->link[LW6KER_DIR_NNE]
+		      && zone_ne->link[LW6KER_DIR_NE] >= 0
+		      && zone_se->link[LW6KER_DIR_SE] >= 0
+		      && zone_sw->link[LW6KER_DIR_SW] >= 0
+		      && zone_nw->link[LW6KER_DIR_NW] >= 0
+		      && ((!zone_up) || (zone_up && zone_up->size >= step))
+		      && ((!zone_down)
+			  || (zone_down && zone_down->size >= step)))
+		    {
+		      /*
+		       * Delete unused zones
+		       */
+		      zone_ne->used = 0;
+		      zone_se->used = 0;
+		      zone_sw->used = 0;
+
+		      /*
+		       * Double the zone size of the remaining zone
+		       */
+		      zone_nw->size = step * 2;
+
+		      /*
+		       * Change the links of the remaining zone
+		       */
+		      zone_nw->link[LW6KER_DIR_NNE] =
+			zone_ne->link[LW6KER_DIR_NNE];
+		      zone_nw->link[LW6KER_DIR_NE] =
+			zone_ne->link[LW6KER_DIR_NE];
+		      zone_nw->link[LW6KER_DIR_ENE] =
+			zone_ne->link[LW6KER_DIR_ENE];
+		      zone_nw->link[LW6KER_DIR_ESE] =
+			zone_se->link[LW6KER_DIR_ESE];
+		      zone_nw->link[LW6KER_DIR_SE] =
+			zone_se->link[LW6KER_DIR_SE];
+		      zone_nw->link[LW6KER_DIR_SSE] =
+			zone_se->link[LW6KER_DIR_SSE];
+		      zone_nw->link[LW6KER_DIR_SSW] =
+			zone_sw->link[LW6KER_DIR_SSW];
+		      zone_nw->link[LW6KER_DIR_SW] =
+			zone_sw->link[LW6KER_DIR_SW];
+		      zone_nw->link[LW6KER_DIR_WSW] =
+			zone_sw->link[LW6KER_DIR_WSW];
+
+		      /*
+		       * Change all the links of the adjacent zones,
+		       * which were pointing on the deleted zones,
+		       * and must now point on the remaining one.
+		       */
+		      for (j = 0; j < LW6KER_DIR_UP; ++j)
 			{
-			  test =
-			    &(draft_zones->zones[zone_nw->link[j]].link[k]);
-			  if (*test == i_ne || *test == i_se || *test == i_sw)
+			  for (k = 0; k < LW6KER_DIR_UP; ++k)
 			    {
-			      *test = i_nw;
+			      if (zone_nw->link[j] >= 0)
+				{
+				  test =
+				    &(draft_zones->zones[zone_nw->link[j]].
+				      link[k]);
+				  if (*test == i_ne || *test == i_se
+				      || *test == i_sw)
+				    {
+				      *test = i_nw;
+				    }
+				}
 			    }
 			}
+
+		      /*
+		       * Now treat vertical (cross-layer) zones links
+		       * which were pointing on the deleted zones
+		       */
+		      if (d > 1)
+			{
+			  j =
+			    relative_index (level,
+					    draft_zones->zones[i_ne].pos.x,
+					    draft_zones->zones[i_ne].pos.y,
+					    draft_zones->zones[i_ne].pos.z +
+					    1);
+			  if (draft_zones->zones[j].used)
+			    {
+			      draft_zones->zones[j].link[LW6KER_DIR_UP] =
+				i_nw;
+			    }
+			  j =
+			    relative_index (level,
+					    draft_zones->zones[i_se].pos.x,
+					    draft_zones->zones[i_se].pos.y,
+					    draft_zones->zones[i_se].pos.z +
+					    1);
+			  if (draft_zones->zones[j].used)
+			    {
+			      draft_zones->zones[j].link[LW6KER_DIR_UP] =
+				i_nw;
+			    }
+			  j =
+			    relative_index (level,
+					    draft_zones->zones[i_sw].pos.x,
+					    draft_zones->zones[i_sw].pos.y,
+					    draft_zones->zones[i_sw].pos.z +
+					    1);
+			  if (draft_zones->zones[j].used)
+			    {
+			      draft_zones->zones[j].link[LW6KER_DIR_UP] =
+				i_nw;
+			    }
+			  j =
+			    relative_index (level,
+					    draft_zones->zones[i_ne].pos.x,
+					    draft_zones->zones[i_ne].pos.y,
+					    draft_zones->zones[i_ne].pos.z -
+					    1);
+			  if (draft_zones->zones[j].used)
+			    {
+			      draft_zones->zones[j].link[LW6KER_DIR_DOWN] =
+				i_nw;
+			    }
+			  j =
+			    relative_index (level,
+					    draft_zones->zones[i_se].pos.x,
+					    draft_zones->zones[i_se].pos.y,
+					    draft_zones->zones[i_se].pos.z -
+					    1);
+			  if (draft_zones->zones[j].used)
+			    {
+			      draft_zones->zones[j].link[LW6KER_DIR_DOWN] =
+				i_nw;
+			    }
+			  j =
+			    relative_index (level,
+					    draft_zones->zones[i_sw].pos.x,
+					    draft_zones->zones[i_sw].pos.y,
+					    draft_zones->zones[i_sw].pos.z -
+					    1);
+			  if (draft_zones->zones[j].used)
+			    {
+			      draft_zones->zones[j].link[LW6KER_DIR_DOWN] =
+				i_nw;
+			    }
+			}
+
+		      draft_zones->max_zone_size = zone_nw->size;
+		      ++found;
 		    }
 		}
-
-	      draft_zones->max_zone_size = zone_nw->size;
-	      ++found;
 	    }
 	}
     }
@@ -414,14 +556,15 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
 			   lw6sys_progress_t * progress)
 {
   int ret = 0;
-  int32_t w, h, size, nb_zones;
+  int32_t w, h, d, size, nb_zones;
   int32_t i, j, k, temp;
 
   lw6sys_progress_begin (progress);
 
   w = draft_zones->shape.w;
   h = draft_zones->shape.h;
-  size = w * h;
+  d = draft_zones->shape.d;
+  size = w * h * d;
   nb_zones = 0;
 
   for (i = 0; i < size; ++i)
@@ -432,9 +575,8 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
 	}
     }
 
-  map_struct->shape.w = w;
-  map_struct->shape.h = h;
-  map_struct->nb_slots = w * h;
+  map_struct->shape = draft_zones->shape;;
+  map_struct->nb_slots = w * h * d;
   map_struct->nb_zones = nb_zones;
   map_struct->max_zone_size = draft_zones->max_zone_size;
 
@@ -460,6 +602,10 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
 
 	      j++;
 	    }
+	  else
+	    {
+	      draft_zones->zones[i].corres = -1;
+	    }
 	}
 
       for (j = 0; j < nb_zones; ++j)
@@ -471,6 +617,10 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
 		  map_struct->zones[j].link[k] =
 		    draft_zones->zones[temp].corres;
 		}
+	      else
+		{
+		  map_struct->zones[j].link[k] = -1;
+		}
 	    }
 	}
       ret = 1;
@@ -501,23 +651,26 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
   map_struct->slots =
     (lw6ker_slot_struct_t *) LW6SYS_CALLOC (map_struct->shape.w *
 					    map_struct->shape.h *
+					    map_struct->shape.d *
 					    sizeof (lw6ker_slot_struct_t));
 
   if (map_struct)
     {
-      int32_t i, x, y;
-      int32_t depth;
+      int32_t i, x, y, z;
 
       lw6ker_zone_struct_t *zone;
 
       /*
        * Set up the id lookup table
        */
-      for (y = 0; y < map_struct->shape.h; ++y)
+      for (z = 0; z < map_struct->shape.d; ++z)
 	{
-	  for (x = 0; x < map_struct->shape.w; ++x)
+	  for (y = 0; y < map_struct->shape.h; ++y)
 	    {
-	      lw6ker_map_struct_set_zone_id (map_struct, x, y, -1);
+	      for (x = 0; x < map_struct->shape.w; ++x)
+		{
+		  lw6ker_map_struct_set_zone_id (map_struct, x, y, z, -1);
+		}
 	    }
 	}
 
@@ -529,26 +682,10 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
 	      for (x = 0; x < map_struct->zones[i].size; ++x)
 		{
 		  lw6ker_map_struct_set_zone_id (map_struct, zone->pos.x + x,
-						 zone->pos.y + y, i);
+						 zone->pos.y + y, zone->pos.z,
+						 i);
 		  map_struct->nb_usable_slots++;
-		}
-	    }
-	}
-
-      /*
-       * Copy depth information from the map.
-       */
-      map_struct->max_depth = 0;
-      for (y = 0; y < map_struct->shape.h; ++y)
-	{
-	  for (x = 0; x < map_struct->shape.w; ++x)
-	    {
-	      depth = lw6map_depth_get (&(level->depth), x, y);
-	      lw6ker_map_struct_set_depth (map_struct, x, y, depth);
-	      map_struct->room_for_armies += depth;
-	      if (map_struct->max_depth < depth)
-		{
-		  map_struct->max_depth = depth;
+		  map_struct->room_for_armies++;
 		}
 	    }
 	}
@@ -578,7 +715,8 @@ _lw6ker_map_struct_get_compression (lw6ker_map_struct_t * map_struct)
 
   ret =
     ((float) map_struct->nb_zones) /
-    ((float) (map_struct->shape.w * map_struct->shape.h));
+    ((float)
+     (map_struct->shape.w * map_struct->shape.h * map_struct->shape.d));
 
   return ret;
 }
@@ -626,7 +764,7 @@ _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
       i = 1;
       progress_i = 0;
       while (i <= level->param.rules.max_zone_size / 2
-	     && draft_zones_group (draft_zones, i))
+	     && draft_zones_group (level, draft_zones, i))
 	{
 	  lw6sys_progress_update (&progress2, 0, progress_n, progress_i++);
 	  i *= 2;
@@ -640,13 +778,15 @@ _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
 
       ret = ret && init_slots (map_struct, level, &progress4);
 
+      lw6ker_map_struct_sanity_check (map_struct);
+
       if (ret)
 	{
 	  lw6sys_log (LW6SYS_LOG_INFO,
 		      _
-		      ("map struct created %dx%d, %d zones, %1.1f%% compression"),
+		      ("map struct created %dx%dx%d, %d zones, %1.1f%% compression"),
 		      map_struct->shape.w, map_struct->shape.h,
-		      map_struct->nb_zones,
+		      map_struct->shape.d, map_struct->nb_zones,
 		      _lw6ker_map_struct_get_compression (map_struct) *
 		      100.0f);
 	}
@@ -676,13 +816,14 @@ _lw6ker_map_struct_clear (lw6ker_map_struct_t * map_struct)
 
 void
 lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
-				       lw6sys_xy_t * there, lw6sys_xy_t here)
+				       lw6sys_xyz_t * there,
+				       lw6sys_xyz_t here)
 {
   int found = 0;
 
   there->x = there->y = 0;
 
-  if (lw6ker_map_struct_get_depth (map_struct, here.x, here.y) > 0)
+  if (lw6ker_map_struct_get_zone_id (map_struct, here.x, here.y, here.z) >= 0)
     {
       *there = here;
       found = 1;
@@ -691,7 +832,7 @@ lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
     {
       int32_t angle, radius;
       int32_t max_radius, max_angle;
-      int32_t x, y;
+      int32_t x, y, z;
 
       max_radius = map_struct->shape.w + map_struct->shape.h;	// +, not *
       for (radius = 0; radius < max_radius && !found; ++radius)
@@ -710,11 +851,15 @@ lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
 	      if (x >= 0 && x < map_struct->shape.w && y >= 0
 		  && y < map_struct->shape.h)
 		{
-		  if (lw6ker_map_struct_get_depth (map_struct, x, y) > 0)
+		  for (z = 0; z < map_struct->shape.d; ++z)
 		    {
-		      found = 1;
-		      there->x = x;
-		      there->y = y;
+		      if (lw6ker_map_struct_get_zone_id (map_struct, x, y, z)
+			  >= 0)
+			{
+			  found = 1;
+			  there->x = x;
+			  there->y = y;
+			}
 		    }
 		}
 	    }
@@ -727,3 +872,99 @@ lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
 		  _("unable to find a free zone near %dx%d"), here.x, here.y);
     }
 }
+
+int
+lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct)
+{
+  int ret = 1;
+  int x, y, z, w, h, d;
+  int nb_zones, nb_slots;
+  int zone_id;
+  int i, j;
+  int z1, z2;
+
+  w = map_struct->shape.w;
+  h = map_struct->shape.h;
+  d = map_struct->shape.d;
+  nb_zones = map_struct->nb_zones;
+  nb_slots = map_struct->nb_slots;
+
+  if (nb_slots != w * h * d)
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("inconsistent nb_slots=%d shape=%dx%dx%d"), nb_slots, w,
+		  h, d);
+      ret = 0;
+    }
+
+  for (z = 0; z < d; z++)
+    {
+      for (y = 0; y < h; y++)
+	{
+	  for (x = 0; x < w; x++)
+	    {
+	      zone_id = lw6ker_map_struct_get_zone_id (map_struct, x, y, z);
+	      if (zone_id == -1 || (zone_id >= 0 && zone_id < nb_zones))
+		{
+		  if (zone_id >= 0)
+		    {
+		      z1 = map_struct->zones[zone_id].pos.z;
+		      for (i = 0; i < LW6KER_NB_DIRS; ++i)
+			{
+			  j = map_struct->zones[zone_id].link[i];
+			  if (j == -1 || (j >= 0 && j < nb_zones))
+			    {
+			      if (j >= 0)
+				{
+				  z2 = map_struct->zones[j].pos.z;
+				  switch (i)
+				    {
+				    case LW6KER_DIR_UP:
+				      if (!(z2 == z1 - 1 || z2 == d - 1))
+					{
+					  lw6sys_log (LW6SYS_LOG_WARNING,
+						      _
+						      ("bad UP link in %d,%d,%d z1=%d z2=%d"),
+						      x, y, z, z1, z2);
+					  ret = 0;
+					}
+				      break;
+				    case LW6KER_DIR_DOWN:
+				      if (!(z2 == z1 + 1 || z2 == 0))
+					{
+					  lw6sys_log (LW6SYS_LOG_WARNING,
+						      _
+						      ("bad DOWN link in %d,%d,%d z1=%d z2=%d"),
+						      x, y, z, z1, z2);
+					  ret = 0;
+					}
+				      break;
+				    default:
+				      // no check for other dirs
+				      break;
+				    }
+				}
+			    }
+			  else
+			    {
+			      lw6sys_log (LW6SYS_LOG_WARNING,
+					  _("bad link %d->%d in %d,%d,%d"), i,
+					  j, x, y, z);
+			      ret = 0;
+			    }
+			}
+		    }
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _("bad zone id %d in %d,%d,%d"), zone_id, x, y,
+			      z);
+		  ret = 0;
+		}
+	    }
+	}
+    }
+
+  return ret;
+}
