@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,9 +32,11 @@
  * and calculating "what's in that direction?".
  */
 int32_t _LW6KER_TABLES_MOVE_X_OFFSET[LW6KER_NB_DIRS] =
-  { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0 };
+  { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0, 0, 0 };
 int32_t _LW6KER_TABLES_MOVE_Y_OFFSET[LW6KER_NB_DIRS] =
-  { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1, -1 };
+  { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1, -1, 0, 0 };
+int32_t _LW6KER_TABLES_MOVE_Z_OFFSET[LW6KER_NB_DIRS] =
+  { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1 };
 
 /*
  * Used to try a direction or another one, when something
@@ -92,6 +94,14 @@ int32_t
     {
     LW6KER_DIR_NNW, LW6KER_DIR_NW, LW6KER_DIR_NE, LW6KER_DIR_WNW,
 	LW6KER_DIR_ENE, LW6KER_DIR_SW, LW6KER_DIR_SE}
+    ,
+    {
+    LW6KER_DIR_UP, LW6KER_DIR_NNE, LW6KER_DIR_NE, LW6KER_DIR_ENE,
+	LW6KER_DIR_ESE, LW6KER_DIR_SE, LW6KER_DIR_SSE}
+    ,
+    {
+    LW6KER_DIR_DOWN, LW6KER_DIR_SSW, LW6KER_DIR_SW, LW6KER_DIR_WSW,
+	LW6KER_DIR_WNW, LW6KER_DIR_NW, LW6KER_DIR_NNW}
   }
   ,
   {				// parity 1
@@ -142,6 +152,14 @@ int32_t
     {
     LW6KER_DIR_NNW, LW6KER_DIR_NW, LW6KER_DIR_NE, LW6KER_DIR_WNW,
 	LW6KER_DIR_ENE, LW6KER_DIR_SW, LW6KER_DIR_SE}
+    ,
+    {
+    LW6KER_DIR_UP, LW6KER_DIR_WSW, LW6KER_DIR_SW, LW6KER_DIR_SSW,
+	LW6KER_DIR_SSE, LW6KER_DIR_SE, LW6KER_DIR_ESE}
+    ,
+    {
+    LW6KER_DIR_DOWN, LW6KER_DIR_ENE, LW6KER_DIR_NE, LW6KER_DIR_NNE,
+	LW6KER_DIR_NNW, LW6KER_DIR_NW, LW6KER_DIR_WNW}
   }
 };
 
