@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,11 +28,12 @@
 
 #define TEST_MAP_WIDTH 72
 #define TEST_MAP_HEIGHT 24
+#define TEST_MAP_NB_LAYERS 5
 #define TEST_NB_ROUNDS 100
-#define TEST_GAME_STRUCT_CHECKSUM 0x024ccc4c
-#define TEST_GAME_STATE_CHECKSUM 0x17e3296f
-#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x23283da7
-#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0xe041edba
+#define TEST_GAME_STRUCT_CHECKSUM 0x44df6790
+#define TEST_GAME_STATE_CHECKSUM 0x64970de0
+#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x75400075
+#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x2c1bf492
 #define TEST_SERVER_ID 0x1234123412341234LL
 #define TEST_CURSOR1_ID 0x1234
 #define TEST_CURSOR2_ID 0x2345
@@ -89,7 +90,8 @@ test_struct ()
     int checksum;
 
     ret = 0;
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -125,7 +127,8 @@ test_state ()
     int checksum;
 
     ret = 0;
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -169,7 +172,8 @@ test_population ()
 
     ret = 0;
 
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -228,7 +232,8 @@ test_algorithm ()
     int cursor_x, cursor_y;
 
     ret = 0;
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
