@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ _lw6ker_zone_struct_update_checksum (lw6ker_zone_struct_t * zone_struct,
 {
   int i;
 
-  lw6sys_checksum_update_xy (checksum, &(zone_struct->pos));
+  lw6sys_checksum_update_xyz (checksum, &(zone_struct->pos));
   lw6sys_checksum_update_int32 (checksum, zone_struct->size);
   for (i = 0; i < LW6KER_NB_DIRS; ++i)
     {
