@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include "../sys/sys.h"
 #include "../map/map.h"
 
-#define LW6KER_NB_DIRS 12
+#define LW6KER_NB_DIRS 14
 
 #define LW6KER_DIR_NNE 0
 #define LW6KER_DIR_NE 1
@@ -40,6 +40,8 @@
 #define LW6KER_DIR_WNW 9
 #define LW6KER_DIR_NW 10
 #define LW6KER_DIR_NNW 11
+#define LW6KER_DIR_UP 12
+#define LW6KER_DIR_DOWN 13
 
 #define LW6KER_NB_PARITIES 2
 
@@ -62,7 +64,7 @@
 
 typedef struct lw6ker_zone_struct_s
 {
-  lw6sys_xy_t pos;
+  lw6sys_xyz_t pos;
   u_int32_t size;
   int32_t link[LW6KER_NB_DIRS];
 }
@@ -71,7 +73,6 @@ lw6ker_zone_struct_t;
 typedef struct lw6ker_slot_struct_s
 {
   int32_t zone_id;
-  int32_t depth;
 }
 lw6ker_slot_struct_t;
 
@@ -92,12 +93,11 @@ lw6ker_slot_struct_t;
  */
 typedef struct lw6ker_map_struct_s
 {
-  lw6sys_wh_t shape;
+  lw6sys_whd_t shape;
   int32_t nb_zones;
   int32_t nb_slots;
   int32_t nb_usable_slots;
   int32_t room_for_armies;
-  int32_t max_depth;
   int32_t max_zone_size;
   lw6ker_zone_struct_t *zones;
   lw6ker_slot_struct_t *slots;
@@ -125,7 +125,7 @@ typedef struct lw6ker_zone_state_s
 {
   int32_t potential:24;
   int32_t direction_to_cursor:8;
-  lw6sys_xy_t closest_cursor_pos;
+  lw6sys_xyz_t closest_cursor_pos;
 }
 lw6ker_zone_state_t;
 
@@ -137,11 +137,10 @@ lw6ker_slot_state_t;
 
 typedef struct lw6ker_fighter_s
 {
-  u_int32_t team_color:4;
-  u_int32_t layer:4;
-  u_int32_t last_direction:8;
-  u_int32_t health:16;
-  lw6sys_xy_t pos;
+  u_int32_t team_color:8;
+  int32_t last_direction:8;
+  int32_t health:16;
+  lw6sys_xyz_t pos;
 }
 lw6ker_fighter_t;
 
@@ -152,8 +151,8 @@ typedef struct lw6ker_cursor_s
   char letter;
   int enabled;
   int team_color;
-  lw6sys_xy_t pos;
-  lw6sys_xy_t apply_pos;
+  lw6sys_xyz_t pos;
+  lw6sys_xyz_t apply_pos;
   int32_t pot_offset;
 }
 lw6ker_cursor_t;
@@ -219,7 +218,7 @@ typedef struct lw6ker_armies_s
    * It's more convenient to access them this way, instead of
    * having to read a w*h array, which can be very big and 90%
    * empty. This optimization is not usefull on small and/or
-   * crowded maps, but experience shows that:
+   * crowded maps, but experience shows that
    * a) only small maps can be crowded anyway
    * b) small maps are fast, only big maps require optimization.
    */
@@ -227,24 +226,16 @@ typedef struct lw6ker_armies_s
 }
 lw6ker_armies_t;
 
-typedef struct lw6ker_layer_s
-{
-  lw6ker_map_struct_t *map_struct;
-  int32_t nb_slots;		// redundant but convenient
-  lw6ker_armies_t *armies;
-  lw6ker_slot_state_t *slots;
-} lw6ker_layer_t;
-
 typedef struct lw6ker_map_state_s
 {
   lw6ker_map_struct_t *map_struct;
-  lw6sys_wh_t shape;		// redundant but convenient
+  lw6sys_whd_t shape;		// redundant but convenient
   lw6ker_armies_t armies;
   int32_t max_nb_teams;
   lw6ker_team_t teams[LW6MAP_MAX_NB_TEAMS];
   lw6ker_cursor_array_t cursor_array;
-  int32_t nb_layers;
-  lw6ker_layer_t layers[LW6MAP_MAX_DEPTH];
+  int32_t nb_slots;		// redundant but convenient
+  lw6ker_slot_state_t *slots;
 }
 lw6ker_map_state_t;
 
@@ -288,9 +279,10 @@ extern int lw6ker_cursor_enable (lw6ker_cursor_t * cursor,
 extern int lw6ker_cursor_disable (lw6ker_cursor_t * cursor);
 extern int lw6ker_cursor_update (lw6ker_cursor_t * cursor, int32_t x,
 				 int32_t y, int32_t pot_offset,
-				 lw6sys_wh_t * shape, lw6map_rules_t * rules);
+				 lw6sys_whd_t * shape,
+				 lw6map_rules_t * rules);
 extern int lw6ker_cursor_sanity_check (lw6ker_cursor_t * cursor,
-				       lw6sys_wh_t * shape,
+				       lw6sys_whd_t * shape,
 				       lw6map_rules_t * rules);
 
 /*
@@ -310,11 +302,11 @@ extern int lw6ker_cursor_array_update (lw6ker_cursor_array_t * cursor_array,
 				       u_int64_t server_id,
 				       u_int16_t cursor_id, int32_t x,
 				       int32_t y, int32_t pot_offset,
-				       lw6sys_wh_t * shape,
+				       lw6sys_whd_t * shape,
 				       lw6map_rules_t * rules);
 extern int lw6ker_cursor_array_sanity_check (lw6ker_cursor_array_t *
 					     cursor_array,
-					     lw6sys_wh_t * shape,
+					     lw6sys_whd_t * shape,
 					     lw6map_rules_t * rules);
 
 /*
@@ -408,19 +400,23 @@ extern lw6ker_game_struct_t *lw6ker_game_struct_dup (lw6ker_game_struct_t *
 extern u_int32_t lw6ker_game_struct_checksum (lw6ker_game_struct_t *
 					      game_struct);
 
-/*
- * In layer.c
- */
-
 /*
  * in mapstate.c
  */
+static inline int
+lw6ker_map_state_slot_index (lw6ker_map_state_t * map_state, int32_t x,
+			     int32_t y, int32_t z)
+{
+  return (map_state->shape.w * map_state->shape.h * z +
+	  map_state->shape.w * y + x);
+}
+
 extern int lw6ker_map_state_get_free_team_color (lw6ker_map_state_t *
 						 map_state);
 extern int32_t lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
 					       int32_t team_color,
 					       int32_t nb_fighters,
-					       lw6sys_xy_t desired_center,
+					       lw6sys_xyz_t desired_center,
 					       lw6map_rules_t * rules);
 extern int lw6ker_map_state_redistribute_team (lw6ker_map_state_t * map_state,
 					       int32_t dst_team_color,
@@ -439,38 +435,39 @@ extern int lw6ker_map_state_remove_team_fighters (lw6ker_map_state_t *
 						  int32_t nb_fighters);
 static inline void
 lw6ker_map_state_set_fighter_id (lw6ker_map_state_t * map_state,
-				 int32_t layer, int32_t x,
-				 int32_t y, int32_t fighter_id)
+				 int32_t x,
+				 int32_t y, int32_t z, int32_t fighter_id)
 {
-  map_state->layers[layer].slots[map_state->shape.w * y + x].fighter_id =
+  map_state->
+    slots[lw6ker_map_state_slot_index (map_state, x, y, z)].fighter_id =
     fighter_id;
 };
 
 static inline int32_t
 lw6ker_map_state_get_fighter_id (lw6ker_map_state_t * map_state,
-				 int32_t layer, int32_t x, int32_t y)
+				 int32_t x, int32_t y, int32_t z)
 {
-  return (map_state->layers[layer].slots[map_state->shape.w * y + x].
-	  fighter_id);
+  return (map_state->
+	  slots[lw6ker_map_state_slot_index (map_state, x, y, z)].fighter_id);
 };
 
 extern lw6ker_fighter_t *lw6ker_map_state_get_fighter_safe (lw6ker_map_state_t
 							    * map_state,
-							    int32_t layer,
 							    int32_t x,
-							    int32_t y);
+							    int32_t y,
+							    int32_t z);
 /*
  * Carefull with this one, there must really be a fighter
  * or it segfaults directly.
  */
 static inline lw6ker_fighter_t *
 lw6ker_map_state_get_fighter_unsafe (lw6ker_map_state_t * map_state,
-				     int32_t layer, int32_t x, int32_t y)
+				     int32_t x, int32_t y, int32_t z)
 {
   return (&
-	  (map_state->armies.
-	   fighters[map_state->layers[layer].
-		    slots[map_state->shape.w * y + x].fighter_id]));
+	  (map_state->armies.fighters[map_state->slots
+				      [lw6ker_map_state_slot_index
+				       (map_state, x, y, z)].fighter_id]));
 };
 
 extern void lw6ker_map_state_print_debug (lw6ker_map_state_t * map_state);
@@ -491,38 +488,37 @@ extern void lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
 /*
  * In mapstruct.c
  */
-static inline void
-lw6ker_map_struct_set_depth (lw6ker_map_struct_t * map_struct, int32_t x,
-			     int32_t y, int32_t depth)
+static inline int
+lw6ker_map_struct_slot_index (lw6ker_map_struct_t * map_struct, int32_t x,
+			      int32_t y, int32_t z)
 {
-  map_struct->slots[map_struct->shape.w * y + x].depth = depth;
+  return (map_struct->shape.w * map_struct->shape.h * z +
+	  map_struct->shape.w * y + x);
+}
+
+static inline void
+lw6ker_map_struct_set_zone_id (lw6ker_map_struct_t * map_struct,
+			       int32_t x, int32_t y, int32_t z,
+			       int32_t zone_id)
+{
+  map_struct->
+    slots[lw6ker_map_struct_slot_index (map_struct, x, y, z)].zone_id =
+    zone_id;
 };
 
 static inline int32_t
-lw6ker_map_struct_get_depth (lw6ker_map_struct_t * map_struct, int32_t x,
-			     int32_t y)
+lw6ker_map_struct_get_zone_id (lw6ker_map_struct_t * map_struct,
+			       int32_t x, int32_t y, int32_t z)
 {
-  return (map_struct->slots[map_struct->shape.w * y + x].depth);
-};
-
-static inline void
-lw6ker_map_struct_set_zone_id (lw6ker_map_struct_t * map_struct, int32_t x,
-			       int32_t y, int32_t zone_id)
-{
-  map_struct->slots[map_struct->shape.w * y + x].zone_id = zone_id;
-};
-
-static inline int32_t
-lw6ker_map_struct_get_zone_id (lw6ker_map_struct_t * map_struct, int32_t x,
-			       int32_t y)
-{
-  return (map_struct->slots[map_struct->shape.w * y + x].zone_id);
+  return (map_struct->slots
+	  [lw6ker_map_struct_slot_index (map_struct, x, y, z)].zone_id);
 };
 
 extern void lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t *
 						   map_struct,
-						   lw6sys_xy_t * there,
-						   lw6sys_xy_t here);
+						   lw6sys_xyz_t * there,
+						   lw6sys_xyz_t here);
+extern int lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct);
 
 /*
  * in server.c
@@ -550,9 +546,10 @@ extern int lw6ker_server_array_sanity_check (lw6ker_server_array_t *
 /*
  * In team.c
  */
-extern void lw6ker_team_activate (lw6ker_team_t * team, lw6sys_xy_t pos);
+extern void lw6ker_team_activate (lw6ker_team_t * team, lw6sys_xyz_t pos);
 extern void lw6ker_team_unactivate (lw6ker_team_t * team);
-extern void lw6ker_team_spread_gradient (lw6ker_team_t * team);
+extern void lw6ker_team_spread_gradient (lw6ker_team_t * team,
+					 int skip_vertical);
 extern void lw6ker_team_normalize_pot (lw6ker_team_t * team,
 				       lw6map_rules_t * rules);
 
