@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,12 @@
 #define _LW6LDR_FILE_README "README"
 #define _LW6LDR_FILE_README_TXT "README.txt"
 #define _LW6LDR_FILE_MAP_PNG "map.png"
+#define _LW6LDR_FILE_LAYER2_PNG "layer2.png"
+#define _LW6LDR_FILE_LAYER3_PNG "layer3.png"
+#define _LW6LDR_FILE_LAYER4_PNG "layer4.png"
+#define _LW6LDR_FILE_LAYER5_PNG "layer5.png"
+#define _LW6LDR_FILE_LAYER6_PNG "layer6.png"
+#define _LW6LDR_FILE_LAYER7_PNG "layer7.png"
 #define _LW6LDR_FILE_TEXTURE_PNG "texture.png"
 #define _LW6LDR_FILE_TEXTURE_JPEG "texture.jpeg"
 #define _LW6LDR_FILE_TEXTURE_JPG "texture.jpg"
@@ -38,7 +44,8 @@
 
 typedef struct _lw6ldr_image_bw_s
 {
-  lw6sys_wh_t shape;
+  int w;
+  int h;
   unsigned char **data;
   int step;
 }
@@ -46,7 +53,8 @@ _lw6ldr_image_bw_t;
 
 typedef struct _lw6ldr_image_rgba_s
 {
-  lw6sys_wh_t shape;
+  int w;
+  int h;
   unsigned char **data;
 }
 _lw6ldr_image_rgba_t;
