@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,7 +34,8 @@
  * @dirname: the directory containing the map
  * @default_param: default parameters, as strings
  * @forced_param: forced parameters, as strings
- * @display_shape: the shape of the display output (resolution)
+ * @display_w: the width of the display output (resolution)
+ * @display_h: the height of the display output (resolution)
  * @progress: information used to handle the progress bar
  *
  * Loads a map from dist. The default_param and forced_param can contain
@@ -52,7 +53,7 @@
  */
 lw6map_level_t *
 lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
-	     lw6sys_assoc_t * forced_param, lw6sys_wh_t * display_shape,
+	     lw6sys_assoc_t * forced_param, int display_w, int display_h,
 	     lw6sys_progress_t * progress)
 {
   lw6map_level_t *level = NULL;
@@ -60,14 +61,14 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
   float ratio = 0.0f;		// important, in case texture isn't found/used
   int texture_exists = 0;
   lw6sys_progress_t progress_texture;
-  lw6sys_progress_t progress_depth;
+  lw6sys_progress_t progress_body;
   lw6sys_progress_t progress_color;
   lw6ldr_hints_t hints;
   lw6ldr_use_t use;
 
   lw6sys_log (LW6SYS_LOG_INFO, _("loading map \"%s\""), dirname);
 
-  lw6sys_progress_split3 (&progress_texture, &progress_depth, &progress_color,
+  lw6sys_progress_split3 (&progress_texture, &progress_body, &progress_color,
 			  progress);
 
   level = lw6map_new ();
@@ -106,18 +107,18 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
 	  ok = ok
 	    && lw6ldr_texture_read (&level->texture, dirname,
 				    &(level->param), &hints, use.use_texture,
-				    display_shape, &ratio, &texture_exists,
-				    &progress_texture);
+				    display_w, display_h, &ratio,
+				    &texture_exists, &progress_texture);
 	}
       ok = ok
-	&& lw6ldr_depth_read (&level->depth, dirname, &(level->param), &hints,
-			      display_shape, ratio, &progress_depth);
+	&& lw6ldr_body_read (&level->body, dirname, &(level->param), &hints,
+			     display_w, display_h, ratio, &progress_body);
       if (!level->texture.data)
 	{
 	  ok = ok
-	    && lw6map_texture_from_depth (&level->texture, &level->depth,
-					  &(level->param.
-					    style.view_color_map));
+	    && lw6map_texture_from_body (&level->texture, &level->body,
+					 &(level->param.
+					   style.view_color_map));
 	}
       if (ok && texture_exists)
 	{
@@ -148,7 +149,8 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
  * @relative_path: something which will be appended to a @map_path member
  * @default_param: default parameters, as strings
  * @forced_param: forced parameters, as strings
- * @display_shape: the shape of the display output (resolution)
+ * @display_w: the width of the display output (resolution)
+ * @display_h: the height of the display output (resolution)
  * @progress: information used to handle the progress bar
  *
  * Reads a map from disk, using the map-path value, which is a collection
@@ -162,7 +164,7 @@ lw6map_level_t *
 lw6ldr_read_relative (char *map_path, char *relative_path,
 		      lw6sys_assoc_t * default_param,
 		      lw6sys_assoc_t * forced_param,
-		      lw6sys_wh_t * display_shape,
+		      int display_w, int display_h,
 		      lw6sys_progress_t * progress)
 {
   lw6map_level_t *ret = NULL;
@@ -184,7 +186,7 @@ lw6ldr_read_relative (char *map_path, char *relative_path,
 		    {
 		      ret =
 			lw6ldr_read (full_dir, default_param, forced_param,
-				     display_shape, progress);
+				     display_w, display_h, progress);
 		    }
 		}
 	      LW6SYS_FREE (full_dir);
