@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -151,8 +151,8 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file,
 			  lw6sys_progress_update (progress, 0, 3, 2);
 			  png_read_end (png_ptr, end_info);
 
-			  image->shape.w = width;
-			  image->shape.h = height;
+			  image->w = width;
+			  image->h = height;
 			  image->data = buf;
 			  ret = 1;
 			}
@@ -276,8 +276,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
 		      buf[j][i * 4 + 3] = 255;
 		    }
 		}
-	      image->shape.w = cinfo.output_width;
-	      image->shape.h = cinfo.output_height;
+	      image->w = cinfo.output_width;
+	      image->h = cinfo.output_height;
 	      image->data = buf;
 	      ret = 1;
 	      break;
@@ -303,8 +303,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
 		      buf[j][i * 4 + 3] = 255;
 		    }
 		}
-	      image->shape.w = cinfo.output_width;
-	      image->shape.h = cinfo.output_height;
+	      image->w = cinfo.output_width;
+	      image->h = cinfo.output_height;
 	      image->data = buf;
 	      ret = 1;
 	      break;
@@ -354,7 +354,7 @@ _lw6ldr_rgba_clear (_lw6ldr_image_rgba_t * image)
 
   if (image->data)
     {
-      for (row = 0; row < image->shape.h; ++row)
+      for (row = 0; row < image->h; ++row)
 	{
 	  if (image->data[row])
 	    {
