@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -53,7 +53,6 @@
 static int
 check_map_with_absolute_path (char *absolute_path)
 {
-  lw6sys_wh_t display_shape;
   lw6map_level_t *level1 = NULL;
   lw6map_level_t *level2 = NULL;
   lw6map_level_t *level3 = NULL;
@@ -63,9 +62,9 @@ check_map_with_absolute_path (char *absolute_path)
   char *repr = NULL;
 
   lw6sys_log (LW6SYS_LOG_NOTICE, _("deep check \"%s\""), absolute_path);
-  display_shape.w = TEST_DISPLAY_WIDTH;
-  display_shape.h = TEST_DISPLAY_HEIGHT;
-  level1 = lw6ldr_read (absolute_path, NULL, NULL, &display_shape, NULL);
+  level1 =
+    lw6ldr_read (absolute_path, NULL, NULL, TEST_DISPLAY_WIDTH,
+		 TEST_DISPLAY_HEIGHT, NULL);
   if (level1)
     {
       hexa_level1 = lw6map_to_hexa (level1);
@@ -361,7 +360,6 @@ test_read ()
     lw6map_level_t *level = NULL;
     char *repr = NULL;
     char *map_path = NULL;
-    lw6sys_wh_t display_shape = { TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT };
     lw6sys_progress_t progress;
     float done = 0.0f;
 
@@ -373,7 +371,8 @@ test_read ()
       {
 	level =
 	  lw6ldr_read_relative (map_path, TEST_MAP, NULL, NULL,
-				&display_shape, &progress);
+				TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT,
+				&progress);
 	if (level)
 	  {
 	    repr = lw6map_repr (level);
