@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,11 +34,11 @@ read_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
 {
   int ret = 0;
 
-  texture->shape.w = image->shape.w;
-  texture->shape.h = image->shape.h;
+  texture->w = image->w;
+  texture->h = image->h;
   texture->data =
-    (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->shape.w *
-					texture->shape.h *
+    (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->w *
+					texture->h *
 					sizeof (lw6sys_color_8_t *));
 
   if (texture->data)
@@ -46,9 +46,9 @@ read_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
       int row, col;
       lw6sys_color_8_t value;
 
-      for (row = 0; row < texture->shape.h; ++row)
+      for (row = 0; row < texture->h; ++row)
 	{
-	  for (col = 0; col < texture->shape.w; ++col)
+	  for (col = 0; col < texture->w; ++col)
 	    {
 	      value.r = image->data[row][col * 4];
 	      value.g = image->data[row][col * 4 + 1];
@@ -82,16 +82,15 @@ read_alpha_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
 {
   int ret = 0;
 
-  if (texture->shape.w == image->shape.w &&
-      texture->shape.h == image->shape.h)
+  if (texture->w == image->w && texture->h == image->h)
     {
       int row, col;
       lw6sys_color_8_t value;
       u_int32_t alpha;
 
-      for (row = 0; row < texture->shape.h; ++row)
+      for (row = 0; row < texture->h; ++row)
 	{
-	  for (col = 0; col < texture->shape.w; ++col)
+	  for (col = 0; col < texture->w; ++col)
 	    {
 	      value = lw6map_texture_get (texture, col, row);
 	      alpha = (((u_int32_t) image->data[row][col * 4]) +
@@ -109,8 +108,7 @@ read_alpha_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
       lw6sys_log (LW6SYS_LOG_ERROR,
 		  _
 		  ("texture size (%dx%d) and alpha layer size (%dx%d) do not match"),
-		  texture->shape.w, texture->shape.h, image->shape.w,
-		  image->shape.h);
+		  texture->w, texture->h, image->w, image->h);
     }
 
   _lw6ldr_rgba_clear (image);
@@ -187,7 +185,7 @@ read_alpha_jpeg (lw6map_texture_t * texture, char *texture_alpha_dot_jpeg,
 int
 lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 		     lw6map_param_t * param, lw6ldr_hints_t * hints,
-		     int use_texture, lw6sys_wh_t * display_shape,
+		     int use_texture, int display_w, int display_h,
 		     float *ratio, int *texture_exists,
 		     lw6sys_progress_t * progress)
 {
@@ -286,15 +284,15 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 	}
     }
 
-  if (ret && texture->shape.w > 0 && texture->shape.h > 0)
+  if (ret && texture->w > 0 && texture->h > 0)
     {
       if (param->style.keep_ratio)
 	{
-	  (*ratio) = ((float) texture->shape.w) / ((float) texture->shape.h);
+	  (*ratio) = ((float) texture->w) / ((float) texture->h);
 	}
       else
 	{
-	  (*ratio) = ((float) display_shape->w) / ((float) display_shape->h);
+	  (*ratio) = ((float) display_w) / ((float) display_h);
 	}
     }
   else
