@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -76,8 +76,10 @@ typedef struct lw6ldr_use_s
 
 typedef struct lw6ldr_resampler_s
 {
-  lw6sys_wh_t target_shape;
-  lw6sys_wh_t source_shape;
+  int target_w;
+  int target_h;
+  int source_w;
+  int source_h;
   float scale_x;
   float scale_y;
 }
@@ -92,18 +94,16 @@ typedef struct lw6ldr_entry_s
 }
 lw6ldr_entry_t;
 
+/* ldr-body.c */
+extern int lw6ldr_body_read (lw6map_body_t * body, char *dirname,
+			     lw6map_param_t * param, lw6ldr_hints_t * hints,
+			     int display_w, int display_h, float ratio,
+			     lw6sys_progress_t * progress);
+
 /* ldr-color.c */
 extern void lw6ldr_auto_colors (lw6map_style_t * style,
 				lw6ldr_hints_t * hints);
 
-/*
- * In depth.c
- */
-extern int lw6ldr_depth_read (lw6map_depth_t * depth, char *dirname,
-			      lw6map_param_t * param, lw6ldr_hints_t * hints,
-			      lw6sys_wh_t * display_shape, float ratio,
-			      lw6sys_progress_t * progress);
-
 /* ldr-dir.c */
 extern void lw6ldr_free_entry (lw6ldr_entry_t * entry);
 extern lw6sys_list_t *lw6ldr_get_entries (char *map_path,
@@ -125,6 +125,17 @@ extern char *lw6ldr_hints_get_default (char *key);
 extern int lw6ldr_hints_update (lw6ldr_hints_t * hints,
 				lw6sys_assoc_t * values);
 
+/* ldr-layer.c */
+extern int lw6ldr_layer_read_first (lw6map_layer_t * layer, char *filename,
+				    lw6map_param_t * param,
+				    lw6ldr_hints_t * hints,
+				    int display_w,
+				    int display_h,
+				    float target_ratio,
+				    lw6sys_progress_t * progress);
+extern int lw6ldr_layer_read_next (lw6map_layer_t * layer, char *filename,
+				   int target_w, int target_h);
+
 /*
  * In metadata.c
  */
@@ -150,13 +161,13 @@ extern int lw6ldr_print_examples (char *user_dir);
 extern lw6map_level_t *lw6ldr_read (char *dirname,
 				    lw6sys_assoc_t * default_param,
 				    lw6sys_assoc_t * forced_param,
-				    lw6sys_wh_t * display_shape,
+				    int display_w, int display_h,
 				    lw6sys_progress_t * progress);
 extern lw6map_level_t *lw6ldr_read_relative (char *map_path,
 					     char *relative_path,
 					     lw6sys_assoc_t * default_param,
 					     lw6sys_assoc_t * forced_param,
-					     lw6sys_wh_t * display_shape,
+					     int display_w, int display_h,
 					     lw6sys_progress_t * progress);
 
 /*
@@ -165,9 +176,13 @@ extern lw6map_level_t *lw6ldr_read_relative (char *map_path,
 extern void lw6ldr_resampler_init (lw6ldr_resampler_t * resampler,
 				   lw6map_param_t * param,
 				   lw6ldr_hints_t * hints,
-				   lw6sys_wh_t * source_shape,
-				   lw6sys_wh_t * display_shape,
-				   float target_ratio);
+				   int source_w,
+				   int source_h,
+				   int display_w,
+				   int display_h, float target_ratio);
+extern void lw6ldr_resampler_force (lw6ldr_resampler_t * resampler,
+				    int source_w,
+				    int source_h, int target_w, int target_h);
 extern void lw6ldr_resampler_source2target (lw6ldr_resampler_t * resampler,
 					    int *target_x, int *target_y,
 					    int source_x, int source_y);
@@ -192,7 +207,7 @@ extern int lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 				lw6map_param_t * param,
 				lw6ldr_hints_t * hints,
 				int use_texture,
-				lw6sys_wh_t * display_shape, float *ratio,
+				int display_w, int display_h, float *ratio,
 				int *texture_exists,
 				lw6sys_progress_t * progress);
 
