@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -155,6 +155,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6_print_pedigree ();
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_TARGET, argv[i]))
+	{
+	  lw6_print_target ();
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_AUDIT, argv[i]))
 	{
 	  lw6_print_audit (argc, argv);
@@ -371,6 +376,16 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_target_cpu ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENDIANNESS, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_endianness ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_POINTER_SIZE, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_get_pointer_size ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_TARGET_OS, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_target_os ());
