@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -83,7 +83,7 @@ lw6_print_long_copyright ()
   printf
     ("%s",
      "Liquid War 6 is a unique multiplayer wargame.\n"
-     "Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>\n"
+     "Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>\n"
      "\n"
      "This program is free software; you can redistribute it and/or modify\n"
      "it under the terms of the GNU General Public License as published by\n"
@@ -127,7 +127,15 @@ lw6_print_pedigree ()
   printf ("hostname: %s\n", lw6sys_build_get_hostname ());
   printf ("date: %s\n", lw6sys_build_get_date ());
   printf ("time: %s\n", lw6sys_build_get_time ());
+  fflush (stdout);
+}
+
+void
+lw6_print_target ()
+{
   printf ("target-cpu: %s\n", lw6sys_build_get_target_cpu ());
+  printf ("endianness: %s\n", lw6sys_build_get_endianness ());
+  printf ("pointer-size: %d\n", lw6sys_build_get_pointer_size ());
   printf ("target-os: %s\n", lw6sys_build_get_target_os ());
   printf ("ms-windows: %d\n", lw6sys_build_is_ms_windows ());
   fflush (stdout);
@@ -617,20 +625,13 @@ lw6_print_hello (int argc, char *argv[])
 {
   lw6sys_log (LW6SYS_LOG_INFO, _("hello"));
 
-  lw6sys_build_log_pedigree ();
+  lw6sys_build_log_all ();
   lw6sys_options_log_defaults ();
   lw6sys_options_log (argc, argv);
 
+  lw6sys_check_types_size (argc, argv);
   lw6sys_log (LW6SYS_LOG_INFO, _("approx. %d megabytes available"),
 	      lw6sys_megabytes_available ());
-  if (lw6sys_is_big_endian ())
-    {
-      lw6sys_log (LW6SYS_LOG_INFO, _("big endian system (ppc-like)"));
-    }
-  if (lw6sys_is_little_endian ())
-    {
-      lw6sys_log (LW6SYS_LOG_INFO, _("little endian system (x86-like)"));
-    }
 }
 
 void
