@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,8 @@ lw6map_dup (lw6map_level_t * source)
 {
   lw6map_level_t *ret = NULL;
   int size = 0;
-  int id;
+  u_int32_t id;
+  int layer = 0;
 
   ret = lw6map_new ();
   if (ret)
@@ -63,27 +64,28 @@ lw6map_dup (lw6map_level_t * source)
 	{
 	  ret->metadata.readme = lw6sys_str_copy (source->metadata.readme);
 	}
-      if (source->depth.data)
+      for (layer = 0; layer < ret->body.shape.d; ++layer)
 	{
 	  size =
-	    source->depth.shape.w * source->depth.shape.h *
-	    sizeof (unsigned char);
-	  ret->depth.data = LW6SYS_MALLOC (size);
-	  if (ret->depth.data)
+	    source->body.layers[layer].shape.w *
+	    source->body.layers[layer].shape.h * sizeof (u_int8_t);
+	  ret->body.layers[layer].data = LW6SYS_MALLOC (size);
+	  if (ret->body.layers[layer].data)
 	    {
-	      memcpy (ret->depth.data, source->depth.data, size);
+	      memcpy (ret->body.layers[layer].data,
+		      source->body.layers[layer].data, size);
 	    }
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _("unable to duplicate depth data"));
+			  _("unable to duplicate layer %d data"), layer);
+
 	    }
 	}
       if (source->texture.data)
 	{
 	  size =
-	    source->texture.shape.w * source->texture.shape.h *
-	    sizeof (lw6sys_color_8_t);
+	    source->texture.w * source->texture.h * sizeof (lw6sys_color_8_t);
 	  ret->texture.data = LW6SYS_MALLOC (size);
 	  if (ret->texture.data)
 	    {
