@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,25 +41,39 @@ push_metadata (lw6sys_hexa_serializer_t * hexa_serializer,
 }
 
 static int
-push_depth (lw6sys_hexa_serializer_t * hexa_serializer,
-	    lw6map_depth_t * depth)
+push_layer (lw6sys_hexa_serializer_t * hexa_serializer,
+	    lw6map_layer_t * layer)
 {
   int ret = 1;
   int x, y;
 
-  ret = ret && lw6sys_hexa_serializer_push_wh (hexa_serializer, depth->shape);
-  for (y = 0; y < depth->shape.h && ret; ++y)
+  ret = ret
+    && lw6sys_hexa_serializer_push_whd (hexa_serializer, layer->shape);
+  for (y = 0; y < layer->shape.h && ret; ++y)
     {
-      for (x = 0; x < depth->shape.w && ret; ++x)
+      for (x = 0; x < layer->shape.w && ret; ++x)
 	{
 	  ret = ret
 	    && lw6sys_hexa_serializer_push_int8 (hexa_serializer,
-						 lw6map_depth_get (depth, x,
+						 lw6map_layer_get (layer, x,
 								   y));
 	}
     }
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer, depth->max);
+
+  return ret;
+}
+
+static int
+push_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
+{
+  int ret = 1;
+  int layer;
+
+  ret = ret && lw6sys_hexa_serializer_push_whd (hexa_serializer, body->shape);
+  for (layer = 0; layer < body->shape.d && ret; ++layer)
+    {
+      ret = ret && push_layer (hexa_serializer, &(body->layers[layer]));
+    }
 
   return ret;
 }
@@ -72,10 +86,12 @@ push_texture (lw6sys_hexa_serializer_t * hexa_serializer,
   int x, y;
 
   ret = ret
-    && lw6sys_hexa_serializer_push_wh (hexa_serializer, texture->shape);
-  for (y = 0; y < texture->shape.h && ret; ++y)
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer, texture->w);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer, texture->h);
+  for (y = 0; y < texture->h && ret; ++y)
     {
-      for (x = 0; x < texture->shape.w && ret; ++x)
+      for (x = 0; x < texture->w && ret; ++x)
 	{
 	  ret = ret
 	    && lw6sys_hexa_serializer_push_color (hexa_serializer,
@@ -252,7 +268,7 @@ lw6map_to_hexa (lw6map_level_t * level)
   if (hexa_serializer)
     {
       ok = ok && push_metadata (hexa_serializer, &(level->metadata));
-      ok = ok && push_depth (hexa_serializer, &(level->depth));
+      ok = ok && push_body (hexa_serializer, &(level->body));
       ok = ok && push_texture (hexa_serializer, &(level->texture));
       ok = ok && push_param (hexa_serializer, &(level->param));
       if (ok)
@@ -281,32 +297,28 @@ pop_metadata (lw6sys_hexa_serializer_t * hexa_serializer,
 }
 
 static int
-pop_depth (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_depth_t * depth)
+pop_layer (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_layer_t * layer,
+	   lw6sys_whd_t * shape)
 {
   int ret = 1;
   int x, y;
   int8_t c = 0;
 
   ret = ret
-    && lw6sys_hexa_serializer_pop_wh (hexa_serializer, &(depth->shape));
-  if (depth->shape.w >= LW6MAP_MIN_SIDE
-      && depth->shape.w <= LW6MAP_MAX_SIDE
-      && depth->shape.h >= LW6MAP_MIN_SIDE
-      && depth->shape.h <= LW6MAP_MAX_SIDE
-      && depth->shape.w * depth->shape.h >= LW6MAP_MIN_SURFACE
-      && depth->shape.w * depth->shape.h <= LW6MAP_MAX_SURFACE)
+    && lw6sys_hexa_serializer_pop_whd (hexa_serializer, &(layer->shape));
+  if (layer->shape.w == shape->w && layer->shape.h == shape->h)
     {
-      depth->data =
-	(u_int8_t *) LW6SYS_CALLOC (depth->shape.w * depth->shape.h);
-      if (depth->data)
+      layer->data =
+	(u_int8_t *) LW6SYS_CALLOC (layer->shape.w * layer->shape.h);
+      if (layer->data)
 	{
-	  for (y = 0; y < depth->shape.h && ret; ++y)
+	  for (y = 0; y < layer->shape.h && ret; ++y)
 	    {
-	      for (x = 0; x < depth->shape.w && ret; ++x)
+	      for (x = 0; x < layer->shape.w && ret; ++x)
 		{
 		  ret = ret
 		    && lw6sys_hexa_serializer_pop_int8 (hexa_serializer, &c);
-		  lw6map_depth_set (depth, x, y, c);
+		  lw6map_layer_set (layer, x, y, c);
 		}
 	    }
 	}
@@ -317,12 +329,38 @@ pop_depth (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_depth_t * depth)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("map shape out of range (%dx%d)"),
-		  depth->shape.w, depth->shape.h);
+      lw6sys_log (LW6SYS_LOG_WARNING, _("bad layer shape (%dx%d != %dx%d)"),
+		  layer->shape.w, layer->shape.h, shape->w, shape->h);
       ret = 0;
     }
+
+  return ret;
+}
+
+static int
+pop_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
+{
+  int ret = 1;
+  int layer;
+
   ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(depth->max));
+    && lw6sys_hexa_serializer_pop_whd (hexa_serializer, &(body->shape));
+  if (lw6sys_shape_check_min_max_whd
+      (&body->shape, LW6MAP_MIN_SIDE, LW6MAP_MAX_SIDE, LW6MAP_MAX_DEPTH))
+    {
+      for (layer = 0; layer < body->shape.d; ++layer)
+	{
+	  ret = ret
+	    && pop_layer (hexa_serializer, &(body->layers[layer]),
+			  &(body->shape));
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("map shape out of range (%dx%dx%d)"),
+		  body->shape.w, body->shape.h, body->shape.d);
+      ret = 0;
+    }
 
   return ret;
 }
@@ -336,23 +374,25 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
   lw6sys_color_8_t color = LW6SYS_COLOR_8_BLACK;
 
   ret = ret
-    && lw6sys_hexa_serializer_pop_wh (hexa_serializer, &(texture->shape));
-  if (texture->shape.w >= LW6MAP_MIN_SIDE
-      && texture->shape.w <= LW6MAP_MAX_SIDE
-      && texture->shape.h >= LW6MAP_MIN_SIDE
-      && texture->shape.h <= LW6MAP_MAX_SIDE
-      && texture->shape.w * texture->shape.h >= LW6MAP_MIN_SURFACE
-      && texture->shape.w * texture->shape.h <= LW6MAP_MAX_SURFACE)
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(texture->w));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(texture->h));
+  if (texture->w >= LW6MAP_MIN_SIDE
+      && texture->w <= LW6MAP_MAX_SIDE
+      && texture->h >= LW6MAP_MIN_SIDE
+      && texture->h <= LW6MAP_MAX_SIDE
+      && texture->w * texture->h >= LW6MAP_MIN_SURFACE
+      && texture->w * texture->h <= LW6MAP_MAX_SURFACE)
     {
       texture->data =
-	(lw6sys_color_8_t *) LW6SYS_CALLOC (texture->shape.w *
-					    texture->shape.h *
+	(lw6sys_color_8_t *) LW6SYS_CALLOC (texture->w *
+					    texture->h *
 					    sizeof (lw6sys_color_8_t));
       if (texture->data)
 	{
-	  for (y = 0; y < texture->shape.h && ret; ++y)
+	  for (y = 0; y < texture->h && ret; ++y)
 	    {
-	      for (x = 0; x < texture->shape.w && ret; ++x)
+	      for (x = 0; x < texture->w && ret; ++x)
 		{
 		  ret = ret
 		    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
@@ -369,7 +409,7 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING, _("texture shape out of range (%dx%d)"),
-		  texture->shape.w, texture->shape.h);
+		  texture->w, texture->h);
       ret = 0;
     }
   ret = ret
@@ -553,7 +593,7 @@ lw6map_from_hexa (char *hexa)
       if (level)
 	{
 	  ok = ok && pop_metadata (hexa_serializer, &(level->metadata));
-	  ok = ok && pop_depth (hexa_serializer, &(level->depth));
+	  ok = ok && pop_body (hexa_serializer, &(level->body));
 	  ok = ok && pop_texture (hexa_serializer, &(level->texture));
 	  ok = ok && pop_param (hexa_serializer, &(level->param));
 	  if (!lw6sys_hexa_serializer_eof (hexa_serializer))
