@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,11 +37,13 @@ char *LW6MAP_RULES_LIST[] = {
   LW6DEF_FIGHTER_ATTACK,
   LW6DEF_FIGHTER_DEFENSE,
   LW6DEF_FIGHTER_NEW_HEALTH,
+  LW6DEF_FIGHTER_REGENERATE,
   LW6DEF_SIDE_ATTACK_FACTOR,
   LW6DEF_SIDE_DEFENSE_FACTOR,
   LW6DEF_NB_MOVE_TRIES,
   LW6DEF_NB_ATTACK_TRIES,
   LW6DEF_NB_DEFENSE_TRIES,
+  LW6DEF_VERTICAL_MOVE,
   LW6DEF_SINGLE_ARMY_SIZE,
   LW6DEF_TOTAL_ARMIES_SIZE,
   LW6DEF_MAX_NB_TEAMS,
@@ -49,6 +51,7 @@ char *LW6MAP_RULES_LIST[] = {
   LW6DEF_MAX_NB_SERVERS,
   LW6DEF_X_POLARITY,
   LW6DEF_Y_POLARITY,
+  LW6DEF_Z_POLARITY,
   LW6DEF_MAX_ZONE_SIZE,
   LW6DEF_ROUND_DELTA,
   LW6DEF_MAX_ROUND_DELTA,
@@ -90,11 +93,13 @@ static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_FIGHTER_ATTACK,
   LW6MAP_RULES_DEFAULT_FIGHTER_DEFENSE,
   LW6MAP_RULES_DEFAULT_FIGHTER_NEW_HEALTH,
+  LW6MAP_RULES_DEFAULT_FIGHTER_REGENERATE,
   LW6MAP_RULES_DEFAULT_SIDE_ATTACK_FACTOR,
   LW6MAP_RULES_DEFAULT_SIDE_DEFENSE_FACTOR,
   LW6MAP_RULES_DEFAULT_NB_MOVE_TRIES,
   LW6MAP_RULES_DEFAULT_NB_ATTACK_TRIES,
   LW6MAP_RULES_DEFAULT_NB_DEFENSE_TRIES,
+  LW6MAP_RULES_DEFAULT_VERTICAL_MOVE,
   LW6MAP_RULES_DEFAULT_SINGLE_ARMY_SIZE,
   LW6MAP_RULES_DEFAULT_TOTAL_ARMIES_SIZE,
   LW6MAP_RULES_DEFAULT_MAX_NB_TEAMS,
@@ -102,6 +107,7 @@ static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_MAX_NB_SERVERS,
   LW6MAP_RULES_DEFAULT_X_POLARITY,
   LW6MAP_RULES_DEFAULT_Y_POLARITY,
+  LW6MAP_RULES_DEFAULT_Z_POLARITY,
   LW6MAP_RULES_DEFAULT_MAX_ZONE_SIZE,
   LW6MAP_RULES_DEFAULT_ROUND_DELTA,
   LW6MAP_RULES_DEFAULT_MAX_ROUND_DELTA,
@@ -142,11 +148,13 @@ static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_FIGHTER_ATTACK,
   LW6MAP_RULES_MIN_FIGHTER_DEFENSE,
   LW6MAP_RULES_MIN_FIGHTER_NEW_HEALTH,
+  LW6MAP_RULES_MIN_FIGHTER_REGENERATE,
   LW6MAP_RULES_MIN_SIDE_ATTACK_FACTOR,
   LW6MAP_RULES_MIN_SIDE_DEFENSE_FACTOR,
   LW6MAP_RULES_MIN_NB_MOVE_TRIES,
   LW6MAP_RULES_MIN_NB_ATTACK_TRIES,
   LW6MAP_RULES_MIN_NB_DEFENSE_TRIES,
+  LW6MAP_RULES_MIN_VERTICAL_MOVE,
   LW6MAP_RULES_MIN_SINGLE_ARMY_SIZE,
   LW6MAP_RULES_MIN_TOTAL_ARMIES_SIZE,
   LW6MAP_RULES_MIN_MAX_NB_TEAMS,
@@ -154,6 +162,7 @@ static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_MAX_NB_SERVERS,
   LW6MAP_RULES_MIN_X_POLARITY,
   LW6MAP_RULES_MIN_Y_POLARITY,
+  LW6MAP_RULES_MIN_Z_POLARITY,
   LW6MAP_RULES_MIN_MAX_ZONE_SIZE,
   LW6MAP_RULES_MIN_ROUND_DELTA,
   LW6MAP_RULES_MIN_MAX_ROUND_DELTA,
@@ -194,11 +203,13 @@ static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_FIGHTER_ATTACK,
   LW6MAP_RULES_MAX_FIGHTER_DEFENSE,
   LW6MAP_RULES_MAX_FIGHTER_NEW_HEALTH,
+  LW6MAP_RULES_MAX_FIGHTER_REGENERATE,
   LW6MAP_RULES_MAX_SIDE_ATTACK_FACTOR,
   LW6MAP_RULES_MAX_SIDE_DEFENSE_FACTOR,
   LW6MAP_RULES_MAX_NB_MOVE_TRIES,
   LW6MAP_RULES_MAX_NB_ATTACK_TRIES,
   LW6MAP_RULES_MAX_NB_DEFENSE_TRIES,
+  LW6MAP_RULES_MAX_VERTICAL_MOVE,
   LW6MAP_RULES_MAX_SINGLE_ARMY_SIZE,
   LW6MAP_RULES_MAX_TOTAL_ARMIES_SIZE,
   LW6MAP_RULES_MAX_MAX_NB_TEAMS,
@@ -206,6 +217,7 @@ static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_MAX_NB_SERVERS,
   LW6MAP_RULES_MAX_X_POLARITY,
   LW6MAP_RULES_MAX_Y_POLARITY,
+  LW6MAP_RULES_MAX_Z_POLARITY,
   LW6MAP_RULES_MAX_MAX_ZONE_SIZE,
   LW6MAP_RULES_MAX_ROUND_DELTA,
   LW6MAP_RULES_MAX_MAX_ROUND_DELTA,
@@ -264,11 +276,13 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
   lw6sys_checksum_update_int32 (checksum, rules->fighter_attack);
   lw6sys_checksum_update_int32 (checksum, rules->fighter_defense);
   lw6sys_checksum_update_int32 (checksum, rules->fighter_new_health);
+  lw6sys_checksum_update_int32 (checksum, rules->fighter_regenerate);
   lw6sys_checksum_update_int32 (checksum, rules->side_attack_factor);
   lw6sys_checksum_update_int32 (checksum, rules->side_defense_factor);
   lw6sys_checksum_update_int32 (checksum, rules->nb_move_tries);
   lw6sys_checksum_update_int32 (checksum, rules->nb_attack_tries);
   lw6sys_checksum_update_int32 (checksum, rules->nb_defense_tries);
+  lw6sys_checksum_update_int32 (checksum, rules->vertical_move);
   lw6sys_checksum_update_int32 (checksum, rules->single_army_size);
   lw6sys_checksum_update_int32 (checksum, rules->total_armies_size);
   lw6sys_checksum_update_int32 (checksum, rules->max_nb_teams);
@@ -276,6 +290,7 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
   lw6sys_checksum_update_int32 (checksum, rules->max_nb_servers);
   lw6sys_checksum_update_int32 (checksum, rules->x_polarity);
   lw6sys_checksum_update_int32 (checksum, rules->y_polarity);
+  lw6sys_checksum_update_int32 (checksum, rules->z_polarity);
   lw6sys_checksum_update_int32 (checksum, rules->max_zone_size);
   lw6sys_checksum_update_int32 (checksum, rules->round_delta);
   lw6sys_checksum_update_int32 (checksum, rules->max_round_delta);
@@ -350,6 +365,10 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->fighter_new_health);
 	    }
+	  else if (!strcmp (formatted_key, LW6DEF_FIGHTER_REGENERATE))
+	    {
+	      ret = &(rules->fighter_regenerate);
+	    }
 	  else if (!strcmp (formatted_key, LW6DEF_SIDE_ATTACK_FACTOR))
 	    {
 	      ret = &(rules->side_attack_factor);
@@ -370,6 +389,10 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->nb_defense_tries);
 	    }
+	  else if (!strcmp (formatted_key, LW6DEF_VERTICAL_MOVE))
+	    {
+	      ret = &(rules->vertical_move);
+	    }
 	  else if (!strcmp (formatted_key, LW6DEF_SINGLE_ARMY_SIZE))
 	    {
 	      ret = &(rules->single_army_size);
@@ -398,6 +421,10 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->y_polarity);
 	    }
+	  else if (!strcmp (formatted_key, LW6DEF_Z_POLARITY))
+	    {
+	      ret = &(rules->z_polarity);
+	    }
 	  else if (!strcmp (formatted_key, LW6DEF_MAX_ZONE_SIZE))
 	    {
 	      ret = &(rules->max_zone_size);
