@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ lw6map_style_defaults (lw6map_style_t * style)
   style->animation_density = LW6MAP_STYLE_DEFAULT_ANIMATION_DENSITY;
   style->animation_speed = LW6MAP_STYLE_DEFAULT_ANIMATION_SPEED;
   style->cursor_size = LW6MAP_STYLE_DEFAULT_CURSOR_SIZE;
+  style->hidden_layer_alpha = LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA;
   style->colorize = LW6MAP_STYLE_DEFAULT_COLORIZE;
   style->color_base.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_COLOR_BASE_BG);
@@ -238,6 +239,10 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
 	{
 	  style->cursor_size = lw6sys_atof (value);
 	}
+      else if (!strcmp (LW6DEF_HIDDEN_LAYER_ALPHA, formatted_key))
+	{
+	  style->hidden_layer_alpha = lw6sys_atof (value);
+	}
       else if (!strcmp (LW6DEF_COLORIZE, formatted_key))
 	{
 	  style->colorize = lw6sys_atob (value);
@@ -447,6 +452,10 @@ lw6map_style_get (lw6map_style_t * style, char *key)
 	{
 	  ret = lw6sys_ftoa (style->cursor_size);
 	}
+      else if (!strcmp (LW6DEF_HIDDEN_LAYER_ALPHA, formatted_key))
+	{
+	  ret = lw6sys_ftoa (style->hidden_layer_alpha);
+	}
       else if (!strcmp (LW6DEF_COLORIZE, formatted_key))
 	{
 	  ret = lw6sys_btoa (style->colorize);
