@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,16 +28,18 @@
 
 #include "map.h"
 
-#define TEST_MAP_WIDTH 72
-#define TEST_MAP_HEIGHT 24
+#define TEST_MAP_NB_LAYERS 2
+#define TEST_MAP_WIDTH 8
+#define TEST_MAP_HEIGHT 6
 #define TEST_RULES_KEY LW6DEF_TOTAL_TIME
 #define TEST_RULES_VALUE 3600
-#define TEST_RULES_CHECKSUM 0x1b844db5
+#define TEST_RULES_CHECKSUM 0x3c5fbb06
 #define TEST_STYLE_KEY LW6DEF_ZOOM
 #define TEST_STYLE_VALUE "1.0"
 #define TEST_COORDS_NB 5
 #define TEST_COORDS_W 100
 #define TEST_COORDS_H 50
+#define TEST_COORDS_D 1
 #define TEST_COORDS_X1 66
 #define TEST_COORDS_Y1 33
 #define TEST_COORDS_X2 130
@@ -122,7 +124,7 @@ test_coords ()
 
   {
     lw6map_rules_t rules;
-    lw6sys_wh_t shape;
+    lw6sys_whd_t shape;
     int test_x[TEST_COORDS_NB] =
       { TEST_COORDS_X1, TEST_COORDS_X2, TEST_COORDS_X3, TEST_COORDS_X4,
       TEST_COORDS_X5
@@ -136,6 +138,7 @@ test_coords ()
     lw6map_rules_defaults (&rules);
     shape.w = TEST_COORDS_W;
     shape.h = TEST_COORDS_H;
+    shape.d = TEST_COORDS_D;
 
     for (py = 1; py >= -1; --py)
       {
@@ -151,7 +154,7 @@ test_coords ()
 		y = test_y[i];
 		lw6sys_log (LW6SYS_LOG_NOTICE, _("coords before fix %d,%d"),
 			    x, y);
-		lw6map_coords_fix (&rules, &shape, &x, &y);
+		lw6map_coords_fix_xy (&rules, &shape, &x, &y);
 		lw6sys_log (LW6SYS_LOG_NOTICE, _("coords after fix %d,%d"), x,
 			    y);
 	      }
@@ -178,7 +181,8 @@ test_defaults ()
     lw6map_level_t *level = NULL;
     char *repr = NULL;
 
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	repr = lw6map_repr (level);
@@ -219,7 +223,8 @@ test_dup ()
     char *repr1 = NULL;
     char *repr2 = NULL;
 
-    level1 = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level1 =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level1)
       {
 	repr1 = lw6map_repr (level1);
@@ -277,8 +282,10 @@ test_hexa ()
     lw6map_level_t *level = NULL;
     char *repr = NULL;
     char *hexa = NULL;
+    char *hexa_check = NULL;
 
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	repr = lw6map_repr (level);
@@ -311,6 +318,27 @@ test_hexa ()
 		  {
 		    ret = 0;
 		  }
+
+		hexa_check = lw6map_to_hexa (level);
+		if (hexa_check)
+		  {
+		    if (!strcmp (hexa, hexa_check))
+		      {
+			lw6sys_log (LW6SYS_LOG_NOTICE,
+				    _("copy and original look the same"));
+		      }
+		    else
+		      {
+			lw6sys_log (LW6SYS_LOG_WARNING,
+				    _("copy and original are different"));
+			ret = 0;
+		      }
+		    LW6SYS_FREE (hexa_check);
+		  }
+		else
+		  {
+		    ret = 0;
+		  }
 		lw6map_free (level);
 	      }
 	    else
