@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,18 +54,22 @@
 #define LW6MAP_RULES_MIN_ROUNDS_PER_SEC 1
 #define LW6MAP_RULES_MAX_ROUNDS_PER_SEC 100
 
-#define LW6MAP_RULES_DEFAULT_FIGHTER_ATTACK 750
+#define LW6MAP_RULES_DEFAULT_FIGHTER_ATTACK 500
 #define LW6MAP_RULES_MIN_FIGHTER_ATTACK 1
 #define LW6MAP_RULES_MAX_FIGHTER_ATTACK LW6MAP_MAX_FIGHTER_HEALTH
 
-#define LW6MAP_RULES_DEFAULT_FIGHTER_DEFENSE 75
-#define LW6MAP_RULES_MIN_FIGHTER_DEFENSE 1
+#define LW6MAP_RULES_DEFAULT_FIGHTER_DEFENSE 50
+#define LW6MAP_RULES_MIN_FIGHTER_DEFENSE 0
 #define LW6MAP_RULES_MAX_FIGHTER_DEFENSE LW6MAP_MAX_FIGHTER_HEALTH
 
-#define LW6MAP_RULES_DEFAULT_FIGHTER_NEW_HEALTH 3000
+#define LW6MAP_RULES_DEFAULT_FIGHTER_NEW_HEALTH 5000
 #define LW6MAP_RULES_MIN_FIGHTER_NEW_HEALTH 1
 #define LW6MAP_RULES_MAX_FIGHTER_NEW_HEALTH LW6MAP_MAX_FIGHTER_HEALTH
 
+#define LW6MAP_RULES_DEFAULT_FIGHTER_REGENERATE 5
+#define LW6MAP_RULES_MIN_FIGHTER_REGENERATE 0
+#define LW6MAP_RULES_MAX_FIGHTER_REGENERATE LW6MAP_MAX_FIGHTER_HEALTH
+
 #define LW6MAP_RULES_DEFAULT_SIDE_ATTACK_FACTOR 20	// 20%
 #define LW6MAP_RULES_MIN_SIDE_ATTACK_FACTOR 0
 #define LW6MAP_RULES_MAX_SIDE_ATTACK_FACTOR 100
@@ -86,6 +90,10 @@
 #define LW6MAP_RULES_MIN_NB_DEFENSE_TRIES 1
 #define LW6MAP_RULES_MAX_NB_DEFENSE_TRIES LW6MAP_MAX_NB_DIR_TRIES
 
+#define LW6MAP_RULES_DEFAULT_VERTICAL_MOVE 1
+#define LW6MAP_RULES_MIN_VERTICAL_MOVE 0
+#define LW6MAP_RULES_MAX_VERTICAL_MOVE LW6MAP_MAX_NB_DIR_TRIES
+
 #define LW6MAP_RULES_DEFAULT_SINGLE_ARMY_SIZE 30	// 9%
 #define LW6MAP_RULES_MIN_SINGLE_ARMY_SIZE 1	// 0.01%
 #define LW6MAP_RULES_MAX_SINGLE_ARMY_SIZE 95	// 90%
@@ -114,6 +122,10 @@
 #define LW6MAP_RULES_MIN_Y_POLARITY -1
 #define LW6MAP_RULES_MAX_Y_POLARITY 1
 
+#define LW6MAP_RULES_DEFAULT_Z_POLARITY 0
+#define LW6MAP_RULES_MIN_Z_POLARITY 0
+#define LW6MAP_RULES_MAX_Z_POLARITY 1
+
 #define LW6MAP_RULES_DEFAULT_MAX_ZONE_SIZE 8
 #define LW6MAP_RULES_MIN_MAX_ZONE_SIZE 1
 #define LW6MAP_RULES_MAX_MAX_ZONE_SIZE 64
@@ -249,11 +261,13 @@ typedef struct lw6map_rules_s
   int32_t fighter_attack;
   int32_t fighter_defense;
   int32_t fighter_new_health;
+  int32_t fighter_regenerate;
   int32_t side_attack_factor;
   int32_t side_defense_factor;
   int32_t nb_move_tries;
   int32_t nb_attack_tries;
   int32_t nb_defense_tries;
+  int32_t vertical_move;
   int32_t single_army_size;
   int32_t total_armies_size;
   int32_t max_nb_teams;
@@ -261,6 +275,7 @@ typedef struct lw6map_rules_s
   int32_t max_nb_servers;
   int32_t x_polarity;
   int32_t y_polarity;
+  int32_t z_polarity;
   int32_t max_zone_size;
   int32_t round_delta;
   int32_t max_round_delta;
@@ -293,10 +308,10 @@ typedef struct lw6map_rules_s
 } lw6map_rules_t;
 extern char *LW6MAP_RULES_LIST[];
 
-#define LW6MAP_MIN_SIDE 5
-#define LW6MAP_MAX_SIDE 10000
-#define LW6MAP_MIN_SURFACE 100
-#define LW6MAP_MAX_SURFACE 25000000
+#define LW6MAP_MIN_SIDE 3
+#define LW6MAP_MAX_SIDE 8000	// serious limit here, must be < 8191
+#define LW6MAP_MIN_SURFACE 12
+#define LW6MAP_MAX_SURFACE 48000000
 
 #define LW6MAP_MAX_DEPTH 7	// can't be too high for perf issues
 
@@ -309,6 +324,7 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_STYLE_DEFAULT_ANIMATION_DENSITY 1.0f
 #define LW6MAP_STYLE_DEFAULT_ANIMATION_SPEED 1.0f
 #define LW6MAP_STYLE_DEFAULT_CURSOR_SIZE 1.0f
+#define LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA 0.1f
 #define LW6MAP_STYLE_DEFAULT_COLORIZE 1
 #define LW6MAP_STYLE_DEFAULT_COLOR_BASE_BG "#000"
 #define LW6MAP_STYLE_DEFAULT_COLOR_BASE_FG "#ccc"
@@ -370,18 +386,16 @@ typedef struct lw6map_metadata_s
   char *title;
   char *readme;
 } lw6map_metadata_t;
-typedef struct lw6map_depth_s
+typedef struct lw6map_layer_s
 {
-  lw6sys_wh_t shape;
-
-  /*
-   * Depth is used for game logic. 8 fighters can fit on a slot/point
-   * when depth is 8. The default depth (as of Liquid War 5) is 1, and
-   * only one fighter can fit. 0 mean it's a wall. This 
-   */
-  unsigned char *data;
-  int max;
-} lw6map_depth_t;
+  lw6sys_whd_t shape;
+  u_int8_t *data;
+} lw6map_layer_t;
+typedef struct lw6map_body_s
+{
+  lw6sys_whd_t shape;
+  lw6map_layer_t layers[LW6MAP_MAX_DEPTH];
+} lw6map_body_t;
 typedef struct lw6map_color_couple_s
 {
   lw6sys_color_8_t fg;
@@ -389,7 +403,8 @@ typedef struct lw6map_color_couple_s
 } lw6map_color_couple_t;
 typedef struct lw6map_texture_s
 {
-  lw6sys_wh_t shape;
+  int w;
+  int h;
   lw6sys_color_8_t *data;
   lw6map_color_couple_t guessed_color_base;
   lw6map_color_couple_t guessed_color_alternate;
@@ -405,6 +420,7 @@ typedef struct lw6map_style_s
   float animation_density;
   float animation_speed;
   float cursor_size;
+  float hidden_layer_alpha;
   int colorize;
   lw6map_color_couple_t color_base;
   lw6map_color_couple_t color_alternate;
@@ -429,42 +445,51 @@ typedef struct lw6map_level_s
 {
   u_int32_t id;
   lw6map_metadata_t metadata;
-  lw6map_depth_t depth;
+  lw6map_body_t body;
   lw6map_texture_t texture;
   lw6map_param_t param;
 } lw6map_level_t;
 
 /*
- * Simple setters/getters. Not so usefull since the purpose of 
- * having plain pointers on a raw buffer is exactly to bypass 
- * these kind of cumbersome functions 8-). In fact having the 
- * setter is a good way to 1) test and 2) find out quickly how 
- * data is stored.
+ * Commodity inline setters/getters
  */
-static inline void
-lw6map_depth_set (lw6map_depth_t * depth, int x, int y, unsigned char value)
-{
-  depth->data[y * depth->shape.w + x] = value;
-} static inline unsigned char
 
-lw6map_depth_get (lw6map_depth_t * depth, int x, int y)
+static inline void
+lw6map_body_set (lw6map_body_t * body, int x, int y, int z, u_int8_t value)
 {
-  return depth->data[y * depth->shape.w + x];
+  body->layers[z].data[y * body->shape.w + x] = value;
+}
+
+static inline u_int8_t
+lw6map_body_get (lw6map_body_t * body, int x, int y, int z)
+{
+  return body->layers[z].data[y * body->shape.w + x];
+}
+
+static inline void
+lw6map_layer_set (lw6map_layer_t * layer, int x, int y, u_int8_t value)
+{
+  layer->data[y * layer->shape.w + x] = value;
+}
+
+static inline u_int8_t
+lw6map_layer_get (lw6map_layer_t * layer, int x, int y)
+{
+  return layer->data[y * layer->shape.w + x];
 }
 
 static inline void
 lw6map_texture_set (lw6map_texture_t * texture, int x, int y,
 		    lw6sys_color_8_t value)
 {
-  texture->data[y * texture->shape.w + x] = value;
+  texture->data[y * texture->w + x] = value;
 } static inline lw6sys_color_8_t
 
 lw6map_texture_get (lw6map_texture_t * texture, int x, int y)
 {
-  return texture->data[y * texture->shape.w + x];
+  return texture->data[y * texture->w + x];
 }
 
-
 /* map-color.c */
 extern void lw6map_color_invert (lw6map_color_couple_t * color);
 extern int lw6map_color_is_same (lw6map_color_couple_t * color1,
@@ -474,35 +499,38 @@ extern int lw6map_team_color_key_to_index (char *key);
 
 
 /* map-coords.c */
-extern void lw6map_coords_fix (lw6map_rules_t * rules, lw6sys_wh_t * shape,
-			       int *x, int *y);
+extern void lw6map_coords_fix_xy (lw6map_rules_t * rules,
+				  lw6sys_whd_t * shape, int *x, int *y);
+extern void lw6map_coords_fix_z (lw6map_rules_t * rules, lw6sys_whd_t * shape,
+				 int *z);
 
 /* map-dup.c */
 extern lw6map_level_t *lw6map_dup (lw6map_level_t * source);
 
-/*
- * In depth.c
- */
-extern void lw6map_depth_defaults (lw6map_depth_t * depth, int w, int h);
-extern void lw6map_depth_clear (lw6map_depth_t * depth);
-extern void lw6map_depth_fill (lw6map_depth_t * depth, unsigned char value);
-extern int lw6map_depth_check_and_fix_holes (lw6map_depth_t * depth,
-					     lw6map_rules_t * rules);
-extern int lw6map_depth_coord_from_texture (lw6map_level_t * level,
-					    int *depth_x, int *depth_y,
-					    int texture_x, int texture_y);
-extern unsigned char lw6map_depth_get_with_texture_coord (lw6map_level_t *
-							  level,
-							  int texture_x,
-							  int texture_y);
+/* map-body.c */
+extern void lw6map_body_defaults (lw6map_body_t * body, int w, int h, int d);
+extern void lw6map_body_clear (lw6map_body_t * body);
+extern int lw6map_body_check_and_fix_holes (lw6map_body_t * body,
+					    lw6map_rules_t * rules);
+extern int lw6map_body_coord_from_texture (lw6map_level_t * level,
+					   int *depth_x, int *depth_y,
+					   int texture_x, int texture_y);
+extern u_int8_t lw6map_body_get_with_texture_coord (lw6map_level_t *
+						    level,
+						    int texture_x,
+						    int texture_y, int z);
 
 /* map-hexa.c */
 extern char *lw6map_to_hexa (lw6map_level_t * level);
 extern lw6map_level_t *lw6map_from_hexa (char *hexa);
 
+/* map-layer.c */
+extern void lw6map_layer_defaults (lw6map_layer_t * layer, int w, int h);
+extern void lw6map_layer_clear (lw6map_layer_t * layer);
+
 /* map-level.c */
 extern lw6map_level_t *lw6map_new ();
-extern lw6map_level_t *lw6map_defaults (int w, int h);
+extern lw6map_level_t *lw6map_defaults (int w, int h, int d);
 extern void lw6map_free (lw6map_level_t * level);
 extern int lw6map_memory_footprint (lw6map_level_t * level);
 extern char *lw6map_repr (lw6map_level_t * level);
@@ -555,17 +583,16 @@ extern int lw6map_test ();
 /*
  * In texture.c
  */
-extern int lw6map_texture_defaults (lw6map_texture_t * texture);
 extern void lw6map_texture_clear (lw6map_texture_t * texture);
-extern int lw6map_texture_coord_from_depth (lw6map_level_t * level,
-					    int *texture_x, int *texture_y,
-					    int depth_x, int depth_y);
-extern lw6sys_color_8_t lw6map_texture_get_with_depth_coord (lw6map_level_t *
-							     level,
-							     int depth_x,
-							     int depth_y);
-extern int lw6map_texture_from_depth (lw6map_texture_t * texture,
-				      lw6map_depth_t * depth,
-				      lw6map_color_couple_t * color);
+extern int lw6map_texture_coord_from_body (lw6map_level_t * level,
+					   int *texture_x, int *texture_y,
+					   int body_x, int body_y);
+extern lw6sys_color_8_t lw6map_texture_get_with_body_coord (lw6map_level_t *
+							    level,
+							    int body_x,
+							    int body_y);
+extern int lw6map_texture_from_body (lw6map_texture_t * texture,
+				     lw6map_body_t * body,
+				     lw6map_color_couple_t * color);
 
 #endif /*  */
