@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #define BENCH_DURATION 10
 #define BENCH_MAP_WIDTH 400
 #define BENCH_MAP_HEIGHT 300
+#define BENCH_MAP_NB_LAYERS 1
 #define DUMMY_INIT 0.0f
 #define DUMMY_INC 0.000001f
 #define BENCH_WORKER_SLEEP 0.001f
@@ -181,7 +182,8 @@ lw6pil_bench (float *bench_result)
   lw6pil_pilot_t *pilot = NULL;
   float value;
 
-  level = lw6map_defaults (BENCH_MAP_WIDTH, BENCH_MAP_HEIGHT);
+  level =
+    lw6map_defaults (BENCH_MAP_WIDTH, BENCH_MAP_HEIGHT, BENCH_MAP_NB_LAYERS);
   if (level)
     {
       level->param.rules.total_time = LW6MAP_RULES_MAX_TOTAL_TIME;
