@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,16 +29,18 @@
 
 #define TEST_MAP_WIDTH 45
 #define TEST_MAP_HEIGHT 15
+#define TEST_MAP_NB_LAYERS 7
 #define TEST_WORKER_SLEEP 0.02f
 #define TEST_CYCLE 0.5f
 #define TEST_NB_PILOTS 3
 #define TEST_SYNC_COMMAND_I 10
 #define TEST_BACKUP_ROUND 70
-#define TEST_BACKUP_CHECKSUM 0x2548b55e
+#define TEST_BACKUP_CHECKSUM 0x0cf2d466
 #define TEST_CALIBRATE_TICKS 12345
 #define TEST_COORDS_NB 5
 #define TEST_COORDS_W 100
 #define TEST_COORDS_H 50
+#define TEST_COORDS_D 1
 #define TEST_COORDS_X1 66.0f
 #define TEST_COORDS_Y1 33.0f
 #define TEST_COORDS_X2 130.0f
@@ -49,6 +51,7 @@
 #define TEST_COORDS_Y4 -5.5f
 #define TEST_COORDS_X5 1000.1f
 #define TEST_COORDS_Y5 51.1f
+#define TEST_COORDS_Z 0.0f
 
 static char *test_commands[] = {
   "2 1234abcd1234abcd REGISTER",
@@ -179,7 +182,7 @@ test_coords ()
 
   {
     lw6map_rules_t rules;
-    lw6sys_wh_t shape;
+    lw6sys_whd_t shape;
     float test_x[TEST_COORDS_NB] =
       { TEST_COORDS_X1, TEST_COORDS_X2, TEST_COORDS_X3, TEST_COORDS_X4,
       TEST_COORDS_X5
@@ -189,11 +192,12 @@ test_coords ()
       TEST_COORDS_Y5
     };
     int i, px, py;
-    float x, y;
+    float x, y, z;
 
     lw6map_rules_defaults (&rules);
     shape.w = TEST_COORDS_W;
     shape.h = TEST_COORDS_H;
+    shape.d = TEST_COORDS_D;
 
     for (py = 1; py >= -1; --py)
       {
@@ -207,11 +211,13 @@ test_coords ()
 	      {
 		x = test_x[i];
 		y = test_y[i];
+		z = TEST_COORDS_Z;
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("coords before fix %0.2f,%0.2f"), x, y);
-		lw6pil_coords_fix (&rules, &shape, &x, &y);
+			    _("coords before fix %0.2f,%0.2f,%0.2f"), x, y,
+			    z);
+		lw6pil_coords_fix (&rules, &shape, &x, &y, &z);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("coords after fix %0.2f,%0.2f"), x, y);
+			    _("coords after fix %0.2f,%0.2f,0.2f"), x, y, z);
 	      }
 	  }
       }
@@ -257,7 +263,8 @@ test_pilot ()
     int i;
     u_int32_t checksum = 0;
 
-    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
+    level =
+      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
     if (level)
       {
 	/*
