@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -126,8 +126,8 @@ extern int lw6pil_command_execute_text (lw6ker_game_state_t * game_state,
 					char *command_text);
 
 /* pil-coords.c */
-extern void lw6pil_coords_fix (lw6map_rules_t * rules, lw6sys_wh_t * shape,
-			       float *x, float *y);
+extern void lw6pil_coords_fix (lw6map_rules_t * rules, lw6sys_whd_t * shape,
+			       float *x, float *y, float *z);
 
 /* pil-pilot.c */
 extern lw6pil_pilot_t *lw6pil_pilot_new (lw6ker_game_state_t * game_state,
