@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "sys.h"
 #include "sys-build.h"
 
-#define COPYRIGHT "Copyright (C)  2008  Christian Mauduit <ufoot@ufoot.org>"
+#define COPYRIGHT "Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>"
 #define LICENSE "GPLv3+ (GNU GPL version 3 or later)"
 #define TOP_SRCDIR_TEST_FILE "liquidwar6.spec.in"
 #define TOP_SRCDIR_MAX_UNPARENT 4
@@ -326,6 +326,40 @@ lw6sys_build_get_target_cpu ()
   return LW6_TARGET_CPU;
 }
 
+/**
+ * lw6sys_build_get_endianness:
+ *
+ * Returns the endianness of the computer.
+ *
+ * Return value: 'little' (x86-like) or 'big' (ppc-like), as a string.
+ *   Must not be freed.
+ */
+char *
+lw6sys_build_get_endianness ()
+{
+  char *ret = "little";		// do not translate this, could be used by another program
+
+  if (lw6sys_is_big_endian ())
+    {
+      ret = "big";		// do not translate this, could be used by another program
+    }
+
+  return ret;
+}
+
+/**
+ * lw6sys_build_get_pointer_size:
+ *
+ * Returns the system pointer size, in bytes.
+ *
+ * Return value: 4 for 32-bit, 8 for 64-bit.
+ */
+int
+lw6sys_build_get_pointer_size ()
+{
+  return sizeof (void *);
+}
+
 /**
  * lw6sys_build_get_target_os:
  *
@@ -693,15 +727,16 @@ lw6sys_build_get_enable_valgrind ()
 }
 
 /**
- * lw6sys_build_log_pedigree
+ * lw6sys_build_log_all
  *
- * Dumps in the log file the whole program pedigree, that is, what are
- * the values of all the build options. Usefull for bug reports.
+ * Dumps in the log file the whole program pedigree, target, modules,
+ * that is, what are the values of all the build options. 
+ * Usefull for bug reports.
  *
  * Return value: none.
  */
 void
-lw6sys_build_log_pedigree ()
+lw6sys_build_log_all ()
 {
   lw6sys_log (LW6SYS_LOG_INFO, _("build package tarname is \"%s\""),
 	      lw6sys_build_get_package_tarname ());
@@ -735,9 +770,13 @@ lw6sys_build_log_pedigree ()
 	      lw6sys_build_get_time ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build target cpu is \"%s\""),
 	      lw6sys_build_get_target_cpu ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build endianness is \"%s\""),
+	      lw6sys_build_get_endianness ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build pointer size is %d"),
+	      lw6sys_build_get_pointer_size ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build target os is \"%s\""),
 	      lw6sys_build_get_target_os ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build ms windows is \"%d\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _("build ms windows is %d"),
 	      lw6sys_build_is_ms_windows ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build top_srcdir is \"%s\""),
 	      lw6sys_build_get_top_srcdir ());
