@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ lw6sys_clear_file (char *filename)
   int ret = 0;
   FILE *f = NULL;
 
-  f = fopen (filename, "w");
+  f = fopen (filename, "wb");
   if (f)
     {
       fclose (f);
@@ -147,7 +147,7 @@ lw6sys_write_file_content (char *filename, char *content)
   FILE *f = NULL;
   int ret = 0;
 
-  f = fopen (filename, "w");
+  f = fopen (filename, "wb");
   if (f)
     {
       if (strlen (content) == fprintf (f, "%s", content))
