@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -422,47 +422,49 @@ lw6sys_hexa_serializer_push_str (lw6sys_hexa_serializer_t * hexa_serializer,
 }
 
 /**
- * lw6sys_hexa_serializer_push_xy
+ * lw6sys_hexa_serializer_push_xyz
  *
  * @hexa_serializer: an hexa serializer object
  * @value: value to push
  *
- * Pushes a lw6sys_xy_t structure in the serializer object.
+ * Pushes a lw6sys_xyz_t structure in the serializer object.
  * Calling this avoids calling push for 2 integers separately.
  *
  * Return value: 1 if success, 0 if failure
  */
 int
-lw6sys_hexa_serializer_push_xy (lw6sys_hexa_serializer_t *
-				hexa_serializer, lw6sys_xy_t value)
+lw6sys_hexa_serializer_push_xyz (lw6sys_hexa_serializer_t *
+				 hexa_serializer, lw6sys_xyz_t value)
 {
   int ret = 1;
 
   ret = ret && lw6sys_hexa_serializer_push_int16 (hexa_serializer, value.x);
   ret = ret && lw6sys_hexa_serializer_push_int16 (hexa_serializer, value.y);
+  ret = ret && lw6sys_hexa_serializer_push_int16 (hexa_serializer, value.z);
 
   return ret;
 }
 
 /**
- * lw6sys_hexa_serializer_push_wh
+ * lw6sys_hexa_serializer_push_whd
  *
  * @hexa_serializer: an hexa serializer object
  * @value: value to push
  *
- * Pushes a lw6sys_wh_t structure in the serializer object.
+ * Pushes a lw6sys_whd_t structure in the serializer object.
  * Calling this avoids calling push for 2 integers separately.
  *
  * Return value: 1 if success, 0 if failure
  */
 int
-lw6sys_hexa_serializer_push_wh (lw6sys_hexa_serializer_t *
-				hexa_serializer, lw6sys_wh_t value)
+lw6sys_hexa_serializer_push_whd (lw6sys_hexa_serializer_t *
+				 hexa_serializer, lw6sys_whd_t value)
 {
   int ret = 1;
 
   ret = ret && lw6sys_hexa_serializer_push_int16 (hexa_serializer, value.w);
   ret = ret && lw6sys_hexa_serializer_push_int16 (hexa_serializer, value.h);
+  ret = ret && lw6sys_hexa_serializer_push_int16 (hexa_serializer, value.d);
 
   return ret;
 }
@@ -728,19 +730,19 @@ lw6sys_hexa_serializer_pop_str (lw6sys_hexa_serializer_t * hexa_serializer,
 }
 
 /**
- * lw6sys_hexa_serializer_pop_xy
+ * lw6sys_hexa_serializer_pop_xyz
  *
  * @hexa_serializer: an hexa serializer object
  * @value: value to pop (returned value)
  *
- * Pops a lw6sys_xy_t structure from the serializer object.
+ * Pops a lw6sys_xyz_t structure from the serializer object.
  * Avoids calling two integer pops.
  *
  * Return value: 1 if success, 0 if failure
  */
 int
-lw6sys_hexa_serializer_pop_xy (lw6sys_hexa_serializer_t *
-			       hexa_serializer, lw6sys_xy_t * value)
+lw6sys_hexa_serializer_pop_xyz (lw6sys_hexa_serializer_t *
+				hexa_serializer, lw6sys_xyz_t * value)
 {
   int ret = 1;
   int16_t s;
@@ -755,24 +757,29 @@ lw6sys_hexa_serializer_pop_xy (lw6sys_hexa_serializer_t *
     {
       value->y = s;
     }
+  ret = ret && lw6sys_hexa_serializer_pop_int16 (hexa_serializer, &s);
+  if (ret)
+    {
+      value->z = s;
+    }
 
   return ret;
 }
 
 /**
- * lw6sys_hexa_serializer_pop_wh
+ * lw6sys_hexa_serializer_pop_whd
  *
  * @hexa_serializer: an hexa serializer object
  * @value: value to pop (returned value)
  *
- * Pops a lw6sys_wh_t structure from the serializer object.
+ * Pops a lw6sys_whd_t structure from the serializer object.
  * Avoids calling two integer pops.
  *
  * Return value: 1 if success, 0 if failure
  */
 int
-lw6sys_hexa_serializer_pop_wh (lw6sys_hexa_serializer_t *
-			       hexa_serializer, lw6sys_wh_t * value)
+lw6sys_hexa_serializer_pop_whd (lw6sys_hexa_serializer_t *
+				hexa_serializer, lw6sys_whd_t * value)
 {
   int ret = 1;
   int16_t s;
@@ -787,6 +794,11 @@ lw6sys_hexa_serializer_pop_wh (lw6sys_hexa_serializer_t *
     {
       value->h = s;
     }
+  ret = ret && lw6sys_hexa_serializer_pop_int16 (hexa_serializer, &s);
+  if (ret)
+    {
+      value->d = s;
+    }
 
   return ret;
 }
