@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -81,7 +81,11 @@ lw6sys_locale_to_utf8 (char *string)
 	{
 	  int ilen;
 	  int max_olen;
+#ifdef LW6_MS_WINDOWS
+	  const char *iptr;
+#else
 	  char *iptr;
+#endif
 	  size_t ileft;
 	  char *optr;
 	  size_t oleft;
