@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -535,7 +535,7 @@ open_log_file ()
   name = get_log_file ();
   if (name)
     {
-      ret = fopen (name, "a");
+      ret = fopen (name, "ab");
       LW6SYS_FREE (name);
     }
 
@@ -547,6 +547,7 @@ log_to_file (FILE * f, int level_id, char *level_str, char *file, int line,
 	     char *fmt, va_list ap)
 {
   char ctime_buf[_LW6SYS_LOG_CTIME_BUF_SIZE];
+  char *ctime_ret = NULL;
   time_t t;
   char *file_only;
 
@@ -561,11 +562,14 @@ log_to_file (FILE * f, int level_id, char *level_str, char *file, int line,
     }
 
   t = time (NULL);
-  ctime_r (&t, ctime_buf);
-  ctime_buf[_LW6SYS_LOG_CTIME_ZERO] = '\0';
+  ctime_ret = ctime_r (&t, ctime_buf);
+  if (ctime_ret == ctime_buf)
+    {
+      ctime_buf[_LW6SYS_LOG_CTIME_ZERO] = '\0';
 
-  fprintf (f, "%s\t%s:%d\t%d\t%s\t", ctime_buf,
-	   file_only, line, level_id, level_str);
+      fprintf (f, "%s\t%s:%d\t%d\t%s\t", ctime_buf,
+	       file_only, line, level_id, level_str);
+    }
   vfprintf (f, fmt, ap);
   fprintf (f, "\n");
   fflush (f);
