@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -87,8 +87,8 @@
 #define TEST_HEXA_FLOAT 2.0f
 #define TEST_HEXA_STR1 "abc"
 #define TEST_HEXA_STR2 "defghi"
-#define TEST_HEXA_WH {1,2}
-#define TEST_HEXA_XY {3,4}
+#define TEST_HEXA_WHD {1,2,3}
+#define TEST_HEXA_XYZ {4,5,6}
 #define TEST_HEXA_COLOR {25,50,75,100}
 #define TEST_KEYWORD LW6DEF_PREFIX
 #ifdef LW6_MS_WINDOWS
@@ -139,10 +139,13 @@
 #define TEST_HISTORY_TIMEOUT 2
 #define TEST_SHAPE_W 640
 #define TEST_SHAPE_H 480
+#define TEST_SHAPE_D 3
 #define TEST_SHAPE_X 123
 #define TEST_SHAPE_Y 456
-#define TEST_SHAPE_MIN 10
-#define TEST_SHAPE_MAX 1000
+#define TEST_SHAPE_Z 1
+#define TEST_SHAPE_MIN_WH 10
+#define TEST_SHAPE_MAX_WH 1000
+#define TEST_SHAPE_MAX_D 5
 
 /*
  * Testing functions in arg.c
@@ -317,7 +320,7 @@ test_build ()
     lw6sys_log (LW6SYS_LOG_NOTICE, _("build version is \"%s\""),
 		lw6sys_build_get_version ());
 
-    lw6sys_build_log_pedigree ();
+    lw6sys_build_log_all ();
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -818,8 +821,8 @@ test_hexa ()
     int8_t test_8;
     float test_float;
     char *test_str = NULL;
-    lw6sys_wh_t test_wh = TEST_HEXA_WH;
-    lw6sys_xy_t test_xy = TEST_HEXA_XY;
+    lw6sys_whd_t test_whd = TEST_HEXA_WHD;
+    lw6sys_xyz_t test_xyz = TEST_HEXA_XYZ;
     lw6sys_color_8_t test_color = TEST_HEXA_COLOR;
 
     hexa_serializer = lw6sys_hexa_serializer_new ("");
@@ -848,9 +851,9 @@ test_hexa ()
 	  && lw6sys_hexa_serializer_push_str (hexa_serializer,
 					      TEST_HEXA_STR2);
 	ret = ret
-	  && lw6sys_hexa_serializer_push_wh (hexa_serializer, test_wh);
+	  && lw6sys_hexa_serializer_push_whd (hexa_serializer, test_whd);
 	ret = ret
-	  && lw6sys_hexa_serializer_push_xy (hexa_serializer, test_xy);
+	  && lw6sys_hexa_serializer_push_xyz (hexa_serializer, test_xyz);
 	ret = ret
 	  && lw6sys_hexa_serializer_push_color (hexa_serializer, test_color);
 	if (ret)
@@ -938,19 +941,21 @@ test_hexa ()
 	      {
 		ret = 0;
 	      }
-	    if (lw6sys_hexa_serializer_pop_wh (hexa_serializer, &test_wh))
+	    if (lw6sys_hexa_serializer_pop_whd (hexa_serializer, &test_whd))
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _("wh loaded, value=%dx%d"),
-			    (int) test_wh.w, (int) test_wh.h);
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("whd loaded, value=%dx%dx%d"), (int) test_whd.w,
+			    (int) test_whd.h, (int) test_whd.d);
 	      }
 	    else
 	      {
 		ret = 0;
 	      }
-	    if (lw6sys_hexa_serializer_pop_xy (hexa_serializer, &test_xy))
+	    if (lw6sys_hexa_serializer_pop_xyz (hexa_serializer, &test_xyz))
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _("xy loaded, value=%d,%d"),
-			    (int) test_xy.x, (int) test_xy.y);
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("xyz loaded, value=%d,%d,%d"), (int) test_xyz.x,
+			    (int) test_xyz.y, (int) test_xyz.z);
 	      }
 	    else
 	      {
@@ -1392,6 +1397,8 @@ test_mem ()
       lw6sys_log (LW6SYS_LOG_NOTICE, _("little endian"));
     }
 
+  ret = ret && lw6sys_check_types_size ();
+
   LW6SYS_TEST_FUNCTION_END;
   return ret;
 }
@@ -2049,15 +2056,16 @@ test_shape ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_wh_t shape = { TEST_SHAPE_W, TEST_SHAPE_H };
-    lw6sys_xy_t pos = { TEST_SHAPE_X, TEST_SHAPE_Y };
+    lw6sys_whd_t shape = { TEST_SHAPE_W, TEST_SHAPE_H, TEST_SHAPE_D };
+    lw6sys_xyz_t pos = { TEST_SHAPE_X, TEST_SHAPE_Y, TEST_SHAPE_Z };
 
-    if (lw6sys_shape_check_min_max (&shape, TEST_SHAPE_MIN, TEST_SHAPE_MAX))
+    if (lw6sys_shape_check_min_max_whd
+	(&shape, TEST_SHAPE_MIN_WH, TEST_SHAPE_MAX_WH, TEST_SHAPE_MAX_D))
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _("shape %dx%d respects [%d-%d] constraints"),
-		    (int) shape.w, (int) shape.h, TEST_SHAPE_MIN,
-		    TEST_SHAPE_MAX);
+		    _("shape %dx%dx%d respects [%d-%d-%d] constraints"),
+		    (int) shape.w, (int) shape.h, (int) shape.d,
+		    TEST_SHAPE_MIN_WH, TEST_SHAPE_MAX_WH, TEST_SHAPE_MAX_D);
       }
     else
       {
@@ -2065,8 +2073,10 @@ test_shape ()
       }
     if (lw6sys_shape_check_pos (&shape, &pos))
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE, _("pos %d,%d is inside shape %d,%d"),
-		    (int) pos.x, (int) pos.y, (int) shape.w, (int) shape.h);
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("pos %d,%d,%d is inside shape %dx%dx%d"), (int) pos.x,
+		    (int) pos.y, (int) pos.z, (int) shape.w, (int) shape.h,
+		    (int) shape.d);
       }
     else
       {
