@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -111,15 +111,15 @@ typedef char *char_ptr_t;
 #define LW6SYS_SCRIPT_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin script function \"%s\""),__FUNCTION__); }
 #define LW6SYS_SCRIPT_FUNCTION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end script function \"%s\""),__FUNCTION__); }
 
-typedef struct lw6sys_xy_s
+typedef struct lw6sys_xyz_s
 {
   /*
-   * Forced to 16 bits to optimize data alignment.
+   * All-in 32 bit 3D position, to save memory.
    *
    * It's a deliberate choice in Liquid War to handle "limited size"
-   * levels. In fact 16b bits still allows 30000x30000 maps, which are
-   * at least 1000 times too slow to play now (2006). Should we follow
-   * Moore's law we'd have at least 10 years until those are playable,
+   * levels. In fact 14 bits still allows 8000x8000 maps, which are
+   * at least 100 times too slow to play now (2008). Should we follow
+   * Moore's law we'd have at least 6 years until those are playable,
    * and well, until then, let's wait. The point is that storing this
    * information (x*y) on 4 bytes might be very important in some cases,
    * since it can reduce memory footprint on structs which are stored
@@ -127,29 +127,30 @@ typedef struct lw6sys_xy_s
    * use level 1 & 2 caches and other nice things which happen when
    * memory consumption is not too high.
    *
-   * Point is: why use INT32 and then limit it to 16 bits instead of
+   * Point is: why use INT32 and then limit it to 14 bits instead of
    * using an INT16 or short in the first place? Answer: it's easier
    * to handle INT32 all the time in the rest of the code. Compiler
    * and CPU might even handle that better than short. Then, and only
    * when data will be read/written in the struct will it be truncated.
    * Typical example is: we want to multiplicate y by w (which is a
    * width). Result is beyond INT16/short scope but we want to handle
-   * it! Casting everything to INT32/int is a pain. With this int y:16
+   * it! Casting everything to INT32/int is a pain. With this int y:14
    * trick, we use y as a "full-featured" INT32/int and well, when it
-   * will be read/written we'll loose values over 32767, but we simply
+   * will be read/written we'll loose values over 8191, but we simply
    * do not care.
    */
-  int32_t x:16;
-  int32_t y:16;
+  int32_t x:14;
+  int32_t y:14;
+  int32_t z:4;
 }
-lw6sys_xy_t;
+lw6sys_xyz_t;
 
-typedef struct lw6sys_wh_s
+typedef struct lw6sys_whd_s
 {
   /*
-   * 3 differences with its "XY" equivalent:
-   * - sometimes w*h reads better than x*y.
-   * - xy is signed, wh is unsigned
+   * 3 differences with its "XYZ" equivalent:
+   * - sometimes w*h*d reads better than x*y*z.
+   * - xyz is signed, whd is unsigned
    * - these are real int32 values, it does not really cost any
    *   memory for it's usually used as a single "shape" attribute
    *   for a whole map. At the same time, it's very often used
@@ -159,8 +160,9 @@ typedef struct lw6sys_wh_s
    */
   u_int32_t w;
   u_int32_t h;
+  u_int32_t d;
 }
-lw6sys_wh_t;
+lw6sys_whd_t;
 
 typedef struct lw6sys_color_f_s
 {
@@ -209,9 +211,12 @@ typedef struct lw6sys_module_pedigree_s
   char *time;
 } lw6sys_module_pedigree_t;
 
-#define LW6SYS_SIZEOF_INT64 8
-#define LW6SYS_SIZEOF_INT32 4
+#define LW6SYS_SIZEOF_INT8 1
 #define LW6SYS_SIZEOF_INT16 2
+#define LW6SYS_SIZEOF_INT32 4
+#define LW6SYS_SIZEOF_INT64 8
+
+#define LW6SYS_SIZEOF_XYZ 4
 
 typedef void (*lw6sys_free_func_t) (void *data);
 typedef void (*lw6sys_assoc_callback_func_t) (void *func_data, char *key,
@@ -362,6 +367,8 @@ extern char *lw6sys_build_get_hostname ();
 extern char *lw6sys_build_get_date ();
 extern char *lw6sys_build_get_time ();
 extern char *lw6sys_build_get_target_cpu ();
+extern char *lw6sys_build_get_endianness ();
+extern int lw6sys_build_get_pointer_size ();
 extern char *lw6sys_build_get_target_os ();
 extern int lw6sys_build_is_ms_windows ();
 extern char *lw6sys_build_get_top_srcdir ();
@@ -382,15 +389,15 @@ extern char *lw6sys_build_get_enable_fullstatic ();
 extern char *lw6sys_build_get_enable_gprof ();
 extern char *lw6sys_build_get_enable_gcov ();
 extern char *lw6sys_build_get_enable_valgrind ();
-extern void lw6sys_build_log_pedigree ();
+extern void lw6sys_build_log_all ();
 
 /* sys-checksum.c */
 extern u_int32_t lw6sys_checksum (unsigned char *data, int len);
 extern u_int32_t lw6sys_checksum_str (char *value);
 extern u_int32_t lw6sys_checksum_int32 (u_int32_t value);
 extern u_int32_t lw6sys_checksum_int64 (u_int64_t value);
-extern u_int32_t lw6sys_checksum_wh (lw6sys_wh_t * wh);
-extern u_int32_t lw6sys_checksum_xy (lw6sys_xy_t * xy);
+extern u_int32_t lw6sys_checksum_whd (lw6sys_whd_t * whd);
+extern u_int32_t lw6sys_checksum_xyz (lw6sys_xyz_t * xyz);
 extern void lw6sys_checksum_update (u_int32_t * checksum,
 				    unsigned char *data, int len);
 extern void lw6sys_checksum_update_str (u_int32_t * checksum, char *value);
@@ -398,10 +405,10 @@ extern void lw6sys_checksum_update_int32 (u_int32_t * checksum,
 					  int32_t value);
 extern void lw6sys_checksum_update_int64 (u_int32_t * checksum,
 					  int64_t value);
-extern void lw6sys_checksum_update_wh (u_int32_t * checksum,
-				       lw6sys_wh_t * wh);
-extern void lw6sys_checksum_update_xy (u_int32_t * checksum,
-				       lw6sys_xy_t * xy);
+extern void lw6sys_checksum_update_whd (u_int32_t * checksum,
+					lw6sys_whd_t * whd);
+extern void lw6sys_checksum_update_xyz (u_int32_t * checksum,
+					lw6sys_xyz_t * xyz);
 
 /* sys-color.c */
 extern u_int8_t lw6sys_color_float2char (float f);
@@ -505,12 +512,12 @@ extern int lw6sys_hexa_serializer_push_float (lw6sys_hexa_serializer_t *
 					      hexa_serializer, float value);
 extern int lw6sys_hexa_serializer_push_str (lw6sys_hexa_serializer_t *
 					    hexa_serializer, char *value);
-extern int lw6sys_hexa_serializer_push_xy (lw6sys_hexa_serializer_t *
-					   hexa_serializer,
-					   lw6sys_xy_t value);
-extern int lw6sys_hexa_serializer_push_wh (lw6sys_hexa_serializer_t *
-					   hexa_serializer,
-					   lw6sys_wh_t value);
+extern int lw6sys_hexa_serializer_push_xyz (lw6sys_hexa_serializer_t *
+					    hexa_serializer,
+					    lw6sys_xyz_t value);
+extern int lw6sys_hexa_serializer_push_whd (lw6sys_hexa_serializer_t *
+					    hexa_serializer,
+					    lw6sys_whd_t value);
 extern int lw6sys_hexa_serializer_push_color (lw6sys_hexa_serializer_t *
 					      hexa_serializer,
 					      lw6sys_color_8_t value);
@@ -529,12 +536,12 @@ extern int lw6sys_hexa_serializer_pop_float (lw6sys_hexa_serializer_t *
 					     hexa_serializer, float *value);
 extern int lw6sys_hexa_serializer_pop_str (lw6sys_hexa_serializer_t *
 					   hexa_serializer, char **value);
-extern int lw6sys_hexa_serializer_pop_xy (lw6sys_hexa_serializer_t *
-					  hexa_serializer,
-					  lw6sys_xy_t * value);
-extern int lw6sys_hexa_serializer_pop_wh (lw6sys_hexa_serializer_t *
-					  hexa_serializer,
-					  lw6sys_wh_t * value);
+extern int lw6sys_hexa_serializer_pop_xyz (lw6sys_hexa_serializer_t *
+					   hexa_serializer,
+					   lw6sys_xyz_t * value);
+extern int lw6sys_hexa_serializer_pop_whd (lw6sys_hexa_serializer_t *
+					   hexa_serializer,
+					   lw6sys_whd_t * value);
 extern int lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
 					     hexa_serializer,
 					     lw6sys_color_8_t * value);
@@ -594,10 +601,10 @@ extern void lw6sys_log_set_level (int level);
 
 /* sys-mem.c */
 #ifdef LW6_OPTIMIZE
-#define LW6SYS_MALLOC(SIZE) malloc(SIZE)
-#define LW6SYS_CALLOC(SIZE) calloc(SIZE)
-#define LW6SYS_REALLOC(SIZE) realloc(SIZE)
-#define LW6SYS_FREE(PTR) free(PTR)
+#define LW6SYS_MALLOC(SIZE) malloc((SIZE))
+#define LW6SYS_CALLOC(SIZE) calloc((SIZE),1)
+#define LW6SYS_REALLOC(PTR,SIZE) realloc((PTR),(SIZE))
+#define LW6SYS_FREE(PTR) free((PTR))
 #else
 #define LW6SYS_MALLOC(SIZE) lw6sys_malloc((SIZE),__FILE__,__LINE__)
 #define LW6SYS_CALLOC(SIZE) lw6sys_calloc((SIZE),__FILE__,__LINE__)
@@ -613,6 +620,7 @@ extern void lw6sys_free_callback (void *ptr);
 extern int lw6sys_megabytes_available ();
 extern int lw6sys_is_big_endian ();
 extern int lw6sys_is_little_endian ();
+extern int lw6sys_check_types_size ();
 
 /* sys-mutex.c */
 extern void *lw6sys_mutex_create ();
@@ -709,9 +717,9 @@ extern void lw6sys_serialize_int16 (unsigned char *data, int16_t value);
 extern int16_t lw6sys_unserialize_int16 (unsigned char *data);
 
 /* sys-shape.c */
-extern int lw6sys_shape_check_min_max (lw6sys_wh_t * shape, int min,
-				       int max);;
-extern int lw6sys_shape_check_pos (lw6sys_wh_t * shape, lw6sys_xy_t * pos);
+extern int lw6sys_shape_check_min_max_whd (lw6sys_whd_t * shape, int min_wh,
+					   int max_wh, int max_d);;
+extern int lw6sys_shape_check_pos (lw6sys_whd_t * shape, lw6sys_xyz_t * pos);
 
 /* sys-sort.c */
 extern int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
