@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,8 @@ typedef struct _lw6tsk_loader_stage1_s
   char *relative_path;
   lw6sys_assoc_t *default_param;
   lw6sys_assoc_t *forced_param;
-  lw6sys_wh_t display_shape;
+  int display_w;
+  int display_h;
   lw6map_level_t *level;
 }
 _lw6tsk_loader_stage1_t;
