@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -78,8 +78,8 @@ stage1_clear_request (_lw6tsk_loader_stage1_t * stage1)
       lw6sys_assoc_free (stage1->forced_param);
       stage1->forced_param = NULL;
     }
-  stage1->display_shape.w = 0;
-  stage1->display_shape.h = 0;
+  stage1->display_w = 0;
+  stage1->display_h = 0;
 }
 
 static void
@@ -154,7 +154,8 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
   lw6sys_assoc_t *default_param = NULL;
   lw6sys_assoc_t *forced_param = NULL;
   lw6map_level_t *level = NULL;
-  lw6sys_wh_t display_shape = { 0, 0 };
+  int display_w = 0;
+  int display_h = 0;
   lw6map_level_t *src2 = NULL;
   lw6sys_progress_t progress;
   float dummy = 0.0f;
@@ -185,7 +186,8 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
       forced_param =
 	lw6sys_assoc_dup (loader_data->stage1.forced_param,
 			  (lw6sys_dup_func_t) lw6sys_str_copy);
-      display_shape = loader_data->stage1.display_shape;
+      display_w = loader_data->stage1.display_w;
+      display_h = loader_data->stage1.display_h;
 
       stage1_clear_request (&(loader_data->stage1));
     }
@@ -198,7 +200,7 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
       level =
 	lw6ldr_read_relative (map_path, relative_path, default_param,
-			      forced_param, &display_shape, &progress);
+			      forced_param, display_w, display_h, &progress);
       if (level)
 	{
 	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
@@ -416,7 +418,7 @@ void
 lw6tsk_loader_push (lw6tsk_loader_t * loader, char *map_path,
 		    char *relative_path, lw6sys_assoc_t * default_param,
 		    lw6sys_assoc_t * forced_param,
-		    lw6sys_wh_t * display_shape)
+		    int display_w, int display_h)
 {
   _lw6tsk_loader_data_t *loader_data;
 
@@ -432,7 +434,8 @@ lw6tsk_loader_push (lw6tsk_loader_t * loader, char *map_path,
     lw6sys_assoc_dup (default_param, (lw6sys_dup_func_t) lw6sys_str_copy);
   loader_data->stage1.forced_param =
     lw6sys_assoc_dup (forced_param, (lw6sys_dup_func_t) lw6sys_str_copy);
-  loader_data->stage1.display_shape = *display_shape;
+  loader_data->stage1.display_w = display_w;
+  loader_data->stage1.display_h = display_h;
 
   LOADER_UNLOCK;
 }
