@@ -1,4 +1,6 @@
 _("begin main game loop");	// extracted by scriptpo-update.sh
+_("Please wait...");		// extracted by scriptpo-update.sh
+_("Please wait...");		// extracted by scriptpo-update.sh
 _("Mouse");			// extracted by scriptpo-update.sh
 _("Keyboard");			// extracted by scriptpo-update.sh
 _("Joystick 1");		// extracted by scriptpo-update.sh
@@ -48,9 +50,30 @@ _("Sound backend");		// extracted by scriptpo-update.sh
 _("scheme error");		// extracted by scriptpo-update.sh
 _("running scheme code with Guile");	// extracted by scriptpo-update.sh
 _("leaving Guile");		// extracted by scriptpo-update.sh
-_("unexpected error, leaving Guile without proper cleaning");	// extracted by scriptpo-update.sh
+_("catched Guile error");	// extracted by scriptpo-update.sh
+_("Quick start");		// extracted by scriptpo-update.sh
+_("Play");			// extracted by scriptpo-update.sh
+_("Choose map");		// extracted by scriptpo-update.sh
+_("Players");			// extracted by scriptpo-update.sh
+_("Options");			// extracted by scriptpo-update.sh
+_("Welcome to Liquid War 6");	// extracted by scriptpo-update.sh
+_("player2");			// extracted by scriptpo-update.sh
+_("player3");			// extracted by scriptpo-update.sh
+_("player4");			// extracted by scriptpo-update.sh
+_("Respawn mode (deatchmatch)");	// extracted by scriptpo-update.sh
+_("Only one life (last wins)");	// extracted by scriptpo-update.sh
+_("Cursors can have any color");	// extracted by scriptpo-update.sh
+_("Can collaborate locally");	// extracted by scriptpo-update.sh
+_("One cursor per team");	// extracted by scriptpo-update.sh
+_("Rules");			// extracted by scriptpo-update.sh
 _("Free slot");			// extracted by scriptpo-update.sh
 _("Players");			// extracted by scriptpo-update.sh
+_("Local game");		// extracted by scriptpo-update.sh
+_("Join network game");		// extracted by scriptpo-update.sh
+_("Start server");		// extracted by scriptpo-update.sh
+_("Demo");			// extracted by scriptpo-update.sh
+_("Play");			// extracted by scriptpo-update.sh
+_("Play");			// extracted by scriptpo-update.sh
 _("Console enabled");		// extracted by scriptpo-update.sh
 _("Console disabled");		// extracted by scriptpo-update.sh
 _("FPS shown");			// extracted by scriptpo-update.sh
@@ -68,18 +91,8 @@ _("orange");			// extracted by scriptpo-update.sh
 _("light blue");		// extracted by scriptpo-update.sh
 _("purple");			// extracted by scriptpo-update.sh
 _("pink");			// extracted by scriptpo-update.sh
-_("Quick start");		// extracted by scriptpo-update.sh
-_("Play");			// extracted by scriptpo-update.sh
-_("Choose map");		// extracted by scriptpo-update.sh
-_("Players");			// extracted by scriptpo-update.sh
-_("Options");			// extracted by scriptpo-update.sh
-_("Welcome to Liquid War 6");	// extracted by scriptpo-update.sh
-_("Local game");		// extracted by scriptpo-update.sh
-_("Join network game");		// extracted by scriptpo-update.sh
-_("Start server");		// extracted by scriptpo-update.sh
-_("Demo");			// extracted by scriptpo-update.sh
-_("Play");			// extracted by scriptpo-update.sh
-_("Play");			// extracted by scriptpo-update.sh
+_("Unknown bot");		// extracted by scriptpo-update.sh
+_("Not playing");		// extracted by scriptpo-update.sh
 _("Fullscreen");		// extracted by scriptpo-update.sh
 _("Windowed");			// extracted by scriptpo-update.sh
 _("Low res");			// extracted by scriptpo-update.sh
@@ -88,6 +101,10 @@ _("High res");			// extracted by scriptpo-update.sh
 _("User res");			// extracted by scriptpo-update.sh
 _("Backend ~a");		// extracted by scriptpo-update.sh
 _("Video options");		// extracted by scriptpo-update.sh
+_("Playing");			// extracted by scriptpo-update.sh
+_("Time ~a:~a~a:~a~a");		// extracted by scriptpo-update.sh
+_("Speed ~ax~a=~a");		// extracted by scriptpo-update.sh
+_("Time & speed");		// extracted by scriptpo-update.sh
 _("Quit");			// extracted by scriptpo-update.sh
 _("Resume");			// extracted by scriptpo-update.sh
 _("Quit Liquid War 6?");	// extracted by scriptpo-update.sh
@@ -105,10 +122,7 @@ _("System");			// extracted by scriptpo-update.sh
 _("Stop current game");		// extracted by scriptpo-update.sh
 _("Options");			// extracted by scriptpo-update.sh
 _("Options");			// extracted by scriptpo-update.sh
-_("player2");			// extracted by scriptpo-update.sh
-_("player3");			// extracted by scriptpo-update.sh
-_("player4");			// extracted by scriptpo-update.sh
-_("running ~a");		// extracted by scriptpo-update.sh
+_("running \"~a\"");		// extracted by scriptpo-update.sh
 _("no graphical backend found, game can only run in pure server/console mode");	// extracted by scriptpo-update.sh
 _("server mode not implemented yet");	// extracted by scriptpo-update.sh
 _("Armies ~a% - ~a%");		// extracted by scriptpo-update.sh
@@ -137,17 +151,3 @@ _("No music");			// extracted by scriptpo-update.sh
 _("Music ~a%");			// extracted by scriptpo-update.sh
 _("Backend ~a");		// extracted by scriptpo-update.sh
 _("Sound options");		// extracted by scriptpo-update.sh
-_("Respawn mode (deatchmatch)");	// extracted by scriptpo-update.sh
-_("Only one life (last wins)");	// extracted by scriptpo-update.sh
-_("Cursors can have any color");	// extracted by scriptpo-update.sh
-_("Can collaborate locally");	// extracted by scriptpo-update.sh
-_("One cursor per team");	// extracted by scriptpo-update.sh
-_("Rules");			// extracted by scriptpo-update.sh
-_("Time ~a:~a~a:~a~a");		// extracted by scriptpo-update.sh
-_("Speed ~ax~a=~a");		// extracted by scriptpo-update.sh
-_("Time & speed");		// extracted by scriptpo-update.sh
-_("Unknown bot");		// extracted by scriptpo-update.sh
-_("Not playing");		// extracted by scriptpo-update.sh
-_("Playing");			// extracted by scriptpo-update.sh
-_("Please wait...");		// extracted by scriptpo-update.sh
-_("Please wait...");		// extracted by scriptpo-update.sh
